// (c)2009 by Texas Instruments Incorporated, All Rights Reserved.
/*----------------------------------------------------------------------------+
|                                                                             |
|                              Texas Instruments                              |
|                                                                             |
|                             USB HID for BSL                                 |
|                                                                             |
+-----------------------------------------------------------------------------+
|  Source: UsbIsr.h, v1.4 2009/10/13                                          |
|  Author: Rostyslav Stolyar                                                  |
|                                                                             |
|  Release Notes:                                                             |
|  Logs:                                                                      |
|                                                                             |
|  WHO          WHEN         WHAT                                             |
|  ---          ----------   ------------------------------------------------ |
|  R.Stolyar    2009/01/21   born                                             |
|  R.Stolyar    2009/03/12   Change from interrupt handling to polling        |
|  R.Stolyar    2009/04/20   Change version number to v1.0                    |
|  R.Stolyar    2009/06/24   Change to _tiny version                          |
|  R.Stolyar    2009/07/03   Added: USB_power_off event initiates BOR         |
|  R.Stolyar    2009/10/13   Added delay in PWRVBUSoffHandler()	              |
|  R.Stolyar    2009/10/14   Increased delay in IntDelay()	                  |
|  R.Stolyar    2009/11/02   Increased priority of Setup packet handling      |
+----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------+
| Include files                                                               |
+----------------------------------------------------------------------------*/

#include "device.h"
#include "defUSB.h"
#include "types.h"      // Basic Type declarations
#include "usb.h"
#include "UsbIsr.h"
#include "Proj_Settings.h"
#include "USBAPI.h"
#include <intrinsics.h>

/*----------------------------------------------------------------------------+
| External Variables                                                          |
+----------------------------------------------------------------------------*/
extern __no_init BYTE  bFunctionSuspended;

extern volatile BYTE *pbBytesRemainingOnOEP1;

extern __no_init tEDB0 tEndPoint0DescriptorBlock;
extern __no_init tEDB tInputEndPointDescriptorBlock[];
extern __no_init tEDB tOutputEndPointDescriptorBlock[];

extern __no_init BYTE bStatusAction;

/*----------------------------------------------------------------------------+
| General Subroutines                                                         |
+----------------------------------------------------------------------------*/

#ifndef _NO_ISR
#pragma vector=USB_UBM_VECTOR
__interrupt VOID iUsbInterruptHandler(VOID)
#else
VOID UsbHandler(VOID)
#endif
{
    BYTE i;
    
    //Check if the setup interrupt is pending. 
    //We need to check it before other interrupts, 
    //to work around that the Setup Int has lower prio then Input Endp0
    if (USBIFG & SETUPIFG)
    {
        SetupPacketInterruptHandler();  
        USBIFG &= ~SETUPIFG;    // clear the interrupt bit
        //return;  no return - to save code space!
    } 
    
    i = USBVECINT;    // read out the interrupt vector register
    
    if (i == VECINT_PWR_VBUSOn_INTERRUPT)
      PWRVBUSonHandler();
    else if (i == VECINT_PWR_VBUSOff_INTERRUPT)
      PWRVBUSoffHandler();
    else if (i == VECINT_INPUT_ENDPOINT0)
      IEP0InterruptHandler();
    /*  else if (i == VECINT_OUTPUT_ENDPOINT0)
      //OEP0InterruptHandler(); */
    else if (i == VECINT_RSTR_INTERRUPT)
      USB_reset();
    else if (i == VECINT_SUSR_INTERRUPT)
      USB_suspend();
    else if (i == VECINT_RESR_INTERRUPT)
      USB_resume();
    
    //work around: no setup handling here, it needs higher priority 
    //and will be performed above.
    //
    //else if (i == VECINT_SETUP_PACKET_RECEIVED)
    //  SetupPacketInterruptHandler();  
}

/*----------------------------------------------------------------------------+
| Interrupt Sub-routines                                                      |
+----------------------------------------------------------------------------*/

VOID SetupPacketInterruptHandler(VOID)
{
    // NAK both input and output endpoints
    //tEndPoint0DescriptorBlock.bIEPBCNT = EPBCNT_NAK;    //-- - the bit should be set by the HW(workaround Rosty)
    tEndPoint0DescriptorBlock.bOEPBCNT = EPBCNT_NAK;

    usbProcessNewSetupPacket:

    bStatusAction = STATUS_ACTION_NOTHING;

    // clear out return data buffer
    abUsbRequestReturnData[0] = 0x00;
    abUsbRequestReturnData[1] = 0x00;
    //abUsbRequestReturnData[2] = 0x00;

    // decode and process the request
    usbDecodeAndProcessUsbRequest();

    // check if there is another setup packet pending
    // if it is, abandon current one by NAKing both data endpoint 0
    if((USBIFG & STPOWIFG) != 0x00)
    {
        USBIFG &= ~(STPOWIFG | SETUPIFG);
        goto usbProcessNewSetupPacket;
    } 
}

//----------------------------------------------------------------------------
VOID IntDelay(VOID)
{
    //volatile unsigned int i;
    //for (i=1100; i; i--);
    __delay_cycles(36000);   // delay for 8000 cycles ~1 ms at 8 MHz
}

//----------------------------------------------------------------------------
VOID PWRVBUSoffHandler(VOID)
{
    IntDelay();	//delay before reset. Needed to avoid the device started again 
				// after it loosing power

	//reset device if USB cable plagged off
    PMMCTL0 = PMMPW | PMMSWBOR; // generate BOR
}

//----------------------------------------------------------------------------

VOID PWRVBUSonHandler(VOID)
{
    IntDelay();
    USB_enable();
    USB_reset();

    USBPWRCTL &= ~(VBONIFG|VBOFFIFG);        // clean pending VBUS ON and OFF interrupts, if any
    USBCNF |= PUR_EN; // generate rising edge on DP -> the host enumerates our device as full speed device
}

//----------------------------------------------------------------------------
VOID IEP0InterruptHandler(VOID)
{
//--      tEndPoint0DescriptorBlock.bIEPBCNT = EPBCNT_NAK; // NAK IEP0 during filling buffer; maybe not requiered, just in case (workaround for IEP0 NAK bug)
    tEndPoint0DescriptorBlock.bOEPBCNT = 0x00;

    if(bStatusAction == STATUS_ACTION_DATA_IN)
    {
        usbSendNextPacketOnIEP0();
    }
    else
    {
        tEndPoint0DescriptorBlock.bIEPCNFG |= EPCNF_STALL; // no more data
    }
}

/*
//----------------------------------------------------------------------------
VOID OEP0InterruptHandler(VOID)
{
    tEndPoint0DescriptorBlock.bIEPBCNT = 0x00;     // will be set by the hardware

    if(bStatusAction == STATUS_ACTION_DATA_OUT)
    {
        usbReceiveNextPacketOnOEP0();

        / * check if needed
        if(bStatusAction == STATUS_ACTION_NOTHING)
        {
            if ((tSetupPacket.bRequest == USB_REQ_SET_REPORT) &&
             (tSetupPacket.bValueH == USB_REQ_HID_OUTPUT))
            {
                Handler_OutReport();
            }
        }  * /
    }
    else
    {
        tEndPoint0DescriptorBlock.bOEPCNFG |= EPCNF_STALL; // no more data
    }
}
*/

/*----------------------------------------------------------------------------+
| Interrupt Service Routines                                                  |
+----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------+
| Main Routine                                                                |
+----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------+
| End of source file                                                          |
+----------------------------------------------------------------------------*/
/*------------------------ Nothing Below This Line --------------------------*/


