#ifndef __MSP430WARE_COMPE_H__
#define __MSP430WARE_COMPE_H__

#define __MSP430_HAS_COMP_E__

//*****************************************************************************
//
//The following are values that can be passed to Comp_init(),
//Comp_disableInputBuffer(), and Comp_enableInputBuffer() in the
//positiveTerminalInput, negativeTerminalInput, and inputPort parameters.
//
//*****************************************************************************
#define COMPE_INPUT0  (CEIPSEL_0)
#define COMPE_INPUT1  (CEIPSEL_1)
#define COMPE_INPUT2  (CEIPSEL_2)
#define COMPE_INPUT3  (CEIPSEL_3)
#define COMPE_INPUT4  (CEIPSEL_4)
#define COMPE_INPUT5  (CEIPSEL_5)
#define COMPE_INPUT6  (CEIPSEL_6)
#define COMPE_INPUT7  (CEIPSEL_7)
#define COMPE_INPUT8  (CEIPSEL_8)
#define COMPE_INPUT9  (CEIPSEL_9)
#define COMPE_INPUT10 (CEIPSEL_10)
#define COMPE_INPUT11 (CEIPSEL_11)
#define COMPE_INPUT12 (CEIPSEL_12)
#define COMPE_INPUT13 (CEIPSEL_13)
#define COMPE_INPUT14 (CEIPSEL_14)
#define COMPE_INPUT15 (CEIPSEL_15)
#define COMPE_VREF    (0x10)

//*****************************************************************************
//
//The following are values that can be passed to Comp_init() in the
//outputFilterEnableAndDelayLevel parameter.
//
//*****************************************************************************
#define COMPE_FILTEROUTPUT_OFF     0x00
#define COMPE_FILTEROUTPUT_DLYLVL1 (CEF + CEFDLY_0)
#define COMPE_FILTEROUTPUT_DLYLVL2 (CEF + CEFDLY_1)
#define COMPE_FILTEROUTPUT_DLYLVL3 (CEF + CEFDLY_2)
#define COMPE_FILTEROUTPUT_DLYLVL4 (CEF + CEFDLY_3)

//*****************************************************************************
//
//The following are values that can be passed to Comp_init() in the
//invertedOutputPolarity parameter.
//
//*****************************************************************************
#define COMPE_NORMALOUTPUTPOLARITY   ( !(CEOUTPOL) )
#define COMPE_INVERTEDOUTPUTPOLARITY (CEOUTPOL)

//*****************************************************************************
//
//The following are values that can be passed to Comp_setReferenceVoltage() in
//the supplyVoltageBase parameter.
//
//*****************************************************************************
#define COMPE_REFERENCE_AMPLIFIER_DISABLED (CEREFL_0)
#define COMPE_VREFBASE1_5V (CEREFL_1)
#define COMPE_VREFBASE2_0V (CEREFL_2)
#define COMPE_VREFBASE2_5V (CEREFL_3)
//deprecated
#define COMPE_VREFBASE_VCC (CEREFL_0)

//*****************************************************************************
//
//The following are values that can be passed to Comp_setReferenceVoltage() in
//the refrenceAccuracy parameter.
//
//*****************************************************************************
#define COMPE_ACCURACY_STATIC	(!CEREFACC)
#define COMPE_ACCURACY_CLOCKED	(CEREFACC)

//*****************************************************************************
//
//The following are values that can be passed to COMPE_setPowerMode() in
//the powerMode parameter.
//
//*****************************************************************************
#define COMPE_HIGH_SPEED_MODE 		(CEPWRMD_0)
#define COMPE_NORMAL_MODE 			(CEPWRMD_1)
#define COMPE_ULTRA_LOW_POWER_MODE	(CEPWRMD_2)


//*****************************************************************************
//
//The following are values that can be passed to Comp_setEdgeDirection() in
//the edgeDirection parameter.
//
//*****************************************************************************
#define COMPE_FALLINGEDGE ( !(CEIES) )
#define COMPE_RISINGEDGE  (CEIES)

//*****************************************************************************
//
//The following are values that returned by COMPE_outputValue().
//
//*****************************************************************************
#define COMPE_LOW  (0x0)
#define COMPE_HIGH (0x1)

//*****************************************************************************
//
//The following are values that can be passed to COMPE_enableInterrupt().
// COMPE_disableInterrupt()
//
//*****************************************************************************
#define COMPE_OUTPUT_INTERRUPT (CEIE)
#define COMPE_INVERTED_POLARITY_INTERRUPT (CEIIE)
#define COMPE_READY_INTERRUPT (CERDYIE)

//*****************************************************************************
//
//The following are values that can be passed to COMPE_clearInterrupt().
// and returned from COMPE_getInterruptStatus()
//
//*****************************************************************************
#define COMPE_INTERRUPT_FLAG (CEIFG)
#define COMPE_INTERRUPT_FLAG_INVERTED_POLARITY (CEIIFG)
#define COMPE_INTERRUPT_FLAG_READY (CERDYIFG)

//*****************************************************************************
//API
//*****************************************************************************

extern unsigned short COMPE_init(unsigned int baseAddress,
		unsigned char positiveTerminalInput,
		unsigned char negativeTerminalInput,
		unsigned char outputFilterEnableAndDelayLevel,
		unsigned short invertedOutputPolarity);

extern void COMPE_setReferenceVoltage (unsigned int baseAddress,
    unsigned int supplyVoltageReferenceBase,
    unsigned int lowerLimitSupplyVoltageFractionOf32,
    unsigned int upperLimitSupplyVoltageFractionOf32);

extern void COMPE_setReferenceAccuracy (unsigned int baseAddress,
	unsigned int referenceAccuracy);
	
extern void COMPE_setPowerMode (unsigned int baseAddress,
		unsigned int powerMode);
	
extern void COMPE_enableInterrupt(unsigned int baseAddress, unsigned int mask);

extern void COMPE_disableInterrupt(unsigned int baseAddress, unsigned int mask);

extern void COMPE_clearInterrupt(unsigned int baseAddress, unsigned int mask);

extern unsigned char COMPE_getInterruptStatus(unsigned int baseAddress,
		unsigned int mask);

extern void COMPE_interruptSetEdgeDirection(unsigned int baseAddress,
		unsigned short edgeDirection);

extern void COMPE_interruptToggleEdgeDirection(unsigned int baseAddress);

extern void COMPE_enable(unsigned int baseAddress);

extern void COMPE_disable(unsigned int baseAddress);

extern void COMPE_shortInputs (unsigned int baseAddress);

extern void COMPE_unshortInputs (unsigned int baseAddress);

extern void COMPE_disableInputBuffer(unsigned int baseAddress,
		unsigned char inputPort);

extern void COMPE_enableInputBuffer(unsigned int baseAddress,
		unsigned char inputPort);

extern void COMPE_IOSwap(unsigned int baseAddress);

extern unsigned short COMPE_outputValue(unsigned int baseAddress);

#endif

