#ifndef __MSP430WARE_EUART_H__
#define __MSP430WARE_EUART_H__

//*****************************************************************************
//
//The following are the defines to include the required modules for this
//peripheral in msp430xgeneric.h file
//
//*****************************************************************************
#define __MSP430_HAS_EUSCI_Ax__

//*****************************************************************************
//
//The following are values that can be passed to the eUART_init() API
//as the parity parameter.
//
//*****************************************************************************
#define eUART_NO_PARITY   0x00
#define eUART_ODD_PARITY  0x01
#define eUART_EVEN_PARITY 0x02

//*****************************************************************************
//
//The following are values that can be passed to the eUART_init() API
//as the selectClockSource parameter.
//
//*****************************************************************************
#define eUART_CLOCKSOURCE_ACLK    UCSSEL__ACLK
#define eUART_CLOCKSOURCE_SMCLK   UCSSEL__SMCLK

//*****************************************************************************

//*****************************************************************************
//
//The following are values that can be passed to the eUART_init() API
//as the numberofStopBits parameter.
//
//*****************************************************************************
#define eUART_ONE_STOP_BIT    0x00
#define eUART_TWO_STOP_BITS   UCSPB


//*****************************************************************************
//
//The following are values that can be passed to the eUART_init() API
//as the msborLsbFirst parameter.
//
//*****************************************************************************
#define eUART_MSB_FIRST    UCMSB
#define eUART_LSB_FIRST    0x00

//*****************************************************************************
//
//The following are values that can be passed to the eUART_getInterruptStatus(),
//as the mask parameter.
//
//*****************************************************************************
#define eUART_RECEIVE_INTERRUPT_FLAG            UCRXIFG
#define eUART_TRANSMIT_INTERRUPT_FLAG           UCTXIFG

//*****************************************************************************
//
//The following are values that can be passed to the eUART_enableInterrupt(),
//eUART_disableInterrupt() API as the mask parameter.
//
//*****************************************************************************
#define eUART_RECEIVE_INTERRUPT                  UCRXIE
#define eUART_TRANSMIT_INTERRUPT                 UCTXIE
#define eUART_RECEIVE_ERRONEOUSCHAR_INTERRUPT    UCRXEIE
#define eUART_BREAKCHAR_INTERRUPT                UCBRKIE

//*****************************************************************************
//
//The following are values that can be passed to the eUART_selectDeglitchTime()
//API as the deglitchTime parameter.
//
//*****************************************************************************
#define eUART_DEGLITCH_TIME_2ns		0x00
#define eUART_DEGLITCH_TIME_50ns	UCGLIT0
#define eUART_DEGLITCH_TIME_100ns	UCGLIT1
#define eUART_DEGLITCH_TIME_200ns	(UCGLIT0 + UCGLIT1)

//*****************************************************************************
//
//The following are values that can be passed to the eUART_queryStatusFlags()
//API as the mask parameter.
//
//*****************************************************************************
#define eUART_LISTEN_ENABLE      UCLISTEN
#define eUART_FRAMING_ERROR      UCFE
#define eUART_OVERRUN_ERROR      UCOE
#define eUART_PARITY_ERROR       UCPE
#define eUARTBREAK_DETECT        UCBRK
#define eUART_RECEIVE_ERROR      UCRXERR
#define eUART_ADDRESS_RECEIVED   UCADDR
#define eUART_IDLELINE           UCIDLE
#define eUART_BUSY               UCBUSY

//*****************************************************************************
//
//The following are values that can be passed to the eUART_init()
//API as the mode parameter.
//
//*****************************************************************************
#define eUART_MODE                              UCMODE_0
#define eUART_IDLE_LINE_MULTI_PROCESSOR_MODE    UCMODE_1
#define eUART_ADDRESS_BIT_MULTI_PROCESSOR_MODE  UCMODE_2
#define eUART_AUTOMATIC_BAUDRATE_DETECTION_MODE UCMODE_3

//*****************************************************************************
//
//The following are values that can be passed to the eUART_init()
//API as the overSampling parameter.
//
//*****************************************************************************
#define eUART_OVERSAMPLING_BAUDRATE_GENERATION     0x01
#define eUART_LOW_FREQUENCY_BAUDRATE_GENERATION    0x00


//*****************************************************************************
//
//The following are values are the sync characters possible
//
//*****************************************************************************
#define DEFAULT_SYNC 0x00
#define eUART_AUTOMATICBAUDRATE_SYNC 0x55

//*****************************************************************************
//
//Prototypes for the APIs.
//
//*****************************************************************************
extern
unsigned short eUART_init ( unsigned int baseAddress,
    unsigned char selectClockSource,
    unsigned long clockSourceFrequency,
    unsigned long desiredUartBaudRate,
    unsigned char parity,
    unsigned int msborLsbFirst,
    unsigned int numberofStopBits,
    unsigned int uartMode,
    unsigned short overSampling
    );
extern
unsigned short eUART_initAdvance ( unsigned int baseAddress,
    unsigned char selectClockSource,
    unsigned int clockPrescalar,
    unsigned char firstModReg,
    unsigned char secondModReg,
    unsigned char parity,
    unsigned int msborLsbFirst,
    unsigned int numberofStopBits,
    unsigned int uartMode,
    unsigned short overSampling
    );
extern
void eUART_transmitData ( unsigned int baseAddress,
    unsigned char transmitData
    );
extern
unsigned char eUART_receiveData (unsigned int baseAddress);
extern
void eUART_enableInterrupt (unsigned int baseAddress,
    unsigned char mask
    );
extern
void eUART_disableInterrupt (unsigned int baseAddress,
    unsigned char mask
    );
extern
unsigned char eUART_getInterruptStatus (unsigned int baseAddress,
    unsigned char mask
    );
extern
void eUART_clearInterruptFlag (unsigned int baseAddress,
    unsigned char mask
    );
extern
void eUART_enable (unsigned int baseAddress);
extern
void eUART_disable (unsigned int baseAddress);
extern
unsigned char eUART_queryStatusFlags (unsigned int baseAddress,
    unsigned char mask);
extern
void eUART_setDormant (unsigned int baseAddress);
extern
void eUART_resetDormant (unsigned int baseAddress);
extern
void eUART_transmitAddress (unsigned int baseAddress,
    unsigned char transmitAddress);
extern
void eUART_transmitBreak (unsigned int baseAddress);
extern
unsigned long eUART_getReceiveBufferAddressForDMA (unsigned int baseAddress);
extern
unsigned long eUART_getTransmitBufferAddressForDMA (unsigned int baseAddress);
extern
void eUART_selectDeglitchTime(unsigned int baseAddress,
			unsigned long deglitchTime
			);
#endif
