#ifndef __MSP430WARE_FRAM_H__
#define __MSP430WARE_FRAM_H__


//*****************************************************************************
//
//The following are the defines to include the required modules for this
//peripheral in msp430xgeneric.h file
//
//*****************************************************************************
#define __MSP430_HAS_FRAM_FR5XX__


//*****************************************************************************
//
//The following are values that can be passed to the FRAM_enableInterrupt,
//FRAM_disableInterrupt, API as the mask parameter.
//
//*****************************************************************************

#define FRAM_PUC_ON_UNCORRECTABLE_BIT		UBDRSTEN
#define FRAM_UNCORRECTABLE_BIT_INTERRUPT	UBDIEN
#define FRAM_CORRECTABLE_BIT_INTERRUPT		CBDIEN
#define FRAM_ACCESS_VIOLATION_INTERRUPT		ACCVIE
#define FRAM_ACCESS_TIME_ERROR_INTERRUPT	ACCTEIE
#define FRAM_PUC_ON_DOUBLE_BIT_ERROR		SBDRSTEN
#define FRAM_DOUBLE_BIT_ERROR_INTERRUPT		DBDIEN
#define FRAM_SINGLE_BIT_ERROR_INTERRUPT		SBDIEN
//deprecated
#define FRAM_UNCORRECTABLE_BIT_INTERUPT		UBDIEN
#define FRAM_ACCESS_TIME_ERROR_INTERUPT		ACCTEIE
#define FRAM_DOUBLE_BIT_ERROR_INTERUPT		DBDIEN
#define FRAM_SINGLE_BIT_ERROR_INTERUPT		SBDIEN

//*****************************************************************************
//
//The following are values that can be passed to the FRAM_getInterruptStatus
//API as the mask parameter.
//
//*****************************************************************************

#define FRAM_ACCESS_TIME_ERROR_FLAG			ACCTEIFG
#define FRAM_UNCORRECTABLE_BIT_FLAG			UBDIFG
#define FRAM_CORRECTABLE_BIT_FLAG			CBDIFG
#define FRAM_ACCESS_VIOLATION_FLAG			ACCVIFG
#define FRAM_SINGLE_BIT_ERROR_FLAG			SBDIFG
#define FRAM_DOUBLE_BIT_ERROR_FLAG			DBDIFG

//*****************************************************************************
//
//The following are values that are returned by FRAM_isBusy().
//
//*****************************************************************************
#define FRAM_NOTBUSY (0x0)
#define FRAM_BUSY    (0x1)

//*****************************************************************************
//
//The following are values that can be passed to the
//FRAM_configureWaitStateControl API as the manualWaitState parameter
//
//*****************************************************************************
#define FRAM_AUTO_MODE						NAUTO
#define FRAM_MANUAL_MODE					0x00

//*****************************************************************************
//
//The following are values that can be passed to the
//FRAM_configureWaitStateControl API as the accessTime parameter
//
//*****************************************************************************
#define FRAM_ACCESS_TIME_CYCLES_0			NACCESS_0
#define FRAM_ACCESS_TIME_CYCLES_1			NACCESS_1
#define FRAM_ACCESS_TIME_CYCLES_2			NACCESS_2
#define FRAM_ACCESS_TIME_CYCLES_3			NACCESS_3
#define FRAM_ACCESS_TIME_CYCLES_4			NACCESS_4
#define FRAM_ACCESS_TIME_CYCLES_5			NACCESS_5
#define FRAM_ACCESS_TIME_CYCLES_6			NACCESS_6
#define FRAM_ACCESS_TIME_CYCLES_7			NACCESS_7

//*****************************************************************************
//
//The following are values that can be passed to the
//FRAM_configureWaitStateControl API as the prechargeTime parameter
//
//*****************************************************************************
#define FRAM_PRECHARGE_TIME_CYCLES_0		NPRECHG_0
#define FRAM_PRECHARGE_TIME_CYCLES_1		NPRECHG_1
#define FRAM_PRECHARGE_TIME_CYCLES_2		NPRECHG_2
#define FRAM_PRECHARGE_TIME_CYCLES_3		NPRECHG_3
#define FRAM_PRECHARGE_TIME_CYCLES_4		NPRECHG_4
#define FRAM_PRECHARGE_TIME_CYCLES_5		NPRECHG_5
#define FRAM_PRECHARGE_TIME_CYCLES_6		NPRECHG_6
#define FRAM_PRECHARGE_TIME_CYCLES_7		NPRECHG_7

//*****************************************************************************
//
//The following are values that can be passed to the
//FRAM_delayPowerUpFromLPM() API as the delayStatus parameter
//
//*****************************************************************************
#define FRAM_DELAY_FROM_LPM_ENABLE			0x00
#define FRAM_DELAY_FROM_LPM_DISABLE			0x02

//*****************************************************************************
//
//Prototypes for the APIs.
//
//*****************************************************************************

extern void FRAM_write8(unsigned int baseAddress,
		unsigned char *dataPtr,
		unsigned char *framPtr,
		unsigned int numberOfBytes);

extern void FRAM_write16(unsigned int baseAddress,
		 unsigned int *dataPtr,
		 unsigned int *framPtr,
		 unsigned int numberOfBytes);

extern void FRAM_write32(unsigned int baseAddress,
		unsigned long *dataPtr,
		unsigned long *framPtr,
		unsigned int numberOfBytes);

extern void FRAM_memoryFill32(unsigned int baseAddress,
		 unsigned long value,
		 unsigned long *framPtr,
		 unsigned int count);

extern void FRAM_enableInterrupt (unsigned int baseAddress,
		unsigned char interruptMask);

extern unsigned char FRAM_getInterruptStatus(unsigned int baseAddress,
		unsigned int interruptFlagMask);

extern void FRAM_disableInterrupt(unsigned int baseAddress,
		unsigned int interruptMask);

extern unsigned short FRAM_isBusy(unsigned int baseAddress);

extern void FRAM_configureWaitStateControl(unsigned int baseAddress,
		unsigned char manualWaitState,
		unsigned char accessTime,
		unsigned char prechargeTime );

extern void FRAM_delayPowerUpFromLPM(unsigned int baseAddress,
		unsigned char delayStatus);
		
#endif
