//*****************************************************************************
//
//ram.c - Driver for the RAM Controller Module.
//
//*****************************************************************************
#include "inc/hw_types.h"
#include "debug.h"
#include "ram.h"
#ifdef  __IAR_SYSTEMS_ICC__
#include "deprecated/IAR/msp430xgeneric.h"
#else
#include "deprecated/CCS/msp430xgeneric.h"
#endif

//*****************************************************************************
//
//! Set specified RAM sector off
//!
//! \param baseAddress is the base address of the Timer module.
//! \param sector is specified sector to be set off.
//! Valid values are a logical OR of
//!         \b RAM_SECTOR0
//!         \b RAM_SECTOR1
//!         \b RAM_SECTOR2
//!         \b RAM_SECTOR3
//!         \b RAM_SECTOR4
//!         \b RAM_SECTOR5
//!         \b RAM_SECTOR6
//!         \b RAM_SECTOR7
//!
//! Modified register RCCTL0
//!
//! \return None
//
//*****************************************************************************
void RAM_setSectorOff (unsigned int baseAddress,
    unsigned char sector
    )
{
    ASSERT(0x00 == sector & (~(RAM_SECTOR0 +
                               RAM_SECTOR1 +
                               RAM_SECTOR2 +
                               RAM_SECTOR3 
                               )
                             )

        );
    //Write key to start write to RCCTL0 and sector
    HWREG(baseAddress + OFS_RCCTL0) = (RCKEY + sector);
}

//*****************************************************************************
//
//! Get RAM sector ON/OFF status
//!
//! \param baseAddress is the base address of the Timer module.
//! \param sector is specified sector
//! Valid values are a logical OR of
//!         \b RAM_SECTOR0
//!         \b RAM_SECTOR1
//!         \b RAM_SECTOR2
//!         \b RAM_SECTOR3
//!         \b RAM_SECTOR4
//!         \b RAM_SECTOR5
//!         \b RAM_SECTOR6
//!         \b RAM_SECTOR7
//!
//! Modified register RCCTL0
//!
//! \return Mask of the sector state that are ON
//
//*****************************************************************************
unsigned char RAM_getSectorState (unsigned int baseAddress,
    unsigned char sector
    )
{
    ASSERT(0x00 == sector & (~(RAM_SECTOR0 +
                               RAM_SECTOR1 +
                               RAM_SECTOR2 +
                               RAM_SECTOR3 
                               )
                             )

        );
    return (HWREGB(baseAddress + OFS_RCCTL0_L) & sector);
}

//*****************************************************************************
//
//Close the Doxygen group.
//! @}
//
//*****************************************************************************
