#ifndef __MSP430WARE_RTC_A_H__
#define __MSP430WARE_RTC_A_H__

//*****************************************************************************
//
//The following are the defines to include the required modules for this
//peripheral in msp430xgeneric.h file
//
//*****************************************************************************
#define __MSP430_HAS_RTC__

//*****************************************************************************
//
//The following is a struct that can be passed to RTC_CalendarInit() in the
//CalendarTime parameter, as well as returned by RTC_getCalendarTime()
//
//*****************************************************************************
typedef struct {
    unsigned char Seconds;
    unsigned char Minutes;
    unsigned char Hours;
    unsigned char DayOfWeek;
    unsigned char DayOfMonth;
    unsigned char Month;
    unsigned int Year;
} Calendar;

//*****************************************************************************
//
//The following are values that can be passed to RTC_setCalibrationData()
//in the offsetDirection parameter.
//
//*****************************************************************************
#define RTC_A_CALIBRATIONFREQ_OFF   (RTCCALF_0)
#define RTC_A_CALIBRATIONFREQ_512HZ (RTCCALF_1)
#define RTC_A_CALIBRATIONFREQ_256HZ (RTCCALF_2)
#define RTC_A_CALIBRATIONFREQ_1HZ   (RTCCALF_3)

//*****************************************************************************
//
//The following are values that can be passed to RTC_A_setCalibrationData()
//in the offsetDirection parameter.
//
//*****************************************************************************
#define RTC_A_CALIBRATION_DOWN2PPM  ( !(RTCCALS) )
#define RTC_A_CALIBRATION_UP4PPM    (RTCCALS)

//*****************************************************************************
//
//The following are values that can be passed to RTC_A_setClockRegistersFormat()
//in the formatSelect parameter.
//
//*****************************************************************************
#define RTC_A_FORMAT_BINARY  ( !(RTCBCD) )
#define RTC_A_FORMAT_BCD     (RTCBCD)

//*****************************************************************************
//
//The following are values that can be passed to RTC_A_counterInit()
//in the clockSelect parameter.
//
//*****************************************************************************
#define RTC_A_CLOCKSELECT_ACLK  (RTCSSEL_0)
#define RTC_A_CLOCKSELECT_SMCLK (RTCSSEL_1)
#define RTC_A_CLOCKSELECT_RT1PS (RTCSSEL_2)

//*****************************************************************************
//
//The following are values that can be passed to RTC_A_counterInit()
//in the counterSizeSelect parameter.
//
//*****************************************************************************
#define RTC_A_COUNTERSIZE_8BIT  (RTCTEV_0)
#define RTC_A_COUNTERSIZE_16BIT (RTCTEV_1)
#define RTC_A_COUNTERSIZE_24BIT (RTCTEV_2)
#define RTC_A_COUNTERSIZE_32BIT (RTCTEV_3)

//*****************************************************************************
//
//The following is a value that can be passed to RTC_A_setCalendarAlarm() in the
//minutesAlarm, hoursAlarm, dayOfWeekAlarm, and dayOfMonthAlarm parameters.
//
//*****************************************************************************
#define RTC_A_ALARMCONDITION_OFF  (0x80)

//*****************************************************************************
//
//The following are values that can be passed to RTC_A_setCalendarEvent()
//in the eventSelect parameter.
//
//*****************************************************************************
#define RTC_A_CALENDAREVENT_MINUTECHANGE  (RTCTEV_0)
#define RTC_A_CALENDAREVENT_HOURCHANGE    (RTCTEV_1)
#define RTC_A_CALENDAREVENT_NOON          (RTCTEV_2)
#define RTC_A_CALENDAREVENT_MIDNIGHT      (RTCTEV_3)

//*****************************************************************************
//
//The following are values that can be passed to RTC_A_counterPrescaleInit(),
//RTC_A_definePreScaleEvent(), RTC_A_readPrescaleCounterValue(), and
//RTC_A_setPrescaleCounterValue() in the prescaleSelect parameter.
//
//*****************************************************************************
#define RTC_A_PRESCALE_0  (0x0)
#define RTC_A_PRESCALE_1  (0x2)

//*****************************************************************************
//
//The following are values that can be passed to RTC_A_counterPrescaleInit()
//in the prescaleClockSelect parameter.
//
//*****************************************************************************
#define RTC_A_PSCLOCKSELECT_ACLK  (RT1SSEL_0)
#define RTC_A_PSCLOCKSELECT_SMCLK (RT1SSEL_1)
#define RTC_A_PSCLOCKSELECT_RT0PS (RT1SSEL_2)

//*****************************************************************************
//
//The following are values that can be passed to RTC_A_counterPrescaleInit()
//in the prescaleDivider parameter.
//
//*****************************************************************************
#define RTC_A_PSDIVIDER_2   (RT0PSDIV_0)
#define RTC_A_PSDIVIDER_4   (RT0PSDIV_1)
#define RTC_A_PSDIVIDER_8   (RT0PSDIV_2)
#define RTC_A_PSDIVIDER_16  (RT0PSDIV_3)
#define RTC_A_PSDIVIDER_32  (RT0PSDIV_4)
#define RTC_A_PSDIVIDER_64  (RT0PSDIV_5)
#define RTC_A_PSDIVIDER_128 (RT0PSDIV_6)
#define RTC_A_PSDIVIDER_256 (RT0PSDIV_7)

//*****************************************************************************
//
//The following are values that can be passed to RTC_A_definePrescaleEvent()
//in the prescaleEventDivider parameter.
//
//*****************************************************************************
#define RTC_A_PSEVENTDIVIDER_2   (RT0IP_0)
#define RTC_A_PSEVENTDIVIDER_4   (RT0IP_1)
#define RTC_A_PSEVENTDIVIDER_8   (RT0IP_2)
#define RTC_A_PSEVENTDIVIDER_16  (RT0IP_3)
#define RTC_A_PSEVENTDIVIDER_32  (RT0IP_4)
#define RTC_A_PSEVENTDIVIDER_64  (RT0IP_5)
#define RTC_A_PSEVENTDIVIDER_128 (RT0IP_6)
#define RTC_A_PSEVENTDIVIDER_256 (RT0IP_7)

//*****************************************************************************
//
//The following are values that can be passed to RTC_A_getInterruptStatus(),
//RTC_A_clearInterrupt(), RTC_A_enableInterrupt(),  RTC_A_disableInterrupt()
//in the interruptFlagMask parameter.
//
//*****************************************************************************
#define RTC_A_TIME_EVENT_INTERRUPT        RTCTEVIE  
#define RTC_A_CLOCK_ALARM_INTERRUPT       RTCAIE    
#define RTC_A_CLOCK_READ_READY_INTERRUPT  RTCRDYIE  
#define RTC_A_PRESCALE_TIMER0_INTERRUPT   0x02
#define RTC_A_PRESCALE_TIMER1_INTERRUPT   0x01


//*****************************************************************************
//
//Prototypes for the APIs.
//
//*****************************************************************************
extern void RTC_A_startClock (unsigned int baseAddress);

extern void RTC_A_holdClock (unsigned int baseAddress);

extern void RTC_A_setCalibrationFrequency (unsigned int baseAddress,
    unsigned int frequencySelect);

extern void RTC_A_setCalibrationData (unsigned int baseAddress,
    unsigned char offsetDirection,
    unsigned char offsetValue);

extern void RTC_A_counterInit (unsigned int baseAddress,
    unsigned int clockSelect,
    unsigned int counterSizeSelect);

extern void RTC_A_calendarInit (unsigned int baseAddress,
    Calendar CalendarTime,
    unsigned int formatSelect);

extern Calendar RTC_A_getCalendarTime (unsigned int baseAddress);

extern void RTC_A_setCalendarAlarm (unsigned int baseAddress,
    unsigned char minutesAlarm,
    unsigned char hoursAlarm,
    unsigned char dayOfWeekAlarm,
    unsigned char dayOfMonthAlarm);

extern void RTC_A_setCalendarEvent (unsigned int baseAddress,
    unsigned int eventSelect);

extern unsigned long RTC_A_getCounterValue (unsigned int baseAddress);

extern void RTC_A_setCounterValue (unsigned int baseAddress,
    unsigned long counterSizeSelect);

extern void RTC_A_counterPrescaleInit (unsigned int baseAddress,
    unsigned char prescaleSelect,
    unsigned int prescaleClockSelect,
    unsigned int prescaleDivider);

extern void RTC_A_counterPrescaleHold (unsigned int baseAddress,
    unsigned char prescaleSelect);

extern void RTC_A_counterPrescaleStart (unsigned int baseAddress,
    unsigned char prescaleSelect);

extern void RTC_A_definePrescaleEvent (unsigned int baseAddress,
    unsigned char prescaleSelect,
    unsigned char prescaleEventDivider);

extern unsigned char RTC_A_getPrescaleValue (unsigned int baseAddress,
    unsigned char prescaleSelect);

extern void RTC_A_setPrescaleValue (unsigned int baseAddress,
    unsigned char prescaleSelect,
    unsigned char prescaleCounterValue);

extern void RTC_A_enableInterrupt (unsigned int baseAddress,
    unsigned char interruptMask);

extern void RTC_A_disableInterrupt (unsigned int baseAddress,
    unsigned char interruptMask);

extern unsigned char RTC_A_getInterruptStatus (unsigned int baseAddress,
    unsigned char interruptFlagMask);

extern void RTC_A_clearInterrupt (unsigned int baseAddress,
    unsigned char interruptFlagMask);

#endif
