#ifndef __MSP430WARE_RTC_C_H__
#define __MSP430WARE_RTC_C_H__

//*****************************************************************************
//
//The following are the defines to include the required modules for this
//peripheral in msp430xgeneric.h file
//
//*****************************************************************************
#define __MSP430_HAS_RTC_C__

//*****************************************************************************
//
//The following is a struct that can be passed to RTC_C_CalendarInit() in the
//CalendarTime parameter, as well as returned by RTC_C_getCalendarTime()
//
//*****************************************************************************
typedef struct {
    unsigned char Seconds;
    unsigned char Minutes;
    unsigned char Hours;
    unsigned char DayOfWeek;
    unsigned char DayOfMonth;
    unsigned char Month;
    unsigned int Year;
} Calendar;

//*****************************************************************************
//
//The following are values that can be passed to RTC_C_setCalibrationData()
//in the offsetDirection parameter.
//
//*****************************************************************************
#define RTC_C_CALIBRATIONFREQ_OFF   (RTCCALF_0)
#define RTC_C_CALIBRATIONFREQ_512HZ (RTCCALF_1)
#define RTC_C_CALIBRATIONFREQ_256HZ (RTCCALF_2)
#define RTC_C_CALIBRATIONFREQ_1HZ   (RTCCALF_3)

//*****************************************************************************
//
//The following are values that can be passed to RTC_C_setCalibrationData()
//in the offsetDirection parameter.
//
//*****************************************************************************
#define RTC_C_CALIBRATION_DOWN1PPM  ( !(RTCOCALS) )
#define RTC_C_CALIBRATION_UP1PPM    (RTCOCALS)

//*****************************************************************************
//
//The following are values that can be passed to
//RTC_C_setTemperatureCompensation() in the offsetDirection parameter.
//
//*****************************************************************************
#define RTC_C_COMPENSATION_DOWN1PPM  ( !(RTCTCMPS) )
#define RTC_C_COMPENSATION_UP1PPM    (RTCTCMPS)

//*****************************************************************************
//
//The following are values that can be passed to RTC_C_setClockRegistersFormat()
//in the formatSelect parameter.
//
//*****************************************************************************
#define RTC_C_FORMAT_BINARY  ( !(RTCBCD) )
#define RTC_C_FORMAT_BCD     (RTCBCD)

//*****************************************************************************
//
//The following are values that can be passed to RTC_C_counterInit()
//in the clockSelect parameter.
//
//*****************************************************************************
#define RTC_C_CLOCKSELECT_ACLK  (RTCSSEL_0)
#define RTC_C_CLOCKSELECT_SMCLK (RTCSSEL_1)
#define RTC_C_CLOCKSELECT_RT1PS (RTCSSEL_2)

//*****************************************************************************
//
//The following are values that can be passed to RTC_C_counterInit()
//in the counterSizeSelect parameter.
//
//*****************************************************************************
#define RTC_C_COUNTERSIZE_8BIT  (RTCTEV_0)
#define RTC_C_COUNTERSIZE_16BIT (RTCTEV_1)
#define RTC_C_COUNTERSIZE_24BIT (RTCTEV_2)
#define RTC_C_COUNTERSIZE_32BIT (RTCTEV_3)

//*****************************************************************************
//
//The following is a value that can be passed to RTC_C_setCalendarAlarm() in the
//minutesAlarm, hoursAlarm, dayOfWeekAlarm, and dayOfMonthAlarm parameters.
//
//*****************************************************************************
#define RTC_C_ALARMCONDITION_OFF  (0x80)

//*****************************************************************************
//
//The following are values that can be passed to RTC_C_setCalendarEvent()
//in the eventSelect parameter.
//
//*****************************************************************************
#define RTC_C_CALENDAREVENT_MINUTECHANGE  (RTCTEV_0)
#define RTC_C_CALENDAREVENT_HOURCHANGE    (RTCTEV_1)
#define RTC_C_CALENDAREVENT_NOON          (RTCTEV_2)
#define RTC_C_CALENDAREVENT_MIDNIGHT      (RTCTEV_3)

//*****************************************************************************
//
//The following are values that can be passed to RTC_C_counterPrescaleInit(),
//RTC_C_definePreScaleEvent(), RTC_C_readPrescaleCounterValue(), and
//RTC_C_setPrescaleCounterValue() in the prescaleSelect parameter.
//
//*****************************************************************************
#define RTC_C_PRESCALE_0  (0x0)
#define RTC_C_PRESCALE_1  (0x2)

//*****************************************************************************
//
//The following are values that can be passed to RTC_C_counterPrescaleInit()
//in the prescaleClockSelect parameter.
//
//*****************************************************************************
#define RTC_C_PSCLOCKSELECT_ACLK  (RT1SSEL_0)
#define RTC_C_PSCLOCKSELECT_SMCLK (RT1SSEL_1)
#define RTC_C_PSCLOCKSELECT_RT0PS (RT1SSEL_2)

//*****************************************************************************
//
//The following are values that can be passed to RTC_C_counterPrescaleInit()
//in the prescaleDivider parameter.
//
//*****************************************************************************
#define RTC_C_PSDIVIDER_2   (RT0PSDIV_0)
#define RTC_C_PSDIVIDER_4   (RT0PSDIV_1)
#define RTC_C_PSDIVIDER_8   (RT0PSDIV_2)
#define RTC_C_PSDIVIDER_16  (RT0PSDIV_3)
#define RTC_C_PSDIVIDER_32  (RT0PSDIV_4)
#define RTC_C_PSDIVIDER_64  (RT0PSDIV_5)
#define RTC_C_PSDIVIDER_128 (RT0PSDIV_6)
#define RTC_C_PSDIVIDER_256 (RT0PSDIV_7)

//*****************************************************************************
//
//The following are values that can be passed to RTC_C_definePrescaleEvent()
//in the prescaleEventDivider parameter.
//
//*****************************************************************************
#define RTC_C_PSEVENTDIVIDER_2   (RT0IP_0)
#define RTC_C_PSEVENTDIVIDER_4   (RT0IP_1)
#define RTC_C_PSEVENTDIVIDER_8   (RT0IP_2)
#define RTC_C_PSEVENTDIVIDER_16  (RT0IP_3)
#define RTC_C_PSEVENTDIVIDER_32  (RT0IP_4)
#define RTC_C_PSEVENTDIVIDER_64  (RT0IP_5)
#define RTC_C_PSEVENTDIVIDER_128 (RT0IP_6)
#define RTC_C_PSEVENTDIVIDER_256 (RT0IP_7)

//*****************************************************************************
//
//The following are values that can be passed to RTC_C_getInterruptStatus(),
//RTC_C_clearInterrupt(), RTC_C_enableInterrupt(),  RTC_C_disableInterrupt()
//in the interruptFlagMask parameter.
//
//*****************************************************************************
#define RTC_C_OSCILLATOR_FAULT_INTERRUPT  RTCOFIE
#define RTC_C_TIME_EVENT_INTERRUPT        RTCTEVIE
#define RTC_C_CLOCK_ALARM_INTERRUPT       RTCAIE
#define RTC_C_CLOCK_READ_READY_INTERRUPT  RTCRDYIE
#define RTC_C_PRESCALE_TIMER0_INTERRUPT   0x02
#define RTC_C_PRESCALE_TIMER1_INTERRUPT   0x01


//*****************************************************************************
//
//Prototypes for the APIs.
//
//*****************************************************************************
extern void RTC_C_startClock (unsigned int baseAddress);

extern void RTC_C_holdClock (unsigned int baseAddress);

extern void RTC_C_setCalibrationFrequency (unsigned int baseAddress,
    unsigned int frequencySelect);

extern void RTC_C_setCalibrationData (unsigned int baseAddress,
    unsigned char offsetDirection,
    unsigned char offsetValue);
    
extern unsigned short RTC_C_setTemperatureCompensation(unsigned int baseAddress,
	unsigned char offsetDirection,
	unsigned char offsetValue);

extern void RTC_C_calendarInit (unsigned int baseAddress,
    Calendar CalendarTime,
    unsigned int formatSelect);

extern Calendar RTC_C_getCalendarTime (unsigned int baseAddress);

extern void RTC_C_setCalendarAlarm (unsigned int baseAddress,
    unsigned char minutesAlarm,
    unsigned char hoursAlarm,
    unsigned char dayOfWeekAlarm,
    unsigned char dayOfMonthAlarm);

extern void RTC_C_setCalendarEvent (unsigned int baseAddress,
    unsigned int eventSelect);

extern void RTC_C_definePrescaleEvent (unsigned int baseAddress,
    unsigned char prescaleSelect,
    unsigned char prescaleEventDivider);

extern unsigned char RTC_C_getPrescaleValue (unsigned int baseAddress,
    unsigned char prescaleSelect);

extern void RTC_C_setPrescaleValue (unsigned int baseAddress,
    unsigned char prescaleSelect,
    unsigned char prescaleCounterValue);

extern void RTC_C_enableInterrupt (unsigned int baseAddress,
    unsigned char interruptMask);

extern void RTC_C_disableInterrupt (unsigned int baseAddress,
    unsigned char interruptMask);

extern unsigned char RTC_C_getInterruptStatus (unsigned int baseAddress,
    unsigned char interruptFlagMask);

extern void RTC_C_clearInterrupt (unsigned int baseAddress,
    unsigned char interruptFlagMask);

extern unsigned int RTC_C_convertBCDToBinary (unsigned int baseAddressu,
    unsigned int valueToConvert);

extern unsigned int RTC_C_convertBinaryToBCD (unsigned int baseAddress,
    unsigned int valueToConvert);

#endif
