#ifndef __MSP430WARE_USCI_I2C_H__
#define __MSP430WARE_USCI_I2C_H__

//*****************************************************************************
//
//The following are the defines to include the required modules for this
//peripheral in msp430xgeneric.h file
//
//*****************************************************************************
#define __MSP430_HAS_USCI_Bx__

//*****************************************************************************
//
//The following are values that can be passed to the USCI_I2C_masterInit() API
//as the selectClockSource parameter.
//
//*****************************************************************************
#define USCI_I2C_CLOCKSOURCE_ACLK    UCSSEL__ACLK
#define USCI_I2C_CLOCKSOURCE_SMCLK   UCSSEL__SMCLK

//*****************************************************************************
//
//The following are values that can be passed to the USCI_I2C_enableInterrupt(),
//USCI_I2C_disableInterrupt(), USCI_I2C_clearInterrupt(), USCI_I2C_getInterruptStatus(), API
//as the mask parameter.
//
//*****************************************************************************
#define USCI_I2C_NAK_INTERRUPT                UCNACKIE
#define USCI_I2C_ARBITRATIONLOST_INTERRUPT    UCALIE
#define USCI_I2C_STOP_INTERRUPT               UCSTPIE
#define USCI_I2C_START_INTERRUPT              UCSTTIE
#define USCI_I2C_TRANSMIT_INTERRUPT           UCTXIE
#define USCI_I2C_RECEIVE_INTERRUPT            UCRXIE

//*****************************************************************************
//
//The following are values that can be passed to the USCI_I2C_masterInit() API
//as the dataRate parameter.
//
//*****************************************************************************
#define USCI_I2C_SET_DATA_RATE_400KBPS             400000
#define USCI_I2C_SET_DATA_RATE_100KBPS             100000

//*****************************************************************************
//
//The following are values that is returned by the USCI_I2C_isBusy()  and
//USCI_I2C_isBusBusy() API
//
//*****************************************************************************
#define USCI_I2C_BUS_BUSY     UCBBUSY
#define USCI_I2C_BUS_NOT_BUSY 0x00

//*****************************************************************************
//
//The following are values that can be returned by the USCI_I2C_masterIsSTOPSent()
//API
//
//*****************************************************************************

#define USCI_I2C_SENDING_STOP		UCTXSTP
#define USCI_I2C_STOP_SEND_COMPLETE	0x00

//*****************************************************************************
//
//The following are values that can be passed to the USCI_I2C_setMode() API
//as the mode parameter.
//
//*****************************************************************************
#define USCI_I2C_TRANSMIT_MODE       UCTR
#define USCI_I2C_RECEIVE_MODE        0x00

//*****************************************************************************
//
//Prototypes for the APIs.
//
//*****************************************************************************
extern void USCI_I2C_masterInit (unsigned int baseAddress,
    unsigned char selectClockSource,
    unsigned long i2cClk,
    unsigned long dataRate);
extern void USCI_I2C_slaveInit (unsigned int baseAddress,
    unsigned char slaveAddress
    );
extern void USCI_I2C_enable (unsigned int baseAddress);
extern void USCI_I2C_disable (unsigned int baseAddress);
extern void USCI_I2C_setSlaveAddress (unsigned int baseAddress,
    unsigned char slaveAddress
    );
extern void USCI_I2C_setMode (unsigned int baseAddress,
    unsigned char mode
    );
extern void USCI_I2C_slaveDataPut (unsigned int baseAddress,
    unsigned char transmitData
    );
extern unsigned char USCI_I2C_slaveDataGet (unsigned int baseAddress);
extern unsigned char USCI_I2C_isBusBusy (unsigned int baseAddress);
extern unsigned char USCI_I2C_isBusy (unsigned int baseAddress);
extern void USCI_I2C_enableInterrupt (unsigned int baseAddress,
    unsigned char mask
    );
extern void USCI_I2C_disableInterrupt (unsigned int baseAddress,
    unsigned char mask
    );
extern void USCI_I2C_clearInterruptFlag (unsigned int baseAddress,
    unsigned char mask
    );
extern unsigned char USCI_I2C_getInterruptStatus (unsigned int baseAddress,
    unsigned char mask
    );
extern void USCI_I2C_masterSendSingleByte (unsigned int baseAddress,
    unsigned char txData
    );
extern unsigned short USCI_I2C_masterSendSingleByteWithTimeout (unsigned int baseAddress,
    unsigned char txData,
    unsigned long timeout
    );
extern void USCI_I2C_masterMultiByteSendStart (unsigned int baseAddress,
    unsigned char txData
    );
extern unsigned short USCI_I2C_masterMultiByteSendStartWithTimeout (unsigned int baseAddress,
    unsigned char txData, 
    unsigned long timeout
    ); 
extern void USCI_I2C_masterMultiByteSendNext (unsigned int baseAddress,
    unsigned char txData
    );
extern unsigned short USCI_I2C_masterMultiByteSendNextWithTimeout (unsigned int baseAddress,
    unsigned char txData, 
    unsigned long timeout
    );
extern void USCI_I2C_masterMultiByteSendFinish (unsigned int baseAddress,
    unsigned char txData
    );
extern unsigned short USCI_I2C_masterMultiByteReceiveFinishWithTimeout (unsigned int baseAddress,
	unsigned char *txData,
    unsigned long timeout
    );
extern void USCI_I2C_masterMultiByteSendStop (unsigned int baseAddress);
extern unsigned short USCI_I2C_masterMultiByteSendStopWithTimeout (unsigned int baseAddress, 
	unsigned long timeout);
extern void USCI_I2C_masterMultiByteReceiveStart (unsigned int baseAddress);
extern unsigned char USCI_I2C_masterMultiByteReceiveNext (unsigned int baseAddress);
extern unsigned char USCI_I2C_masterMultiByteReceiveFinish (
    unsigned int baseAddress
    );
extern void USCI_I2C_masterMultiByteReceiveStop (unsigned int baseAddress);
extern void USCI_I2C_masterSingleReceiveStart (unsigned int baseAddress);
extern unsigned short USCI_I2C_masterSingleReceiveStartWithTimeout (unsigned int baseAddress,
	unsigned long timeout
	);
extern unsigned char USCI_I2C_masterSingleReceive (unsigned int baseAddress);
extern unsigned long USCI_I2C_getReceiveBufferAddressForDMA (
    unsigned int baseAddress
    );
extern unsigned long USCI_I2C_getTransmitBufferAddressForDMA (
    unsigned int baseAddress
    );
extern unsigned char USCI_I2C_masterIsSTOPSent (unsigned int baseAddress);
extern void USCI_I2C_masterSendStart (unsigned int baseAddress);
#endif
