#ifndef __MSP430WARE_USCI_SPI_H__
#define __MSP430WARE_USCI_SPI_H__

//*****************************************************************************
//
//The following are the defines to include the required modules for this
//peripheral in msp430xgeneric.h file
//
//*****************************************************************************
#define __MSP430_HAS_USCI_Ax__

//*****************************************************************************
//
//The following are values that can be passed to the USCI_SPI_masterInit() API
//as the selectClockSource parameter.
//
//*****************************************************************************
#define USCI_SPI_CLOCKSOURCE_ACLK    UCSSEL__ACLK
#define USCI_SPI_CLOCKSOURCE_SMCLK   UCSSEL__SMCLK

//*****************************************************************************
//
//The following are values that can be passed to the USCI_SPI_masterInit() ,
//USCI_SPI_slaveInit() API as the msbFirst parameter.
//
//*****************************************************************************
#define USCI_SPI_MSB_FIRST    UCMSB
#define USCI_SPI_LSB_FIRST    0x00

//*****************************************************************************
//
//The following are values that can be returned by the USCI_SPI_isBusy() API
//
//*****************************************************************************
#define USCI_SPI_BUSY        UCBUSY
#define USCI_SPI_NOT_BUSY    0x00

//*****************************************************************************
//
//The following are values that can be passed to the USCI_SPI_masterInit() ,
//USCI_SPI_slaveInit() API as the clockPhase parameter.
//
//*****************************************************************************
#define USCI_SPI_PHASE_DATA_CHANGED_ONFIRST_CAPTURED_ON_NEXT    0x00
#define USCI_SPI_PHASE_DATA_CAPTURED_ONFIRST_CHANGED_ON_NEXT    UCCKPH

//*****************************************************************************
//
//The following are values that can be passed to the USCI_SPI_masterInit() ,
//USCI_SPI_slaveInit() API as the clockPolarity parameter.
//
//*****************************************************************************
#define USCI_SPI_CLOCKPOLARITY_INACTIVITY_HIGH    UCCKPL
#define USCI_SPI_CLOCKPOLARITY_INACTIVITY_LOW     0x00

//*****************************************************************************
//
//The following are values that can be passed to the USCI_SPI_enableInterrupt() ,
//USCI_SPI_disableInterrupt(), USCI_SPI_getInterruptStatus(),  API as the mask parameter.
//
//*****************************************************************************
#define USCI_SPI_TRANSMIT_INTERRUPT    UCTXIE
#define USCI_SPI_RECEIVE_INTERRUPT     UCRXIE

//*****************************************************************************
//
//Prototypes for the APIs.
//
//*****************************************************************************
extern unsigned short USCI_SPI_masterInit (unsigned int baseAddress,
    unsigned char selectClockSource,
    unsigned long clockSourceFrequency,
    unsigned long desiredSpiClock,
    unsigned char msbFirst,
    unsigned char clockPhase,
    unsigned char clockPolarity
    );
extern void USCI_SPI_masterChangeClock (unsigned int baseAddress,
    unsigned long clockSourceFrequency,
    unsigned long desiredSpiClock
    );

extern unsigned short USCI_SPI_slaveInit (unsigned int baseAddress,
    unsigned char msbFirst,
    unsigned char clockPhase,
    unsigned char clockPolarity
    );
extern void USCI_SPI_changeClockPhasePolarity (unsigned int baseAddress,
    unsigned char clockPhase,
    unsigned char clockPolarity
    );
extern void USCI_SPI_transmitData ( unsigned int baseAddress,
    unsigned char transmitData
    );

extern unsigned char USCI_SPI_receiveData (unsigned int baseAddress);
extern void USCI_SPI_enableInterrupt (unsigned int baseAddress,
    unsigned char mask
    );
extern void USCI_SPI_disableInterrupt (unsigned int baseAddress,
    unsigned char mask
    );
extern unsigned char USCI_SPI_getInterruptStatus (unsigned int baseAddress,
    unsigned char mask
    );
extern void USCI_SPI_enable (unsigned int baseAddress);
extern void USCI_SPI_disable (unsigned int baseAddress);
extern unsigned long USCI_SPI_getReceiveBufferAddressForDMA
    (unsigned int baseAddress);
extern unsigned long USCI_SPI_getTransmitBufferAddressForDMA
    (unsigned int baseAddress);
extern unsigned char USCI_SPI_isBusy (unsigned int baseAddress);
extern void USCI_SPI_clearInterruptFlag (unsigned int baseAddress,
    unsigned char mask
    );
#endif

