#ifndef __MSP430WARE_USCI_UART_H__
#define __MSP430WARE_USCI_UART_H__

//*****************************************************************************
//
//The following are the defines to include the required modules for this
//peripheral in msp430xgeneric.h file
//
//*****************************************************************************
#define __MSP430_HAS_USCI_Ax__

//*****************************************************************************
//
//The following are values that can be passed to the USCI_UART_init() API
//as the parity parameter.
//
//*****************************************************************************
#define USCI_UART_NO_PARITY   0x00
#define USCI_UART_ODD_PARITY  0x01
#define USCI_UART_EVEN_PARITY 0x02

//*****************************************************************************
//
//The following are values that can be passed to the USCI_UART_init() API
//as the selectClockSource parameter.
//
//*****************************************************************************
#define USCI_UART_CLOCKSOURCE_ACLK    UCSSEL__ACLK
#define USCI_UART_CLOCKSOURCE_SMCLK   UCSSEL__SMCLK

//*****************************************************************************

//*****************************************************************************
//
//The following are values that can be passed to the USCI_UART_init() API
//as the numberofStopBits parameter.
//
//*****************************************************************************
#define USCI_UART_ONE_STOP_BIT    0x00
#define USCI_UART_TWO_STOP_BITS   UCSPB


//*****************************************************************************
//
//The following are values that can be passed to the USCI_UART_init() API
//as the msborLsbFirst parameter.
//
//*****************************************************************************
#define USCI_UART_MSB_FIRST    UCMSB
#define USCI_UART_LSB_FIRST    0x00

//*****************************************************************************
//
//The following are values that can be passed to the USCI_UART_getInterruptStatus(),
//as the mask parameter.
//
//*****************************************************************************
#define USCI_UART_RECEIVE_INTERRUPT_FLAG            UCRXIFG
#define USCI_UART_TRANSMIT_INTERRUPT_FLAG           UCTXIFG

//*****************************************************************************
//
//The following are values that can be passed to the USCI_UART_enableInterrupt(),
//USCI_UART_disableInterrupt() API as the mask parameter.
//
//*****************************************************************************
#define USCI_UART_RECEIVE_INTERRUPT                  UCRXIE
#define USCI_UART_TRANSMIT_INTERRUPT                 UCTXIE
#define USCI_UART_RECEIVE_ERRONEOUSCHAR_INTERRUPT    UCRXEIE
#define USCI_UART_BREAKCHAR_INTERRUPT                UCBRKIE

//*****************************************************************************
//
//The following are values that can be passed to the USCI_UART_queryStatusFlags()
//API as the mask parameter.
//
//*****************************************************************************
#define USCI_UART_LISTEN_ENABLE      UCLISTEN
#define USCI_UART_FRAMING_ERROR      UCFE
#define USCI_UART_OVERRUN_ERROR      UCOE
#define USCI_UART_PARITY_ERROR       UCPE
#define UARTBREAK_DETECT        UCBRK
#define USCI_UART_RECEIVE_ERROR      UCRXERR
#define USCI_UART_ADDRESS_RECEIVED   UCADDR
#define USCI_UART_IDLELINE           UCIDLE
#define USCI_UART_BUSY               UCBUSY

//*****************************************************************************
//
//The following are values that can be passed to the USCI_UART_init()
//API as the mode parameter.
//
//*****************************************************************************
#define USCI_UART_MODE                              UCMODE_0
#define USCI_UART_IDLE_LINE_MULTI_PROCESSOR_MODE    UCMODE_1
#define USCI_UART_ADDRESS_BIT_MULTI_PROCESSOR_MODE  UCMODE_2
#define USCI_UART_AUTOMATIC_BAUDRATE_DETECTION_MODE UCMODE_3

//*****************************************************************************
//
//The following are values that can be passed to the USCI_UART_init()
//API as the overSampling parameter.
//
//*****************************************************************************
#define USCI_UART_OVERSAMPLING_BAUDRATE_GENERATION     0x01
#define USCI_UART_LOW_FREQUENCY_BAUDRATE_GENERATION    0x00


//*****************************************************************************
//
//The following are values are the sync characters possible
//
//*****************************************************************************
#define DEFAULT_SYNC 0x00
#define USCI_UART_AUTOMATICBAUDRATE_SYNC 0x55

//*****************************************************************************
//
//Prototypes for the APIs.
//
//*****************************************************************************
extern
unsigned short USCI_UART_init ( unsigned int baseAddress,
    unsigned char selectClockSource,
    unsigned long clockSourceFrequency,
    unsigned long desiredUartBaudRate,
    unsigned char parity,
    unsigned char msborLsbFirst,
    unsigned char numberofStopBits,
    unsigned char uartMode,
    unsigned short overSampling
    );
extern
unsigned short USCI_UART_initAdvance ( unsigned int baseAddress,
    unsigned char selectClockSource,
    unsigned int clockPrescalar,
    unsigned char firstModReg,
    unsigned char secondModReg,
    unsigned char parity,
    unsigned char msborLsbFirst,
    unsigned char numberofStopBits,
    unsigned char uartMode,
    unsigned short overSampling
    );
extern
void USCI_UART_transmitData ( unsigned int baseAddress,
    unsigned char transmitData
    );
extern
unsigned char USCI_UART_receiveData (unsigned int baseAddress);
extern
void USCI_UART_enableInterrupt (unsigned int baseAddress,
    unsigned char mask
    );
extern
void USCI_UART_disableInterrupt (unsigned int baseAddress,
    unsigned char mask
    );
extern
unsigned char USCI_UART_getInterruptStatus (unsigned int baseAddress,
    unsigned char mask
    );
extern
void USCI_UART_clearInterruptFlag (unsigned int baseAddress,
    unsigned char mask
    );
extern
void USCI_UART_enable (unsigned int baseAddress);
extern
void USCI_UART_disable (unsigned int baseAddress);
extern
unsigned char USCI_UART_queryStatusFlags (unsigned int baseAddress,
    unsigned char mask);
extern
void USCI_UART_setDormant (unsigned int baseAddress);
extern
void USCI_UART_resetDormant (unsigned int baseAddress);
extern
void USCI_UART_transmitAddress (unsigned int baseAddress,
    unsigned char transmitAddress);
extern
void USCI_UART_transmitBreak (unsigned int baseAddress);
extern
unsigned long USCI_UART_getReceiveBufferAddressForDMA (unsigned int baseAddress);
extern
unsigned long USCI_UART_getTransmitBufferAddressForDMA (unsigned int baseAddress);
#endif
