#ifndef __MSP430WARE_EUSCI_SPI_H__
#define __MSP430WARE_EUSCI_SPI_H__

//*****************************************************************************
//
//The following are the defines to include the required modules for this
//peripheral in msp430xgeneric.h file
//
//*****************************************************************************
#define __MSP430_HAS_EUSCI_Ax__

//*****************************************************************************
//
//The following are values that can be passed to the SPI_masterInit() API
//as the selectClockSource parameter.
//
//*****************************************************************************
#define EUSCI_SPI_CLOCKSOURCE_ACLK    UCSSEL__ACLK
#define EUSCI_SPI_CLOCKSOURCE_SMCLK   UCSSEL__SMCLK

//*****************************************************************************
//
//The following are values that can be passed to the EUSCI_SPI_masterInit() ,
//EUSCI_SPI_slaveInit() API as the msbFirst parameter.
//
//*****************************************************************************
#define EUSCI_SPI_MSB_FIRST    UCMSB
#define EUSCI_SPI_LSB_FIRST    0x00

//*****************************************************************************
//
//The following are values that can be returned by the EUSCI_SPI_isBusy() API
//
//*****************************************************************************
#define EUSCI_SPI_BUSY        UCBUSY
#define EUSCI_SPI_NOT_BUSY    0x00

//*****************************************************************************
//
//The following are values that can be passed to the EUSCI_SPI_masterInit() ,
//EUSCI_SPI_slaveInit() API as the clockPhase parameter.
//
//*****************************************************************************
#define EUSCI_SPI_PHASE_DATA_CHANGED_ONFIRST_CAPTURED_ON_NEXT    0x00
#define EUSCI_SPI_PHASE_DATA_CAPTURED_ONFIRST_CHANGED_ON_NEXT    UCCKPH

//*****************************************************************************
//
//The following are values that can be passed to the EUSCI_SPI_masterInit() ,
//EUSCI_SPI_slaveInit as the spiMode parameter.
//
//*****************************************************************************
#define EUSCI_SPI_3PIN                      UCMODE_0
#define EUSCI_SPI_4PIN_UCxSTE_ACTIVE_HIGH   UCMODE_1
#define EUSCI_SPI_4PIN_UCxSTE_ACTIVE_LOW    UCMODE_2

//*****************************************************************************
//
//The following are values that can be passed to the EUSCI_SPI_masterInit() ,
//EUSCI_SPI_slaveInit() API as the clockPolarity parameter.
//
//*****************************************************************************
#define EUSCI_SPI_CLOCKPOLARITY_INACTIVITY_HIGH    UCCKPL
#define EUSCI_SPI_CLOCKPOLARITY_INACTIVITY_LOW     0x00

//*****************************************************************************
//
//The following are values that can be passed to the EUSCI_SPI_enableInterrupt() ,
//EUSCI_SPI_disableInterrupt(), EUSCI_SPI_getInterruptStatus(),  API as the mask parameter.
//
//*****************************************************************************
#define EUSCI_SPI_TRANSMIT_INTERRUPT    UCTXIE
#define EUSCI_SPI_RECEIVE_INTERRUPT     UCRXIE

//*****************************************************************************
//
//The following are values that can be passed to the 
//EUSCI_SPI_select4PinFunctionality() API as the select4PinFunctionality parameter.
//
//*****************************************************************************
#define EUSCI_SPI_ENABLE_SIGNAL_FOR_4WIRE_SLAVE			UCSTEM
#define EUSCI_SPI_PREVENT_CONFLICTS_WITH_OTHER_MASTERS	0x00

//*****************************************************************************
//
//Prototypes for the APIs.
//
//*****************************************************************************
extern unsigned short EUSCI_SPI_masterInit (unsigned int baseAddress,
    unsigned char selectClockSource,
    unsigned long clockSourceFrequency,
    unsigned long desiredSpiClock,
    unsigned int msbFirst,
    unsigned int clockPhase,
    unsigned int clockPolarity,
    unsigned int spiMode
    );
extern void EUSCI_SPI_select4PinFunctionality (unsigned int baseAddress,
    unsigned char select4PinFunctionality
    );
extern void EUSCI_SPI_masterChangeClock (unsigned int baseAddress,
    unsigned long clockSourceFrequency,
    unsigned long desiredSpiClock
    );

extern unsigned short EUSCI_SPI_slaveInit (unsigned int baseAddress,
    unsigned int msbFirst,
    unsigned int clockPhase,
    unsigned int clockPolarity,
	unsigned int spiMode
    );
extern void EUSCI_SPI_changeClockPhasePolarity (unsigned int baseAddress,
    unsigned int clockPhase,
    unsigned int clockPolarity
    );
extern void EUSCI_SPI_transmitData ( unsigned int baseAddress,
    unsigned char transmitData
    );

extern unsigned char EUSCI_SPI_receiveData (unsigned int baseAddress);
extern void EUSCI_SPI_enableInterrupt (unsigned int baseAddress,
    unsigned char mask
    );
extern void EUSCI_SPI_disableInterrupt (unsigned int baseAddress,
    unsigned char mask
    );
extern unsigned char EUSCI_SPI_getInterruptStatus (unsigned int baseAddress,
    unsigned char mask
    );
extern void EUSCI_SPI_enable (unsigned int baseAddress);
extern void EUSCI_SPI_disable (unsigned int baseAddress);
extern unsigned long EUSCI_SPI_getReceiveBufferAddressForDMA
    (unsigned int baseAddress);
extern unsigned long EUSCI_SPI_getTransmitBufferAddressForDMA
    (unsigned int baseAddress);
extern unsigned char EUSCI_SPI_isBusy (unsigned int baseAddress);
extern void EUSCI_SPI_clearInterruptFlag (unsigned int baseAddress,
    unsigned char mask
    );
#endif

