#ifndef __MSP430WARE_MPU_H__
#define __MSP430WARE_MPU_H__

//*****************************************************************************
//
//The following are the defines to include the required modules for this
//peripheral in msp430xgeneric.h file
//
//*****************************************************************************
#define __MSP430_HAS_MPU__

//*****************************************************************************
//
//The following are values that can be passed to the MPU_createTwoSegments()
//and MPU_createThreeSegments  function as the seg1accmask, seg2accmask and
//seg3accmask parameter.
//
//*****************************************************************************

#define MPU_READ		MPUSEG1RE
#define MPU_WRITE		MPUSEG1WE
#define MPU_EXEC		MPUSEG1XE

//*****************************************************************************
//
//The following are values that can be passed to the MPU_createPUConViolation()
//function as the segment parameter.
//
//*****************************************************************************
#define MPU_FIRST_SEG		MPUSEG1VS
#define MPU_SECOND_SEG		MPUSEG2VS
#define MPU_THIRD_SEG		MPUSEG3VS


//*****************************************************************************
//
//The following values are used to by createTwoSegments, createThreeSegments
//to check the user has passed a valid segmentation value. This value was
//obtained from the User's Guide
//
//*****************************************************************************
#define MPU_MAX_SEG_VALUE			0x20

#define MPU_SEG_1_ACCESS_VIOLATION 		MPUSEG1IFG
#define MPU_SEG_2_ACCESS_VIOLATION 		MPUSEG2IFG
#define MPU_SEG_3_ACCESS_VIOLATION 		MPUSEG3IFG

//*****************************************************************************
//
//Prototypes for the APIs.
//
//*****************************************************************************
extern void
MPU_createTwoSegments
(	unsigned int baseAddress,
	unsigned int seg2boundary,
	unsigned char seg1accmask,
	unsigned char seg2accmask
	);

extern void
MPU_createThreeSegments
(	unsigned int baseAddress,
	unsigned int seg1boundary,
	unsigned int seg2boundary,
	unsigned char seg1accmask,
	unsigned char seg2accmask,
	unsigned char seg3accmask
	);

extern void
MPU_start
(	unsigned int baseAddress
	);

extern void
MPU_enablePUCOnViolation
(	unsigned int baseAddress,
	unsigned int segment
	);

extern
void
MPU_disablePUCOnViolation(unsigned int baseAddress,
		unsigned int segment
		);

extern unsigned short
MPU_getInterruptStatus
(	unsigned int baseAddress,
	unsigned int memAccFlag
	);

extern unsigned short
MPU_clearInterruptFlag
(	unsigned int baseAddress,
	unsigned int memAccFlag
	);

unsigned short
MPU_clearAllInterruptFlags
(	unsigned int baseAddress
	);

#endif
