#ifndef __MSP430WARE_RTC_B_H__
#define __MSP430WARE_RTC_B_H__

//*****************************************************************************
//
//The following are the defines to include the required modules for this
//peripheral in msp430xgeneric.h file
//
//*****************************************************************************
#define __MSP430_HAS_RTC_B__

//*****************************************************************************
//
//The following is a struct that can be passed to RTC_B_CalendarInit() in the
//CalendarTime parameter, as well as returned by RTC_B_getCalendarTime()
//
//*****************************************************************************
typedef struct {
    unsigned char Seconds;
    unsigned char Minutes;
    unsigned char Hours;
    unsigned char DayOfWeek;
    unsigned char DayOfMonth;
    unsigned char Month;
    unsigned int Year;
} Calendar;

//*****************************************************************************
//
//The following are values that can be passed to RTC_B_setCalibrationData()
//in the offsetDirection parameter.
//
//*****************************************************************************
#define RTC_B_CALIBRATIONFREQ_OFF   (RTCCALF_0)
#define RTC_B_CALIBRATIONFREQ_512HZ (RTCCALF_1)
#define RTC_B_CALIBRATIONFREQ_256HZ (RTCCALF_2)
#define RTC_B_CALIBRATIONFREQ_1HZ   (RTCCALF_3)

//*****************************************************************************
//
//The following are values that can be passed to RTC_B_setCalibrationData()
//in the offsetDirection parameter.
//
//*****************************************************************************
#define RTC_B_CALIBRATION_DOWN2PPM  ( !(RTCCALS) )
#define RTC_B_CALIBRATION_UP4PPM    (RTCCALS)

//*****************************************************************************
//
//The following are values that can be passed to RTC_B_setClockRegistersFormat()
//in the formatSelect parameter.
//
//*****************************************************************************
#define RTC_B_FORMAT_BINARY  ( !(RTCBCD) )
#define RTC_B_FORMAT_BCD     (RTCBCD)

//*****************************************************************************
//
//The following is a value that can be passed to RTC_B_setCalendarAlarm() in the
//minutesAlarm, hoursAlarm, dayOfWeekAlarm, and dayOfMonthAlarm parameters.
//
//*****************************************************************************
#define RTC_B_ALARMCONDITION_OFF  (0x80)

//*****************************************************************************
//
//The following are values that can be passed to RTC_B_setCalendarEvent()
//in the eventSelect parameter.
//
//*****************************************************************************
#define RTC_B_CALENDAREVENT_MINUTECHANGE  (RTCTEV_0)
#define RTC_B_CALENDAREVENT_HOURCHANGE    (RTCTEV_1)
#define RTC_B_CALENDAREVENT_NOON          (RTCTEV_2)
#define RTC_B_CALENDAREVENT_MIDNIGHT      (RTCTEV_3)

//*****************************************************************************
//
//The following are values that can be passed to RTC_B_counterPrescaleInit(),
//RTC_B_definePreScaleEvent(), RTC_B_readPrescaleCounterValue(), and
//RTC_B_setPrescaleCounterValue() in the prescaleSelect parameter.
//
//*****************************************************************************
#define RTC_B_PRESCALE_0  (0x0)
#define RTC_B_PRESCALE_1  (0x2)

//*****************************************************************************
//The following are values that can be passed to RTC_B_definePrescaleEvent()
//in the prescaleEventDivider parameter.
//
//*****************************************************************************
#define RTC_B_PSEVENTDIVIDER_2   (RT0IP_0)
#define RTC_B_PSEVENTDIVIDER_4   (RT0IP_1)
#define RTC_B_PSEVENTDIVIDER_8   (RT0IP_2)
#define RTC_B_PSEVENTDIVIDER_16  (RT0IP_3)
#define RTC_B_PSEVENTDIVIDER_32  (RT0IP_4)
#define RTC_B_PSEVENTDIVIDER_64  (RT0IP_5)
#define RTC_B_PSEVENTDIVIDER_128 (RT0IP_6)
#define RTC_B_PSEVENTDIVIDER_256 (RT0IP_7)

//*****************************************************************************
//
//The following are values that can be passed to RTC_B_getInterruptStatus(),
//RTC_B_clearInterrupt(), RTC_B_enableInterrupt(),  RTC_B_disableInterrupt()
//in the interruptFlagMask parameter.
//
//*****************************************************************************
#define RTC_B_OSCILLATOR_FAULT_INTERRUPT  RTCOFIE   
#define RTC_B_TIME_EVENT_INTERRUPT        RTCTEVIE  
#define RTC_B_CLOCK_ALARM_INTERRUPT       RTCAIE    
#define RTC_B_CLOCK_READ_READY_INTERRUPT  RTCRDYIE  
#define RTC_B_PRESCALE_TIMER0_INTERRUPT   0x02
#define RTC_B_PRESCALE_TIMER1_INTERRUPT   0x01


//*****************************************************************************
//
//Prototypes for the APIs.
//
//*****************************************************************************
extern void RTC_B_startClock (unsigned int baseAddress);

extern void RTC_B_holdClock (unsigned int baseAddress);

extern void RTC_B_setCalibrationFrequency (unsigned int baseAddress,
    unsigned int frequencySelect);

extern void RTC_B_setCalibrationData (unsigned int baseAddress,
    unsigned char offsetDirection,
    unsigned char offsetValue);

extern void RTC_B_calendarInit (unsigned int baseAddress,
    Calendar CalendarTime,
    unsigned int formatSelect);

extern Calendar RTC_B_getCalendarTime (unsigned int baseAddress);

extern void RTC_B_setCalendarAlarm (unsigned int baseAddress,
    unsigned char minutesAlarm,
    unsigned char hoursAlarm,
    unsigned char dayOfWeekAlarm,
    unsigned char dayOfMonthAlarm);

extern void RTC_B_setCalendarEvent (unsigned int baseAddress,
    unsigned int eventSelect);

extern void RTC_B_definePrescaleEvent (unsigned int baseAddress,
    unsigned char prescaleSelect,
    unsigned char prescaleEventDivider);

extern unsigned char RTC_B_getPrescaleValue (unsigned int baseAddress,
    unsigned char prescaleSelect);

extern void RTC_B_setPrescaleValue (unsigned int baseAddress,
    unsigned char prescaleSelect,
    unsigned char prescaleCounterValue);

extern void RTC_B_enableInterrupt (unsigned int baseAddress,
    unsigned char interruptMask);

extern void RTC_B_disableInterrupt (unsigned int baseAddress,
    unsigned char interruptMask);

extern unsigned char RTC_B_getInterruptStatus (unsigned int baseAddress,
    unsigned char interruptFlagMask);

extern void RTC_B_clearInterrupt (unsigned int baseAddress,
    unsigned char interruptFlagMask);

extern unsigned int RTC_B_convertBCDToBinary (unsigned int baseAddressu,
    unsigned int valueToConvert);

extern unsigned int RTC_B_convertBinaryToBCD (unsigned int baseAddress,
    unsigned int valueToConvert);

#endif
