#ifndef __MSP430WARE_SFR_H__
#define __MSP430WARE_SFR_H__

//*****************************************************************************
//
//The following are the defines to include the required modules for this
//peripheral in msp430xgeneric.h file
//
//*****************************************************************************
#define __MSP430_HAS_SFR__

//*****************************************************************************
//
//The following are values that can be passed to SFR_setResetPinPullResistor()
//in the pullResistorSetup parameter.
//
//*****************************************************************************
#define SFR_RESISTORDISABLE         ( !(SYSRSTRE + SYSRSTUP) )
#define SFR_RESISTORENABLE_PULLUP   ( SYSRSTRE + SYSRSTUP )
#define SFR_RESISTORENABLE_PULLDOWN (SYSRSTRE)

//*****************************************************************************
//
//The following are values that can be passed to SFR_setNMIEdge()
//in the edgeDirection parameter.
//
//*****************************************************************************
#define SFR_NMI_RISINGEDGE  ( !(SYSNMIIES) )
#define SFR_NMI_FALLINGEDGE (SYSNMIIES)

//*****************************************************************************
//
//The following are values that can be passed to SFR_setResetNMIPinFunction()
//in the resetPinFunction parameter.
//
//*****************************************************************************
#define SFR_RESETPINFUNC_RESET ( !(SYSNMI) )
#define SFR_RESETPINFUNC_NMI   (SYSNMI)

//******************************************************************************
//
//The following are values that can be passed to 
//SFR_enableInterrupt(), SFR_disableInterrupt(), SFR_getInterruptStatus(),
//SFR_clearInterrupt() in the outboxSelect parameter.
//
//******************************************************************************
#define SFR_JTAG_OUTBOX_INTERRUPT                         JMBOUTIE
#define SFR_JTAG_INBOX_INTERRUPT                          JMBINIE
#define SFR_NMI_PIN_INTERRUPT                             NMIIE
#define SFR_VACANT_MEMORY_ACCESS_INTERRUPT                VMAIE
#define SFR_OSCILLATOR_FAULT_INTERRUPT                    OFIE
#define SFR_WATCHDOG_INTERVAL_TIMER_INTERRUPT             WDTIE

//*****************************************************************************
//
//Prototypes for the APIs.
//
//*****************************************************************************

extern void SFR_enableInterrupt (unsigned int baseAddress,
    unsigned char interruptMask);

extern void SFR_disableInterrupt (unsigned int baseAddress,
    unsigned char interruptMask);

extern unsigned char SFR_getInterruptStatus (unsigned int baseAddress,
    unsigned char interruptFlagMask);

extern void SFR_clearInterrupt (unsigned int baseAddress,
    unsigned char interruptFlagMask);

extern void SFR_setResetPinPullResistor (unsigned int baseAddress,
    unsigned int pullResistorSetup);

extern void SFR_setNMIEdge (unsigned int baseAddress,
    unsigned int edgeDirection);

extern void SFR_setResetNMIPinFunction (unsigned int baseAddress,
    unsigned char resetPinFunction);

#endif
