//*****************************************************************************
//
//gpio.c - Driver for the DIgital I/O Module.
//
//*****************************************************************************
#include "inc/hw_types.h"
#include "debug.h"
#include "gpio.h"
#ifdef  __IAR_SYSTEMS_ICC__
#include "deprecated/IAR/msp430xgeneric.h"
#else
#include "deprecated/CCS/msp430xgeneric.h"
#endif

#include "inc/hw_memmap.h"

unsigned int GPIO_getBaseAddress(unsigned char selectedPort)
{
	unsigned int baseAddress = 0xFFFF;
	switch (selectedPort){
	
#ifdef __MSP430_HAS_PORT1_R__
		case GPIO_PORT_P1: baseAddress = __MSP430_BASEADDRESS_PORT1_R__; break;
#endif		
#ifdef __MSP430_HAS_PORT2_R__
		case GPIO_PORT_P2: baseAddress = __MSP430_BASEADDRESS_PORT2_R__; break;
#endif		
#ifdef __MSP430_HAS_PORT3_R__
		case GPIO_PORT_P3: baseAddress = __MSP430_BASEADDRESS_PORT3_R__; break;
#endif			
#ifdef __MSP430_HAS_PORT4_R__	
		case GPIO_PORT_P4: baseAddress = __MSP430_BASEADDRESS_PORT4_R__; break;
#endif			
#ifdef __MSP430_HAS_PORT5_R__
		case GPIO_PORT_P5: baseAddress = __MSP430_BASEADDRESS_PORT5_R__; break;
#endif			
#ifdef __MSP430_HAS_PORT6_R__		
		case GPIO_PORT_P6: baseAddress = __MSP430_BASEADDRESS_PORT6_R__; break;
#endif			
#ifdef __MSP430_HAS_PORT7_R__
		case GPIO_PORT_P7: baseAddress = __MSP430_BASEADDRESS_PORT7_R__; break;
#endif			
#ifdef __MSP430_HAS_PORT8_R__
		case GPIO_PORT_P8: baseAddress = __MSP430_BASEADDRESS_PORT8_R__; break;
#endif			
#ifdef __MSP430_HAS_PORT9_R__		
		case GPIO_PORT_P9: baseAddress = __MSP430_BASEADDRESS_PORT9_R__; break;
#endif			
#ifdef __MSP430_HAS_PORT10_R__		
		case GPIO_PORT_P10: baseAddress = __MSP430_BASEADDRESS_PORT10_R__; break;
#endif			
#ifdef __MSP430_HAS_PORT11_R__		
		case GPIO_PORT_P11: baseAddress = __MSP430_BASEADDRESS_PORT11_R__; break;
#endif			
#ifdef __MSP430_HAS_PORTA_R__		
		case GPIO_PORT_PA: baseAddress = __MSP430_BASEADDRESS_PORTA_R__; break;
#endif		
#ifdef __MSP430_HAS_PORTB_R__		
		case GPIO_PORT_PB: baseAddress = __MSP430_BASEADDRESS_PORTB_R__; break;
#endif			
#ifdef __MSP430_HAS_PORTC_R__		
		case GPIO_PORT_PC: baseAddress = __MSP430_BASEADDRESS_PORTC_R__; break;
#endif			
#ifdef __MSP430_HAS_PORTD_R__		
		case GPIO_PORT_PD: baseAddress = __MSP430_BASEADDRESS_PORTD_R__; break;
#endif			
#ifdef __MSP430_HAS_PORTE_R__		
		case GPIO_PORT_PE: baseAddress = __MSP430_BASEADDRESS_PORTE_R__; break;
#endif			
#ifdef __MSP430_HAS_PORTF_R__		
		case GPIO_PORT_PF: baseAddress = __MSP430_BASEADDRESS_PORTF_R__; break;
#endif			
#ifdef __MSP430_HAS_PORTJ_R__		
		case GPIO_PORT_PJ: baseAddress = __MSP430_BASEADDRESS_PORTJ_R__; break;
#endif			
		
	}
	return baseAddress;
}


//*****************************************************************************
//
//! This function configures the selected Pin as output pin
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
///!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxSEL and \b PxDIR.
//!
//! \return None
//
//*****************************************************************************
void GPIO_setAsOutputPin ( 
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}

    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
        	HWREGB(baseAddress + OFS_P1SEL0) &= (unsigned char) ~selectedPins;
        	HWREGB(baseAddress + OFS_P1SEL1) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P1DIR) |= (unsigned char) selectedPins;
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
            HWREGB(baseAddress + OFS_P2SEL0) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P2SEL1) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P2DIR) |= (unsigned char) selectedPins;
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
        	HWREG(baseAddress + OFS_PASEL0) &= ~selectedPins;
        	HWREG(baseAddress + OFS_PASEL1) &= ~selectedPins;
            HWREG(baseAddress + OFS_PADIR) |= selectedPins;
            break;
    }
}

//*****************************************************************************
//
//! This function configures the selected Pin as input pin
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
///!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxSEL, \b PxREN and \b PxDIR.
//! \return None
//
//*****************************************************************************
void GPIO_setAsInputPin (
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}

    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
        	HWREGB(baseAddress + OFS_P1SEL0) &= (unsigned char) ~selectedPins;
        	HWREGB(baseAddress + OFS_P1SEL1) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P1DIR) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P1REN) &= (unsigned char) ~selectedPins;
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
            HWREGB(baseAddress + OFS_P2SEL0) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P2SEL1) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P2DIR) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P2REN) &= (unsigned char) ~selectedPins;
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
        	HWREG(baseAddress + OFS_PASEL0) &= ~selectedPins;
        	HWREG(baseAddress + OFS_PASEL1) &= ~selectedPins;
            HWREG(baseAddress + OFS_PADIR) &= ~selectedPins;
            HWREG(baseAddress + OFS_PAREN) &= ~selectedPins;
            break;
    }
}

//*****************************************************************************
//
//! This function configures the peripheral module function in the output direction
//! for the selected pin for either primary, secondary or ternary module function modes
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! \param mode is the specified mode that the pin should be configured for the module function.
//!             Valid values are:
//!             \b GPIO_PRIMARY_MODULE_FUNCTION
//!             \b GPIO_SECONDARY_MODULE_FUNCTION
//!             \b GPIO_TERNARY_MODULE_FUNCTION
///! Modified registers are \b PxSEL and \b PxDIR.
//!
//! \return None
//
//*****************************************************************************
void GPIO_setAsPeripheralModuleFunctionOutputPin ( 
    unsigned char selectedPort,
    unsigned int selectedPins,
    unsigned char mode
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}
	
    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
        {
        	switch (mode){
				case GPIO_PRIMARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P1SEL0) |= (unsigned char) selectedPins;
		        	HWREGB(baseAddress + OFS_P1SEL1) &= (unsigned char) ~selectedPins;
		            HWREGB(baseAddress + OFS_P1DIR) |= (unsigned char) selectedPins;
		            break;
				case GPIO_SECONDARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P1SEL0) &= (unsigned char) ~selectedPins;
		        	HWREGB(baseAddress + OFS_P1SEL1) |= (unsigned char) selectedPins;
		            HWREGB(baseAddress + OFS_P1DIR) |= (unsigned char) selectedPins;
		            break;
				case GPIO_TERNARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P1SEL0) |= (unsigned char) selectedPins;
		        	HWREGB(baseAddress + OFS_P1SEL1) |= (unsigned char) selectedPins;
		            HWREGB(baseAddress + OFS_P1DIR) |= (unsigned char) selectedPins;
        	}
            break;
        }
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
        {
        	switch (mode){
				case GPIO_PRIMARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P2SEL0) |= (unsigned char) selectedPins;
		        	HWREGB(baseAddress + OFS_P2SEL1) &= (unsigned char) ~selectedPins;
		            HWREGB(baseAddress + OFS_P2DIR) |= (unsigned char) selectedPins;
		            break;
				case GPIO_SECONDARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P2SEL0) &= (unsigned char) ~selectedPins;
		        	HWREGB(baseAddress + OFS_P2SEL1) |= (unsigned char) selectedPins;
		            HWREGB(baseAddress + OFS_P2DIR) |= (unsigned char) selectedPins;
		            break;
				case GPIO_TERNARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P2SEL0) |= (unsigned char) selectedPins;
		        	HWREGB(baseAddress + OFS_P2SEL1) |= (unsigned char) selectedPins;
		            HWREGB(baseAddress + OFS_P2DIR) |= (unsigned char) selectedPins;
        	}
            break;
        }
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
        {
        	switch (mode){
				case GPIO_PRIMARY_MODULE_FUNCTION:
		        	HWREG(baseAddress + OFS_PASEL0) |= selectedPins;
		        	HWREG(baseAddress + OFS_PASEL1) &= ~selectedPins;
		            HWREG(baseAddress + OFS_PADIR) |= selectedPins;
		            break;
				case GPIO_SECONDARY_MODULE_FUNCTION:
		        	HWREG(baseAddress + OFS_PASEL0) &= ~selectedPins;
		        	HWREG(baseAddress + OFS_PASEL1) |= selectedPins;
		            HWREG(baseAddress + OFS_PADIR) |= selectedPins;
		            break;
				case GPIO_TERNARY_MODULE_FUNCTION:
		        	HWREG(baseAddress + OFS_PASEL0) |= selectedPins;
		        	HWREG(baseAddress + OFS_PASEL1) |= selectedPins;
		            HWREG(baseAddress + OFS_PADIR) |= selectedPins;
        	}
            break;
        }
    }
}

//*****************************************************************************
//
//! This function configures the peripheral module function in the input direction
//! for the selected pin for either primary, secondary or ternary module function modes.
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! \param mode is the specified mode that the pin should be configured for the module function.
//!             Valid values are:
//!             \b GPIO_PRIMARY_MODULE_FUNCTION
//!             \b GPIO_SECONDARY_MODULE_FUNCTION
//!             \b GPIO_TERNARY_MODULE_FUNCTION
//! Modified registers are \b PxSEL and \b PxDIR.
//!
//! \return None
//
//*****************************************************************************
void GPIO_setAsPeripheralModuleFunctionInputPin ( 
    unsigned char selectedPort,
    unsigned int selectedPins,
    unsigned char mode
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}

    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
        {
        	switch (mode){
				case GPIO_PRIMARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P1SEL0) |= (unsigned char) selectedPins;
		        	HWREGB(baseAddress + OFS_P1SEL1) &= (unsigned char) ~selectedPins;
		            HWREGB(baseAddress + OFS_P1DIR) &= (unsigned char) ~selectedPins;
		            break;
				case GPIO_SECONDARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P1SEL0) &= (unsigned char) ~selectedPins;
		        	HWREGB(baseAddress + OFS_P1SEL1) |= (unsigned char) selectedPins;
		            HWREGB(baseAddress + OFS_P1DIR) &= (unsigned char) ~selectedPins;
		            break;
				case GPIO_TERNARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P1SEL0) |= (unsigned char) selectedPins;
		        	HWREGB(baseAddress + OFS_P1SEL1) |= (unsigned char) selectedPins;
		            HWREGB(baseAddress + OFS_P1DIR) &= (unsigned char) ~selectedPins;
        	}
            break;
        }
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
        {
        	switch (mode){
				case GPIO_PRIMARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P2SEL0) |= (unsigned char) selectedPins;
		        	HWREGB(baseAddress + OFS_P2SEL1) &= (unsigned char) ~selectedPins;
		            HWREGB(baseAddress + OFS_P2DIR) &= (unsigned char) ~selectedPins;
		            break;
				case GPIO_SECONDARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P2SEL0) &= (unsigned char) ~selectedPins;
		        	HWREGB(baseAddress + OFS_P2SEL1) |= (unsigned char) selectedPins;
		            HWREGB(baseAddress + OFS_P2DIR) &= (unsigned char) ~selectedPins;
		            break;
				case GPIO_TERNARY_MODULE_FUNCTION:
		        	HWREGB(baseAddress + OFS_P2SEL0) |= (unsigned char) selectedPins;
		        	HWREGB(baseAddress + OFS_P2SEL1) |= (unsigned char) selectedPins;
		            HWREGB(baseAddress + OFS_P2DIR) &= (unsigned char) ~selectedPins;
        	}
            break;
        }
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
        {
        	switch (mode){
				case GPIO_PRIMARY_MODULE_FUNCTION:
		        	HWREG(baseAddress + OFS_PASEL0) |= selectedPins;
		        	HWREG(baseAddress + OFS_PASEL1) &= ~selectedPins;
		            HWREG(baseAddress + OFS_PADIR) &= ~selectedPins;
		            break;
				case GPIO_SECONDARY_MODULE_FUNCTION:
		        	HWREG(baseAddress + OFS_PASEL0) &= ~selectedPins;
		        	HWREG(baseAddress + OFS_PASEL1) |= selectedPins;
		            HWREG(baseAddress + OFS_PADIR) &= ~selectedPins;
		            break;
				case GPIO_TERNARY_MODULE_FUNCTION:
		        	HWREG(baseAddress + OFS_PASEL0) |= selectedPins;
		        	HWREG(baseAddress + OFS_PASEL1) |= selectedPins;
		            HWREG(baseAddress + OFS_PADIR) &= ~selectedPins;
        	}
            break;
        }
    }
}

//*****************************************************************************
//
//! This function sets output HIGH on the selected Pin
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxOUT.
//!
//! \return None
//
//*****************************************************************************
void GPIO_setOutputHighOnPin (  
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}

    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
            HWREGB(baseAddress + OFS_P1OUT) |= (unsigned char) selectedPins;
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
            HWREGB(baseAddress + OFS_P2OUT) |= (unsigned char) selectedPins;
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
            HWREG(baseAddress + OFS_PAOUT) |= selectedPins;
            break;
    }
}

//*****************************************************************************
//
//! This function sets output LOW on the selected Pin
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxOUT.
//!
//! \return None
//
//*****************************************************************************
void GPIO_setOutputLowOnPin (  
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}

    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
            HWREGB(baseAddress + OFS_P1OUT) &= (unsigned char) ~selectedPins;
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
            HWREGB(baseAddress + OFS_P2OUT) &= (unsigned char) ~selectedPins;
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
            HWREG(baseAddress + OFS_PAOUT) &= ~selectedPins;
            break;
    }
}

//*****************************************************************************
//
//! This function toggles the output on the selected Pin
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxOUT.
//!
//! \return None
//
//*****************************************************************************
void GPIO_toggleOutputOnPin (  
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}
	
    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
            HWREGB(baseAddress + OFS_P1OUT) ^= (unsigned char) selectedPins;
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
            HWREGB(baseAddress + OFS_P2OUT) ^= (unsigned char) selectedPins;
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
            HWREG(baseAddress + OFS_PAOUT) ^= selectedPins;
            break;
    }
}

//*****************************************************************************
//
//! This function sets the selected Pin in input Mode with Pull Down resistor
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxREN, \b PxOUT and \b PxDIR.
//!
//! \return None
//
//*****************************************************************************
void GPIO_setAsInputPinWithPullDownresistor (  
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}


    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
            HWREGB(baseAddress + OFS_P1SEL0) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P1SEL1) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P1DIR) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P1REN) |= (unsigned char) selectedPins;
            HWREGB(baseAddress + OFS_P1OUT) &= (unsigned char) ~selectedPins;
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
        	HWREGB(baseAddress + OFS_P2SEL0) &= (unsigned char) ~selectedPins;
        	HWREGB(baseAddress + OFS_P2SEL1) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P2DIR) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P2REN) |= (unsigned char) selectedPins;
            HWREGB(baseAddress + OFS_P2OUT) &= (unsigned char) ~selectedPins;
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
        	HWREG(baseAddress + OFS_PASEL0) &= ~selectedPins;
        	HWREG(baseAddress + OFS_PASEL1) &= ~selectedPins;
            HWREG(baseAddress + OFS_PADIR) &= ~selectedPins;
            HWREG(baseAddress + OFS_PAREN) |= selectedPins;
            HWREG(baseAddress + OFS_PAOUT) &= ~selectedPins;
            break;
    }
}

//*****************************************************************************
//
//! This function sets the selected Pin in input Mode with Pull Up resistor
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxREN, \b PxOUT and \b PxDIR.
//!
//! \return None
//
//*****************************************************************************
void GPIO_setAsInputPinWithPullUpresistor (
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}
	
    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
        	HWREGB(baseAddress + OFS_P1SEL0) &= (unsigned char) ~selectedPins;
        	HWREGB(baseAddress + OFS_P1SEL1) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P1DIR) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P1REN) |= (unsigned char) selectedPins;
            HWREGB(baseAddress + OFS_P1OUT) |= (unsigned char) selectedPins;
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
        	HWREGB(baseAddress + OFS_P2SEL0) &= (unsigned char) ~selectedPins;
        	HWREGB(baseAddress + OFS_P2SEL1) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P2DIR) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P2REN) |= (unsigned char) selectedPins;
            HWREGB(baseAddress + OFS_P2OUT) |= (unsigned char) selectedPins;
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
        	HWREG(baseAddress + OFS_PASEL0) &= ~selectedPins;
        	HWREG(baseAddress + OFS_PASEL1) &= ~selectedPins;
            HWREG(baseAddress + OFS_PADIR) &= ~selectedPins;
            HWREG(baseAddress + OFS_PAREN) |= selectedPins;
            HWREG(baseAddress + OFS_PAOUT) |= selectedPins;
            break;
    }
}

//*****************************************************************************
//
//! This function gets the input value on the selected pin
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxIN.
//!
//! \return Input value on Pin - \b GPIO_INPUT_PIN_HIGH,
//!                              \b GPIO_INPUT_PIN_LOW
//
//*****************************************************************************
unsigned short GPIO_getInputPinValue (
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );

    unsigned int inputPinValue = 0;

    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
            inputPinValue = HWREGB(baseAddress + OFS_P1IN) & ((unsigned char) selectedPins);
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
            inputPinValue = HWREGB(baseAddress + OFS_P2IN) & ((unsigned char) selectedPins);
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
            inputPinValue = HWREG(baseAddress + OFS_PAIN) & ((unsigned char) selectedPins);
            break;
    }

    if (inputPinValue > 0){
        return ( GPIO_INPUT_PIN_HIGH) ;
    }
    return ( GPIO_INPUT_PIN_LOW) ;
}

//*****************************************************************************
//
//! This function enables the port interrupt on the selected pin.
//! Note: Not all ports have this capability.  Please refer to the device
//!   specific datasheet.
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxIE.
//!
//! \return None
//
//*****************************************************************************
void GPIO_enableInterrupt (
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}

    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
			HWREGB(baseAddress + OFS_P1IFG) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P1IE) |= (unsigned char) selectedPins;
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
			HWREGB(baseAddress + OFS_P2IFG) &= (unsigned char) ~selectedPins;
            HWREGB(baseAddress + OFS_P2IE) |= (unsigned char) selectedPins;
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
			HWREG(baseAddress + OFS_PAIFG) &= ~selectedPins;
            HWREG(baseAddress + OFS_PAIE) |= selectedPins;
            break;
    }
}

//*****************************************************************************
//
//! This function disables the port interrupt on the selected pin.
//!     Note that only Port 1,2, A have this capability
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxIE.
//!
//! \return None
//
//*****************************************************************************
void GPIO_disableInterrupt (
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}
    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
            HWREGB(baseAddress + OFS_P1IE) &= (unsigned char) ~selectedPins;
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
            HWREGB(baseAddress + OFS_P2IE) &= (unsigned char) ~selectedPins;
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
            HWREG(baseAddress + OFS_PAIE) &= ~selectedPins;
            break;
    }
}

//*****************************************************************************
//
//! This function gets the interrupt status of the selected pin.
//!     Note that only Port 1,2, A have this capability
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxIFG.
//!
//! \return Masked state of the interupt
//
//*****************************************************************************
unsigned int GPIO_getInterruptStatus (
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );

    unsigned char returnValue;

    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
            returnValue = (HWREGB(baseAddress + OFS_P1IFG) & ((unsigned char) selectedPins));
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
            returnValue = (HWREGB(baseAddress + OFS_P2IFG) & ((unsigned char) selectedPins));
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
            returnValue = (HWREG(baseAddress + OFS_PAIFG) & selectedPins);
            break;
    }

    return ( returnValue) ;
}

//*****************************************************************************
//
//! This function clears the interrupt flag on the selected pin.
//!     Note that only Port 1,2, A have this capability
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! Modified registers are \b PxIFG.
//!
//! \return None
//
//*****************************************************************************
void GPIO_clearInterruptFlag (
    unsigned char selectedPort,
    unsigned int selectedPins
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}


    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
            HWREGB(baseAddress + OFS_P1IFG) &= (unsigned char) ~selectedPins;
            break;
        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
            HWREGB(baseAddress + OFS_P2IFG) &= (unsigned char) ~selectedPins;
            break;
        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
            HWREG(baseAddress + OFS_PAIFG) &= ~selectedPins;
            break;
    }
}

//*****************************************************************************
//
//! This function selects on what edge the port interrupt flag should be set
//! for a transition
//!
//!
//! \param selectedPort is the selected port.
//!             Valid values are \b GPIO_PORT_P1, \b GPIO_PORT_P2,
//!             \b GPIO_PORT_P3, \b GPIO_PORT_P4,\b GPIO_PORT_P5,
//!             \b GPIO_PORT_P6, \b GPIO_PORT_P7,\b GPIO_PORT_P8,
//!             \b GPIO_PORT_P9, \b GPIO_PORT_P10,
//!             \b GPIO_PORT_P11, \b GPIO_PORT_PA,
//!             \b GPIO_PORT_PB, \b GPIO_PORT_PC,
//!             \b GPIO_PORT_PD, \b GPIO_PORT_PE,
//!             \b GPIO_PORT_PF, \b GPIO_PORT_PJ
//! \param selectedPins is the specified pin in the selected port.
//!             Valid values are \b GPIO_PIN0, \b GPIO_PIN1, \b GPIO_PIN2,
//!             \b GPIO_PIN3, \b GPIO_PIN4, \b GPIO_PIN5, \b GPIO_PIN6,
//!             \b GPIO_PIN7,\b GPIO_PIN8,\b GPIO_PIN9,\b GPIO_PIN10,
//!             \b GPIO_PIN11,\b GPIO_PIN12,\b GPIO_PIN13,\b GPIO_PIN14,
//!             \b GPIO_PIN15
//! \param edgeSelect specifies what transition sets the interrupt flag
//!             Valid values are
//!             \b GPIO_HIGH_TO_LOW_TRANSITION,
//!             \b GPIO_LOW_TO_HIGH_TRANSITION
//! Modified registers are \b PxIES.
//!
//! \return None
//
//*****************************************************************************
void GPIO_interruptEdgeSelect (
    unsigned char selectedPort,
    unsigned int selectedPins,
    unsigned char edgeSelect
    )
{
    ASSERT((GPIO_PORT_P1 == selectedPort) || (GPIO_PORT_P2 == selectedPort) ||
        (GPIO_PORT_P3 == selectedPort) || (GPIO_PORT_P4 == selectedPort) ||
        (GPIO_PORT_P5 == selectedPort) || (GPIO_PORT_P6 == selectedPort) ||
        (GPIO_PORT_P7 == selectedPort) || (GPIO_PORT_P8 == selectedPort) ||
        (GPIO_PORT_P9 == selectedPort) || (GPIO_PORT_P10 == selectedPort) ||
        (GPIO_PORT_P11 == selectedPort) || (GPIO_PORT_PA == selectedPort) ||
        (GPIO_PORT_PB == selectedPort) || (GPIO_PORT_PC == selectedPort) ||
        (GPIO_PORT_PD == selectedPort) || (GPIO_PORT_PE == selectedPort) ||
        (GPIO_PORT_PF == selectedPort) || (GPIO_PORT_PJ == selectedPort)
        );
  
     ASSERT(0x00 != (selectedPins & (GPIO_PIN0 + GPIO_PIN1 + GPIO_PIN2 + 
                                     GPIO_PIN3 + GPIO_PIN4 + GPIO_PIN5 + 
                                     GPIO_PIN6 + GPIO_PIN7 + GPIO_PIN8 + 
                                     GPIO_PIN9 + GPIO_PIN10 + GPIO_PIN11 +
                                     GPIO_PIN12 + GPIO_PIN13 + GPIO_PIN14 +  
                                     GPIO_PIN15
             )));
			 
	unsigned int baseAddress  = GPIO_getBaseAddress(selectedPort);
	
	ASSERT((0xFFFF != baseAddress) );
    if(0xFFFF == baseAddress)
	{
		return;
	}

    ASSERT((edgeSelect == GPIO_HIGH_TO_LOW_TRANSITION) ||
        (edgeSelect == GPIO_LOW_TO_HIGH_TRANSITION)
        );

    switch (selectedPort){
        case GPIO_PORT_P1:
		case GPIO_PORT_P3:
		case GPIO_PORT_P5:
		case GPIO_PORT_P7:
		case GPIO_PORT_P9:
            if (GPIO_LOW_TO_HIGH_TRANSITION == edgeSelect){
                HWREGB(baseAddress + OFS_P1IES) &= (unsigned char) ~selectedPins;
            } else   {
                HWREGB(baseAddress + OFS_P1IES) |= (unsigned char) selectedPins;
            }
            break;

        case GPIO_PORT_P2:
		case GPIO_PORT_P4:
		case GPIO_PORT_P6:
		case GPIO_PORT_P8:
		case GPIO_PORT_P10:
            if (GPIO_LOW_TO_HIGH_TRANSITION == edgeSelect){
                HWREGB(baseAddress + OFS_P2IES) &= (unsigned char) ~selectedPins;
            } else  {
                HWREGB(baseAddress + OFS_P2IES) |= (unsigned char) selectedPins;
            }
            break;

        case GPIO_PORT_PA:
		case GPIO_PORT_PB:
		case GPIO_PORT_PC:
		case GPIO_PORT_PD:
		case GPIO_PORT_PE:
		case GPIO_PORT_PF:
		case GPIO_PORT_PJ:
		case GPIO_PORT_P11:
            if (GPIO_LOW_TO_HIGH_TRANSITION == edgeSelect){
                HWREG(baseAddress + OFS_PAIES) &= ~selectedPins;
            } else  {
                HWREG(baseAddress + OFS_PAIES) |= selectedPins;
            }
            break;
    }
}

//*****************************************************************************
//
//Close the Doxygen group.
//! @}
//
//*****************************************************************************
