/*******************************************************************************
 *
 *  PowerTest.c
 *
 *
 ******************************************************************************/

#include "hal_MSP-EXP430F5438.h"
#include "LPM.h"
#include "PMM.h"
#include "PowerTest.h"

#define POWER_MENU_MAX 3

static const char PowerText[] = {
    "Select Mode  \0"
    " 1. Active   \0"
    " 2. Low Power\0"
    " 3. Quit     \0"
};

// -------------- Power Test Menu---------------------------------

/**********************************************************************//**
 * @brief  Executes the "PowerTest" menu option in the User Experience
 *         example code. This menu option allows one to observe the
 *                 effects of Active mode versus different Low-Power Modes
 *
 * @param  none
 *
 * @return none
 *************************************************************************/

void menuPower(void)
{
    unsigned char PowermenuPos = 0;
    unsigned char quit = 0;
    unsigned int i;

    halButtonsInterruptDisable(BUTTON_ALL);
    halButtonsInterruptEnable(BUTTON_SELECT + BUTTON_UP + BUTTON_DOWN);
    halLcdClearScreen();

    halLcdPrintLine((char *)PowerText, 0, 0);

    buttonsPressed = 0;

    while (!quit)
    {
        for (i = 0; i < 4; i++)
        {
            halLcdPrintLine((char *)&PowerText[i * 14 + 14], i + 1,       \
                            OVERWRITE_TEXT);
            halLcdPrintLine((char *)&PowerText[PowermenuPos * 14 + 14], PowermenuPos + 1,       \
                            INVERT_TEXT | OVERWRITE_TEXT);
        }

        while (!buttonsPressed) ;

        if (buttonsPressed & BUTTON_DOWN) //scroll down
        {
            halLcdPrintLine((char *)&PowerText[PowermenuPos * 14 + 14], PowermenuPos + 1,      \
                            OVERWRITE_TEXT);
            if (++PowermenuPos >= POWER_MENU_MAX)
            {
                PowermenuPos = 0;
            }
            halLcdPrintLine((char *)&PowerText[PowermenuPos * 14 + 14], PowermenuPos + 1,       \
                            INVERT_TEXT | OVERWRITE_TEXT);
            buttonsPressed = 0;
        }

        if (buttonsPressed & BUTTON_UP)   //scroll up
        {
            halLcdPrintLine((char *)&PowerText[PowermenuPos * 14 + 14], PowermenuPos + 1,      \
                            OVERWRITE_TEXT);
            if (PowermenuPos-- <= 0)
            {
                PowermenuPos = 2;
            }
            halLcdPrintLine((char *)&PowerText[PowermenuPos * 14 + 14], PowermenuPos + 1,       \
                            INVERT_TEXT | OVERWRITE_TEXT);
            buttonsPressed = 0;
        }

        if (buttonsPressed & BUTTON_SELECT)
        {
            switch (PowermenuPos)
            {
                case 0: menuPMMMCLK();    //Active Mode
                    halButtonsInterruptDisable(BUTTON_ALL);
                    halButtonsInterruptEnable(BUTTON_SELECT + BUTTON_UP + BUTTON_DOWN); break;
                case 1: menuLPM(); break; //Low-Power Mode
                case 2: quit = 1; break;
                default: break;
            }
            if (!quit)
            {
                halLcdClearScreen();
                halLcdPrintLine((char *)PowerText, 0, 0);
                halLcdPrintLine((char *)&PowerText[PowermenuPos * 14 + 14], PowermenuPos + 1,       \
                                INVERT_TEXT | OVERWRITE_TEXT);
            }
        }
        buttonsPressed = 0;
    }
}

