/*******************************************************************************
 *
 *  HAL_AppUart.c - Code for controlling Application UART
 *
 *
 ******************************************************************************/

/***************************************************************************//**
 * @file       HAL_AppUart.c
 * @addtogroup HAL_AppUart
 * @{
 ******************************************************************************/
#include <stdint.h>
#include "msp430.h"
#include "HAL_UCS.h"
#include "HAL_AppUart.h"
#include "HAL_Dogs102x6.h"

/***************************************************************************//**
 * @brief   Initialize the Application UART
 * @param   None
 * @return  None
 ******************************************************************************/

void AppUart_init(void)
{
    SELECT_ACLK(SELA__XT1CLK);              // Source ACLK from LFXT1

    P4SEL = BIT5 + BIT4;                    // P4.4,5 = USCI_A1 TXD/RXD
    UCA1CTL1 |= UCSWRST;                    // **Put state machine in reset**
    UCA1CTL0 = 0x00;
    UCA1CTL1 = UCSSEL_1 + UCSWRST;          // Use ACLK, keep RESET
    UCA1BR0 = 0x03;                         // 32kHz/9600=3.41 (see User's Guide)
    UCA1BR1 = 0x00;                         //
    UCA1MCTL = UCBRS_3 + UCBRF_0;           // Modulation UCBRSx=3, UCBRFx=0
    UCA1CTL1 &= ~UCSWRST;                   // **Initialize USCI state machine**
}

/***************************************************************************//**
 * @brief   Receive a character via Application UART
 * @param   None
 * @return  received character
 ******************************************************************************/

uint8_t AppUart_getChar(void)
{
    uint8_t receiveChar;

    while (!(UCA1IFG & UCRXIFG)) ;
    receiveChar = UCA1RXBUF;
    return receiveChar;
}

/***************************************************************************//**
 * @brief   Transmit a character via Application UART
 * @param   transmitChar  Character to be transmitted
 * @return  None
 ******************************************************************************/

void AppUart_putChar(uint8_t transmitChar)
{
    while (!(UCA1IFG & UCTXIFG)) ;
    UCA1TXBUF = transmitChar;
}

