// *************************************************************************************************
//
//
// *************************************************************************************************
// Data logger routines.
// *************************************************************************************************

// *************************************************************************************************
// Include section

// system
#include "project.h"

// logic
#include "datalog.h"

// *************************************************************************************************
// Prototypes section

// *************************************************************************************************
// Defines section

// *************************************************************************************************
// Implementation

void flash_erase_page(u8 page)
{
    // Convert page index to memory address
    u16 *wptr = (u16 *) (page * 512);

    // Range check
    if ((page < DATALOG_PAGE_START) || (page > DATALOG_PAGE_END))
        return;

    // Wait until not busy
    while ((FCTL3 & BUSY) != 0) ;

    __disable_interrupt();
    FCTL3 = FWKEY;              // Clear Lock bit
    FCTL1 = FWKEY + ERASE;      // Set Erase bit
    *wptr = 0;                  // Dummy write to erase Flash seg
    FCTL1 = FWKEY + WRT;        // Set WRT bit for write operation
    FCTL1 = FWKEY;              // Clear WRT bit
    FCTL3 = FWKEY + LOCK;       // Set LOCK bit
    __enable_interrupt();
}

void flash_write(u16 * wptr, u16 data)
{
    // Range check
    //if ((page < DATALOG_MEMORY_START) || (page > DATALOG_MEMORY_END)) return;

    // Wait until not busy
    while ((FCTL3 & BUSY) != 0) ;

    __disable_interrupt();
    FCTL3 = FWKEY;              // Clear Lock bit
    *wptr = 0;                  // Dummy write to erase Flash seg
    FCTL1 = FWKEY + WRT;        // Set WRT bit for write operation
    *wptr = data;
    FCTL1 = FWKEY;              // Clear WRT bit
    FCTL3 = FWKEY + LOCK;       // Set LOCK bit
    __enable_interrupt();
}

