// *************************************************************************************************
//
//
// *************************************************************************************************
// Menu management functions.
// *************************************************************************************************

// *************************************************************************************************
// Include section

// system
#include "project.h"

// driver
#include "display.h"

// logic
#include "menu.h"
#include "user.h"
#include "clock.h"
#include "date.h"
#include "temperature.h"
#include "altitude.h"
#include "battery.h"
#include "bluerobin.h"
#include "rfsimpliciti.h"
#include "acceleration.h"
#include "datalog.h"
#include "rfbsl.h"

// *************************************************************************************************
// Defines section
#define FUNCTION(function)  function

// *************************************************************************************************
// Global Variable section
const struct menu *ptrMenu_L1 = NULL;
const struct menu *ptrMenu_L2 = NULL;

// *************************************************************************************************
// Global Variable section

void display_nothing(u8 line, u8 update)
{
}

u8 update_time(void)
{
    return (display.flag.update_time);
}

u8 update_date(void)
{
    return (display.flag.update_date);
}

u8 update_temperature(void)
{
    return (display.flag.update_temperature);
}

// *************************************************************************************************
// User navigation ( [____] = default menu item after reset )
//
//      LINE1:  [Time] -> Temperature -> Altitude -> Heart rate
//
//      LINE2:  [Date] -> Datalog -> SYNC -> RFBSL
// *************************************************************************************************

// Line1 - Time
const struct menu menu_L1_Time = {
    FUNCTION(sx_time),             // direct function
    FUNCTION(dummy),               // sub menu function
    FUNCTION(display_time),        // display function
    FUNCTION(update_time),         // new display data
    &menu_L1_Temperature,
};

// Line1 - Temperature
const struct menu menu_L1_Temperature = {
    FUNCTION(dummy),               // direct function
    FUNCTION(dummy),               // sub menu function
    FUNCTION(display_temperature), // display function
    FUNCTION(update_time),         // new display data
    &menu_L1_Altitude,
};

// Line1 - Altitude
const struct menu menu_L1_Altitude = {
    FUNCTION(dummy),               // direct function
    FUNCTION(dummy),               // sub menu function
    FUNCTION(display_altitude),    // display function
    FUNCTION(update_time),         // new display data
#ifdef INCLUDE_BLUEROBIN_SUPPORT
    &menu_L1_Heartrate,
};

// Line1 - Heart Rate
const struct menu menu_L1_Heartrate = {
    FUNCTION(sx_bluerobin),        // direct function
    FUNCTION(mx_bluerobin),        // sub menu function
    FUNCTION(display_heartrate),   // display function
    FUNCTION(update_time),         // new display data
#endif
    &menu_L1_Time,
};

// Line2 - Date
const struct menu menu_L2_Date = {
    FUNCTION(sx_date),             // direct function
    FUNCTION(dummy),               // sub menu function
    FUNCTION(display_date),        // display function
    FUNCTION(update_date),         // new display data
    &menu_L2_DataLog,
};

// Line2 - DataLog (data recording on/off)
const struct menu menu_L2_DataLog = {
    FUNCTION(sx_datalog),          // direct function
    FUNCTION(dummy),               // sub menu function
    FUNCTION(display_datalog),     // display function
    FUNCTION(update_time),         // new display data
    &menu_L2_Sync,
};

// Line2 - SYNC (synchronization/data download via SimpliciTI)
const struct menu menu_L2_Sync = {
    FUNCTION(sx_sync),             // direct function
    FUNCTION(dummy),               // sub menu function
    FUNCTION(display_sync),        // display function
    FUNCTION(update_time),         // new display data
    &menu_L2_RFBSL,
};

// Line2 - RFBSL (software update)
const struct menu menu_L2_RFBSL = {
    FUNCTION(sx_rfbsl),            // direct function
    FUNCTION(dummy),               // sub menu function
    FUNCTION(display_rfbsl),       // display function
    FUNCTION(update_time),         // new display data
    &menu_L2_Date,
};
