//******************************************************************************
//   MSP430G2210 Demo - Comp_A, Detect Threshold, Set P1.5 if P1.2/CA2 > 0.25*Vcc
//
//   Description: Use Comparator_A to detect a voltage threshold.
//   Using an external potentiometer, an unknown voltage is applied to P1.2/CA2.
//   Comparator_A compares the unknown voltage to an internal reference
//   voltage, in this example 0.25*VCC. If the unknown voltage is higher
//   than 0.25*VCC, P1.5 is set, if not, P1.5 is reset.
//   ACLK = VLO, MCLK = SMCLK = default DCO
//
//          MSP430G2210
//       -----------------
//   /|\ |            XIN|-
//    |  |               |
//    ---|RST        XOUT|-
//       |               |
//    |  |               |
//    R<-|P1.2/CA2   P1.5|--> Set if > 0.25*Vcc, else reset
//    |  |               |
//    ---|VSS
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main (void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */
  
  P1DIR |= BIT5;                            // P1.5 output
  CACTL1 = CARSEL | CAREF0 | CAON;          // 0.25 Vcc = -comp, on
  CACTL2 = P2CA0 | P2CA4;                   // P1.2/CA2 = +comp

  while (1)                                 // Test comparator_A output
  {
    if ((CAOUT & CACTL2))
      P1OUT |= BIT5;                        // if CAOUT set, set P1.5
    else P1OUT &= ~BIT5;                    // else reset
  }
}

