//******************************************************************************
//  MSP430G2230 Demo - ADC10, Sample A5, AVcc Ref, Set P1.2 if > 0.5*AVcc
//
//  Description: A single sample is made on A5 with reference to AVcc.
//  Software sets ADC10SC to start sample and conversion - ADC10SC
//  automatically cleared at EOC. ADC10 internal oscillator times sample (16x)
//  and conversion. In Mainloop MSP430 waits in LPM0 to save power until ADC10
//  conversion complete, ADC10_ISR will force exit from LPM0 in Mainloop on
//  reti. If A5 > 0.5*AVcc, P1.5 set, else reset.
//
//                MSP430G2230
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//        >---|P1.5/A5      P1.2|-->LED
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  ADC10CTL0 = ADC10SHT_2 | ADC10ON | ADC10IE; // ADC10ON, interrupt enabled
  ADC10CTL1 = INCH_5;                       // input A5
  ADC10AE0 |= BIT5;                         // PA.5 ADC option select
  P1DIR |= BIT2;                            // Set P1.2 to output direction

  for (;;)
  {
    ADC10CTL0 |= ENC | ADC10SC;             // Sampling and conversion start
    __bis_SR_register(CPUOFF + GIE);        // LPM0, ADC10_ISR will force exit
    if (ADC10MEM < 0x1FF)
      P1OUT &= ~BIT2;                       // Clear P1.2 LED off
    else
      P1OUT |= BIT2;                        // Set P1.2 LED on
  }
}

// ADC10 interrupt service routine
#pragma vector=ADC10_VECTOR
__interrupt void ADC10_ISR(void)
{
  __bic_SR_register_on_exit(CPUOFF);        // Clear CPUOFF bit from 0(SR)
}
