//******************************************************************************
//  MSP430G2230 Demo - ADC10, Sample A11, Lo_Batt, Set P1.2 if AVCC<2.3V
//
//  Description: A single sample is made on A11 (AVcc/2) with reference to
//  internal 1.5V Vref. Software sets ADC10SC to start sample and conversion
//  - ADC10SC automatically cleared at EOC. ADC10 internal oscillator times
//  sample (16x) and conversion. ADC10BUSY flag is polled for EOC. If A11
//  (AVcc/2) < 0311h (1.15V) indicating AVcc is less 2.3V, P1.2 set indicating
//  a lo_Batt condition, else reset.
//
//                MSP430G2230
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |A11          P1.2|-->LED
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  ADC10CTL1 = INCH_11;                      // AVcc/2
  ADC10CTL0 = SREF_1 | ADC10SHT_2 | REFON | ADC10ON;
  __enable_interrupt();                     // Enable interrupts.
  TA0CCR0 = 30;                             // Delay to allow Ref to settle
  TA0CCTL0 |= CCIE;                         // Compare-mode interrupt.
  TA0CTL = TASSEL_2 | MC_1;                 // TACLK = SMCLK, Up mode.
  LPM0;                                     // Wait for delay.
  TA0CCTL0 &= ~CCIE;                        // Disable timer Interrupt
  __disable_interrupt();
  P1DIR |= BIT2;                            // Set P1.2 to output direction

  for (;;)
  {
    ADC10CTL0 |= ENC | ADC10SC;             // Sampling and conversion start
    while (ADC10CTL1 & ADC10BUSY);          // ADC10BUSY?
    if (ADC10MEM < 0x311)                   // ADC10MEM = A11 > 0.65?
      P1OUT |= BIT2;                        // Set P1.2 LED on
    else
      P1OUT &= ~BIT2;                       // Clear P1.2 LED off
  }
}

// TIMERA0 interrupt service routine
#pragma vector=TIMERA0_VECTOR
__interrupt void ta0_isr(void)
{
  TA0CTL = 0;
  LPM0_EXIT;                                // Exit LPM0 on return
}
