//******************************************************************************
//  MSP430G2230 Demo - ADC10, DTC Sample A5 -> TA1, AVcc, DCO
//
//  Description: Use DTC to sample A5 with reference to AVcc and directly
//  transfer code to TA0CCR1. Timer_A has been configured for 10-bit PWM mode.
//  TA0CCR1 duty cycle is automatically proportional to ADC10 A5. WDT_ISR used
//  as a period wakeup timer approximately 45ms based on default ~1.2MHz
//  DCO/SMCLK clock source used in this example for the WDT clock source.
//  Timer_A also uses default DCO.
//
//                MSP430G2230
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//        >---|P1.5/A5      P1.2|--> TA0CCR1 - 0-1024 PWM
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDT_MDLY_32;                     // WDT ~45ms interval timer
  IE1 |= WDTIE;                             // Enable WDT interrupt
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */
  
  ADC10CTL0 = ADC10SHT_2 | ADC10ON;
  ADC10CTL1 = INCH_5;                       // ADC Input Channel A5
  ADC10AE0 |= BIT5;                         // P1.5 ADC option select
  ADC10DTC1 = 0x001;                        // 1 conversion
  P1DIR |= BIT2;                            // P1.2 = output
  P1SEL |= BIT2;                            // P1.2 = TA1 output
  TA0CCR0 = 1024 - 1;                       // PWM Period
  TA0CCTL1 = OUTMOD_7;                      // TA0CCR1 reset/set
  TA0CCR1 = 512;                            // TA0CCR1 PWM Duty Cycle
  TA0CTL = TASSEL_2 | MC_1;                 // SMCLK, upmode

  while(1)
  {
    __bis_SR_register(LPM0_bits + GIE);     // LPM0, WDT_ISR will force exit
    ADC10SA = (unsigned int)&TA0CCR1;       // Data transfer location
    ADC10CTL0 |= ENC | ADC10SC;             // Start sampling
  }
}

#pragma vector = WDT_VECTOR
__interrupt void WDT_ISR(void)
{
  __bic_SR_register_on_exit(LPM0_bits);     // Exit LPM0
}

