//******************************************************************************
//  MSP430F20x2/3 Demo - SPI 3-Wire Slave Data Echo
//
//  Description: SPI slave talks to SPI master using 3-wire mode. Data received
//  from master is echoed back.
//  ACLK = VLO, MCLK = SMCLK = Default DCO
//
//  Note: Ensure the slave device is running before the master device starts 
//    code execution 
//
//                    Slave                     Master
//                                      (msp430g2230_usi_03.c)
//                 MSP430G2230                MSP430G2230
//             -----------------          -----------------
//            |              XIN|-    /|\|              XIN|-
//            |                 |      | |                 |
//            |             XOUT|-     --|RST          XOUT|-
//            |                 | /|\    |                 |
//            |          RST/NMI|--+     |                 |
//            |                 |        |                 |
//            |                 |        |             P1.2|-> LED
//            |         SDI/P1.7|<-------|P1.6/SDO         |
//            |         SDO/P1.6|------->|P1.7/SDI         |
//            |        SCLK/P1.5|<-------|P1.5/SCLK        |
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

unsigned char Rx_Data;

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;             // Stop watchdog timer
  /* Initialization Code */
  P1REN = 0x1B;                         // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                        // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                  // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  USICTL0 |= USIPE7 | USIPE6 | USIPE5 | USIOE; // Port, SPI slave
  USICTL1 |= USIIE;                     // Counter interrupt, flag remains set
  USICTL0 &= ~USISWRST;                 // USI released for operation
  USISRL = 0x00;                        // init-load data, dummy data
  USICNT = 8;                           // init-load counter

  __bis_SR_register(LPM0_bits + GIE);   // Enter LPM0 w/ interrupt
  __no_operation();
}

// USI interrupt service routine
#pragma vector=USI_VECTOR
__interrupt void universal_serial_interface(void)
{
  Rx_Data = USISRL;
  USISRL = Rx_Data;                     // Echo back Rxed character
  USICNT = 8;                           // re-load counter
}
