//******************************************************************************
//  MSP430G22x0 Demo - Software Toggle P1.2, MCLK = VLO/8
//
//  Description; Pulse P1.2 with a 1/100 active duty cycle using software.
//  Ultra-low MCLK frequency ~ 1.5kHz, ultra-low power active mode demonstrated.
//  ACLK = VL0, MCLK = VLO/8 ~1.5kHz, SMCLK = n/a
//
//                MSP430G22x0
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//            |             P1.2|-->LED
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  volatile unsigned int i;                  // Volatile to prevent removal
  WDTCTL = WDTPW | WDTHOLD;                 // Stop watchdog timer  
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */
  
  __bis_SR_register(SCG1 | SCG0);           // Stop DCO
  BCSCTL2 |= SELM_3 | DIVM_3;               // MCLK = LFXT1/8
  P1DIR = BIT2|BIT5|BIT6|BIT7;              // Available P1.x outputs
  P1OUT = 0;                                // Reset available P1.x 

  for (;;)
  {
    P1OUT |= BIT2;                          // P1.2 set
    for (i = 10; i > 0; i--);               // Delay 1x
    P1OUT &= ~BIT2;                         // P1.2 reset
    for (i = 1000; i > 0; i--);             // Delay 100x
  }
}
