//******************************************************************************
//  MSP430G22x0 Demo - Software Poll P1.5, Set P1.2 if P1.5 = 1
//
//  Description: Poll P1.5 in a loop, if hi P1.2 is set, if low, P1.2 reset.
//  ACLK = VLO, MCLK = SMCLK = default DCO
//
//               MSP430G22x0
//            -----------------
//        /|\|              XIN|-
//         | |                 |
//         --|RST          XOUT|-
//     /|\   |                 |
//      --o--|P1.5         P1.2|-->LED
//     \|/
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop watchdog timer
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  P1DIR |= BIT2;                            // Set P1.2 to output direction

  while (1)                                 // Test P1.5
  {
    if ((BIT5 & P1IN)) P1OUT |= BIT2;       // if P1.5 set, set P1.2
    else P1OUT &= ~BIT2;                    // else reset
  }
}


