//******************************************************************************
//  MSP430G22x0 Demo - P1 Interrupt from LPM4 with Internal Pull-up
//
//  Description: A hi/low transition on P1.5 will trigger P1_ISR which,
//  toggles P1.2. Normal mode is LPM4 ~ 0.1uA.
//  Internal pullup enabled on P1.5.
//  ACLK = VLO, MCLK = SMCLK = default DCO
//
//               MSP430G22x0
//            -----------------
//        /|\|              XIN|-
//         | |                 |
//         --|RST          XOUT|-
//     /|\   |      R          |
//      --o--| P1.5-o      P1.2|-->LED
//     \|/
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop watchdog timer
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  P1DIR = BIT2;                             // P1.2 output, else input
  P1OUT =  BIT5;                            // P1.5 set, else reset
  P1REN |= BIT5;                            // P1.5 pullup
  P1IE |= BIT5;                             // P1.5 interrupt enabled
  P1IES |= BIT5;                            // P1.5 Hi/lo edge
  P1IFG &= ~BIT5;                           // P1.5 IFG cleared

  __bis_SR_register(LPM4_bits + GIE);       // Enter LPM4 w/interrupt
}

// Port 1 interrupt service routine
#pragma vector=PORT1_VECTOR
__interrupt void Port_1(void)
{
  P1OUT ^= BIT2;                            // P1.2 = toggle
  P1IFG &= ~BIT5;                           // P1.5 IFG cleared
}

