//******************************************************************************
//  MSP430G22x0 Demo - Basic Clock, Output Buffered MCLK/10
//
//  Description: Buffer MCLK/10 on P1.2
//  ACLK = VLO, MCLK = SMCLK = default DCO
//
//               MSP430G22x0
//             -----------------
//         /|\|              XIN|-
//          | |                 | 
//          --|RST          XOUT|-
//            |                 |
//            |             P1.2|-->MCLK/10 = DCO/10
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop watchdog timer
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  P1DIR |= BIT2;                            // P1.2 output

  while(1)
  {
    P1OUT |= BIT2;    	                    // P1.2 = 1
    P1OUT &= ~BIT2;                         // P1.2 = 0
  }
}

