//******************************************************************************
//  MSP430G22x0 Demo - Timer_A, Toggle P1.2, TA0CCR0 Up Mode ISR, DCO SMCLK
//
//  Description: Toggle P1.2 using software and TA_0 ISR. Timer_A is
//  configured for up mode, thus the timer overflows when TAR counts to TA0CCR0.
//  In this example TA0CCR0 is loaded with 50000.
//  ACLK = VLO, MCLK = SMCLK = TACLK = default DCO
//
//
//           MSP430G22x0
//         ---------------
//     /|\|            XIN|-
//      | |               |
//      --|RST        XOUT|-
//        |               |
//        |           P1.2|-->LED
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop watchdog timer
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  P1DIR |= BIT2;                            // P1.2 output
  TA0CCTL0 = CCIE;                          // TA0CCR0 interrupt enabled
  TA0CCR0 = 50000;
  TA0CTL = TASSEL_2 | MC_1;                 // SMCLK, upmode

  __bis_SR_register(LPM0_bits + GIE);       // Enter LPM0 w/ interrupt
}

// Timer A0 interrupt service routine
#pragma vector=TIMERA0_VECTOR
__interrupt void Timer_A (void)
{
  P1OUT ^= BIT2;                            // Toggle P1.2
}

