//******************************************************************************
//  MSP430G22x0 Demo - Timer_A, Toggle P1.2, Overflow ISR, DCO SMCLK
//
//  Description: Toggle P1.2 using software and Timer_A overflow ISR.
//  In this example an ISR triggers when TA overflows. Inside the TA
//  overflow ISR P1.2 is toggled. Toggle rate is approximatlely 12Hz.
//  Proper use of TAIV interrupt vector generator is demonstrated.
//  ACLK = VLO, MCLK = SMCLK = TACLK = default DCO
//  Toggle rate = 2^16/SMCLK ~ 16Hz
//
//           MSP430G22x0
//         ---------------
//     /|\|            XIN|-
//      | |               |
//      --|RST        XOUT|-
//        |               |
//        |           P1.2|-->LED
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop watchdog timer
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  P1DIR |= BIT2;                            // P1.2 output
  TA0CTL = TASSEL_2 | MC_2 | TAIE;          // SMCLK, contmode, interrupt

  __bis_SR_register(LPM0_bits + GIE);       // Enter LPM0 w/ interrupt
}

// Timer_A3 Interrupt Vector (TAIV) handler
#pragma vector=TIMERA1_VECTOR
__interrupt void Timer_A(void)
{
 switch( TAIV )
 {
   case  2: break;                          // TA0CCR1 not used
   case  4: break;                          // TA0CCR2 not used
   case 10: P1OUT ^= BIT2;                  // overflow
            break;
 }
}

