//******************************************************************************
//  MSP430G22x0 Demo - Timer_A, Toggle P1.2, TA0CCR1 Cont. Mode ISR, DCO SMCLK
//
//  Description: Toggle P1.2 using software and TA_1 ISR. Toggles every
//  50000 SMCLK cycles. SMCLK provides clock source for TACLK.
//  During the TA_1 ISR, P1.2 is toggled and 50000 clock cycles are added to
//  TA0CCR0. TA_1 ISR is triggered every 50000 cycles. CPU is normally off and
//  used only during TA_ISR. Proper use of the TAIV interrupt vector generator
//  is demonstrated.
//  ACLK = VLO, MCLK = SMCLK = TACLK = default DCO
//
//           MSP430G22x0
//         ---------------
//     /|\|            XIN|-
//      | |               |
//      --|RST        XOUT|-
//        |               |
//        |           P1.2|-->LED
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop watchdog timer
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  P1DIR |= BIT2;                            // P1.2 output
  TA0CCTL1 = CCIE;                          // TA0CCR1 interrupt enabled
  TA0CCR1 = 50000;
  TA0CTL = TASSEL_2 | MC_2;                 // SMCLK, Contmode

  __bis_SR_register(LPM0_bits + GIE);       // Enter LPM0 w/ interrupt
}

// Timer_A3 Interrupt Vector (TAIV) handler
#pragma vector=TIMERA1_VECTOR
__interrupt void Timer_A(void)
{
  switch( TAIV )
  {
  case  2:                                  // TA0CCR1
    {
    P1OUT ^= BIT2;                          // Toggle P1.2
    TA0CCR1 += 50000;                       // Add Offset to TA0CCR1
    }
           break;
  case  4: break;                           // TA0CCR2 not used
  case 10: break;                           // overflow not used
 }
}

