//******************************************************************************
//  MSP430G22x0 Demo - Timer_A, Toggle P1.5/TA0_0, Up/Down Mode, DCO SMCLK
//
//  Description: Toggle P1.5 using hardware TA0 output. Timer_A is configured
//  for up/down mode with TA0CCR0 defining period, TA0 also output on P1.5. In
//  this example, TA0CCR0 is loaded with 250 and TA0 will toggle P1.5 at
//  TACLK/2*250. Thus the output frequency on P1.5 will be the TACLK/1000.
//  No CPU or software resources required.
//  ACLK = VLO, SMCLK = MCLK = TACLK = default DCO
//  As coded with TACLK = SMCLK, P1.5 output frequency is ~1000000/1000
//
//            MSP430G22x0
//         -----------------
//     /|\|              XIN|-
//      | |                 |
//      --|RST          XOUT|-
//        |                 |
//        |         P1.5/TA0|--> SMCLK/1000
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop watchdog timer
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  P1DIR |= BIT5;                            // P1.5 output
  P1SEL |= BIT5;                            // P1.5 option select
  TA0CCTL0 = OUTMOD_4;                      // TA0CCR0 toggle mode
  TA0CCR0 = 250;
  TA0CTL = TASSEL_2 | MC_3;                 // SMCLK, up-downmode

  __bis_SR_register(CPUOFF);                // CPU off
}
