//******************************************************************************
//  MSP430G22x0 Demo - Timer_A, PWM TA0_1-2, Up Mode, DCO SMCLK
//
//  Description: This program generates one PWM output on P1.2 using
//  Timer_A configured for up mode. The value in TA0CCR0, 512-1, defines the PWM
//  period and the value in TA0CCR1 the PWM duty cycles.
//  A 75% duty cycle on P1.2.
//  ACLK = VLO, SMCLK = MCLK = TACLK = default DCO
//
//               MSP430G22x0
//            -----------------
//        /|\|              XIN|-
//         | |                 |
//         --|RST          XOUT|-
//           |                 |
//           |         P1.2/TA1|--> TA0CCR1 - 75% PWM
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop watchdog timer
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  P1DIR |= BIT2;                            // P1.2 output
  P1SEL |= BIT2;                            // P1.2 TA1/2 options
  TA0CCR0 = 512-1;                          // PWM Period
  TA0CCTL1 = OUTMOD_7;                      // TA0CCR1 reset/set
  TA0CCR1 = 384;                            // TA0CCR1 PWM duty cycle
  TA0CTL = TASSEL_2 | MC_1;                 // SMCLK, up mode

  __bis_SR_register(CPUOFF);                // Enter LPM0
}

