//******************************************************************************
//  MSP430G22x0 Demo - Timer_A, PWM TA0_1, Up/Down Mode, DCO SMCLK
//
//  Description: This program generates one PWM output on P1.2 using
//  Timer_A configured for up/down mode. The value in TA0CCR0, 128, defines the PWM
//  period/2 and the value in TA0CCR1 the PWM duty cycles.
//  A 75% duty cycle is on P1.2.
//  SMCLK = MCLK = TACLK = default DCO
//
//               MSP430G22x0
//            -----------------
//        /|\|              XIN|-
//         | |                 |
//         --|RST          XOUT|-
//           |                 |
//           |         P1.2/TA1|--> TA0CCR1 - 75% PWM
//
//  B. Nisarga
//  Texas Instruments, Inc
//  December 2011
//  Built with CCE Version: 5.1 and IAR Embedded Workbench Version: 5.4
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop watchdog timer
  
  /* Initialization Code */
  P1REN = 0x1B;                             // Terminate unavailable Port1 pins (P1.0/1/3/4) properly
                                            // Config as Input with pull-down enabled
  BCSCTL3 |= LFXT1S_2;                      // Select VLO as low freq clock     
  /* End Initialization Code */ 
  
  P1DIR |= BIT2;                            // P1.2 output
  P1SEL |= BIT2;                            // P1.2 TA1 options
  TA0CCR0 = 128;                            // PWM Period/2
  TA0CCTL1 = OUTMOD_6;                      // TA0CCR1 toggle/set
  TA0CCR1 = 32;                             // TA0CCR1 PWM duty cycle
  TA0CTL = TASSEL_2 | MC_3;                 // SMCLK, up-down mode

  __bis_SR_register(LPM0_bits);             // Enter LPM0
}

