//******************************************************************************
//  MSP430x471xx Demo - FLL+, Runs Internal DCO at 16MHz
//
//  Description: This program demonstrates setting the internal DCO to run at
//  8MHz with auto-calibration by the FLL+.
//  ACLK = LFXT1 = 32768Hz, MCLK = SMCLK = DCO = (121+1) x 4 x ACLK = 16MHz
//  For correct CPU operation @ 16MHz, the supply voltage should be set accordingly
//  //* An external watch crystal between XIN & XOUT is required for ACLK *//	
//
//               MSP430x471xx
//             -----------------
//         /|\|              XIN|-
//          | |                 | 32kHz
//          --|RST          XOUT|-
//            |                 |
//            |             P1.1|--> MCLK = 16MHz
//            |                 |
//            |             P1.5|--> ACLK = 32kHz
//            |                 |
//
//  K.Venkat
//  Texas Instruments Inc.
//  October 2008
//  Built with CCE Version: 3.2.0 and IAR Embedded Workbench Version: 4.11B
//******************************************************************************
#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Stop watchdog timer
  FLL_CTL0 |= DCOPLUS + XCAP11PF;           // DCO+ set, freq = xtal x D x N+1
  SCFI0 = FLLD_4+FN_4;                      // x4 DCO freq, 16MHz nominal DCO
  SCFQCTL = 121;                            // (121+1) x 32768 x 4 = 16 MHz
  P1DIR = BIT1+BIT5;                        // P1.1 & P1.5 to output direction
  P1SEL = BIT1+BIT5;                        // P1.1 & P1.5 to output MCLK & ACLK

  while(1);                                 // Loop in place
}
