//******************************************************************************
//   MSP430F530x Demo  - Software Poll PU.0, Set P1.0 if PU.0 = 1
//
//  Description: Poll PU.0 in a loop, if hi P1.0 is set, if low, P1.0 reset.
//  ACLK = n/a, MCLK = SMCLK = default DCO
//
//              MSP430F530x
//            -----------------
//        /|\|              VCC|--
//         | |                 |  |
//         --|RST          LDOO|<-
//     /|\   |                 |
//      --o--|PU.0         P1.0|-->LED
//     \|/
//
//  Note: 
//    1. PortU pins can only be configured together as either both inputs or both outputs
//    2. PortU is supplied by LDOO rail. Ensure 3.3V is available at LDOO, either by 
//       enabling the LDO OR by an external connection connecting device VCC to LDOO pin
//    3. In this example code, since the LDO is not enabled, an external connection between
//       the device VCC and LDOO pin is required for the PortU operation
//
//   K. Chen
//   Texas Instruments Inc.
//   Ver 2.00 - May 2012
//   Built with CCS Version: 5.2 and IAR Embedded Workbench Version: 5.40.3
//******************************************************************************
#include <msp430.h>         // To include latest F530x and F5310 header file v1.1, refer
                            // to the "ReadMe - Header" file in the code ex zip file

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop watchdog timer
  
  // Configure PU.0 as input pin
  LDOKEYPID = 0x9628;                       // Enable access to config registers 
  PUCTL |= PUIPE;                           // PortU input enable
  LDOKEYPID = 0x0;                          // Disbale access to config registers

  // Configure P1.0 as output 
  P1DIR |= BIT0;                            // Set P1.0 to output direction
  
  while (1)                                 // Test PU.0
  {
    if (PUCTL & PUIN0)
      P1OUT |= BIT0;                        // if PU.0 is high, set P1.0
    else
      P1OUT &= ~BIT0;                       // else reset P1.0
  }
}


