//******************************************************************************
//  MSP430F552x Demo - NMI on a high-to-low transition on the RST/NMI pin from LPM4
//
//  Description: The code will configure the RST/NMI pin to NMI mode and
//  thereafter a high-to-low transition on RST/NMI will trigger the UNMI_ISR
//  routine which in turn will toggle port pin P1.0 (LED). Note that the
//  enabling of global interrupts is not needed since NMIs are not gated by
//  this. However for all practical purposes global interrupts (GIE) will
//  likely need to be enabled in any real-world application.
//
//  *** NOTE *** To observe this example's functionality it is necessary to
//  disconnect the JTAG debugger from the MSP430 to allow application usage
//  of the RST/NMI pin.
//
//  ACLK = n/a, MCLK = SMCLK = default DCO
//
//               MSP430F552x
//            -----------------
//           |              XIN|-
//           |                 |
//           |             XOUT|-
//     /|\   |                 |
//      --o--|RST/NMI      P1.0|-->LED
//     \|/
//
//   Andreas Dannenberg
//   Texas Instruments Inc.
//   May 2012
//   Built Code Composer Studio v5.2
//******************************************************************************

#include <msp430.h>

int main(void) {
	WDTCTL = WDTPW | WDTHOLD;				// Stop watchdog timer

	P1OUT &= ~0x01;							// Clear P1.0 output latch
	P1DIR |= 0x01;                          // Set P1.0 to output direction

	SFRRPCR |= SYSNMIIES | SYSNMI;			// Select NMI function for the RST/NMI pin,
											// interrupt on falling edge
											// (pull-up R on RST/NMI is already enabled after PUC)

	SFRIE1 |= NMIIE;						// Set NMI pin interrupt enable

    __bis_SR_register(LPM4_bits);     		// Enter LPM4
}

// User NMI interrupt service routine
#pragma vector = UNMI_VECTOR
__interrupt void UNMI_ISR(void)
{
	// Efficiently decode the User NMI interrupt source
	switch (__even_in_range(SYSUNIV, SYSUNIV_SYSBUSIV)) {
	   case SYSUNIV_NMIIFG :
		   P1OUT ^= 0x01;                   // Toggle P1.0 = LED
		   break;
	   case SYSUNIV_OFIFG :
	   case SYSUNIV_ACCVIFG :
	   case SYSUNIV_BUSIFG :
	   default :
		   break;
	}
}
