//******************************************************************************
//  MSP430F673x Demo - DMA0, Repeated Block to-from RAM, Software Trigger
//
//  Description: A 16 word block from 1FC0-1FDFh is transfered to 1FE0h-1FFFh
//  using DMA0 in a burst block using software DMAREQ trigger.
//  After each transfer, source, destination and DMA size are
//  reset to initial software setting because DMA transfer mode 5 is used.
//  P1.0 is toggled during DMA transfer only for demonstration purposes.
//  ** RAM location 0x1C00 - 0x1C3F used - make sure no compiler conflict **
//  ACLK = REFO = 32kHz, MCLK = SMCLK = default DCO 1048576Hz
//  Use large memory model
//
//                MSP430F673x
//             -----------------
//         /|\|              XIN|-
//          | |                 | 32kHz
//          --|RST          XOUT|-
//            |                 |
//            |             P1.0|-->LED
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    P1DIR |= 0x01;                          // P1.0 output

    __data16_write_addr((unsigned short) &DMA0SA, (unsigned long) 0x1FC0);
    // Source block address
    __data16_write_addr((unsigned short) &DMA0DA, (unsigned long) 0x1FE0);
    // Destination single address
    DMA0SZ = 16;                            // Block size
    DMA0CTL = DMADT_5 | DMASRCINCR_3 | DMADSTINCR_3;
    // Repeated block transfer
    // Increment source and destination
    DMA0CTL |= DMAEN;                       // Enable DMA0

    while (1)
    {
        P1OUT |= 0x01;                      // P1.0 = 1, LED on
        DMA0CTL |= DMAREQ;                  // Trigger block transfer
        P1OUT &= ~0x01;                     // P1.0 = 0, LED off
    }
}

