//******************************************************************************
//  MSP430F673x Demo - Flash In-System Programming, Single-Byte Copy SegC to SegD
//
//  Description: This program first erases flash segment C, then it writes
//  incrementing values in segment C, then it erases segment D, then copies
//  segment C to segment D. Starting addresses of segments defined in this code:
//  Segment C-0x1880, Segment D-0x1800. RESET the device to re-execute code.
//  This is implemented to prevent stressing of Flash unintentionally.  Run
//  program until it reaches the breakpoint indicated below, then use the
//  debugger's memory browser to view segment C and segment D.
//  ACLK = REFO = 32kHz, MCLK = SMCLK = default DCO 1048576Hz
//
//               MSP430F673x
//            -----------------
//        /|\|              XIN|-
//         | |                 |
//         --|RST          XOUT|-
//           |                 |
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

char value;                                 // 8-bit value to write to segment C

// Function prototypes
void write_SegC(char value);
void copy_C2D(void);

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    value = 0;                              // Initialize value

    write_SegC(value);                      // Write segment C, increment value
    copy_C2D();                             // Copy segment C to D

    while (1) ;                             // Loop forever, SET BREAKPOINT HERE
}

//------------------------------------------------------------------------------
// Input = value, holds value to write to Seg C
//------------------------------------------------------------------------------
void write_SegC(char value)
{
    unsigned int i;
    char *Flash_ptr;                        // Initialize Flash pointer

    Flash_ptr = (char *)0x1880;

    FCTL3 = FWKEY;                          // Clear Lock bit
    FCTL1 = FWKEY | ERASE;                  // Set Erase bit
    *Flash_ptr = 0;                         // Dummy write to erase Flash seg
    FCTL1 = FWKEY | WRT;                    // Set WRT bit for write operation

    for (i = 0; i < 128; i++)
    {
        *Flash_ptr++ = value++;             // Write value to flash
    }

    FCTL1 = FWKEY;                          // Clear WRT bit
    FCTL3 = FWKEY | LOCK;                   // Set LOCK bit
}

//------------------------------------------------------------------------------
// Copy Seg C to Seg D
//------------------------------------------------------------------------------
void copy_C2D(void)
{
    unsigned int i;
    char *Flash_ptrC;
    char *Flash_ptrD;

    Flash_ptrC = (char *) 0x1880;           // Initialize Flash segment C ptr
    Flash_ptrD = (char *) 0x1800;           // Initialize Flash segment D ptr

    FCTL3 = FWKEY;                          // Clear Lock bit
    FCTL1 = FWKEY | ERASE;                  // Set Erase bit
    *Flash_ptrD = 0;                        // Dummy write to erase Flash seg D
    FCTL1 = FWKEY | WRT;                    // Set WRT bit for write operation

    for (i = 0; i < 128; i++)
    {
        *Flash_ptrD++ = *Flash_ptrC++;      // copy value segment C to seg D
    }

    FCTL1 = FWKEY;                          // Clear WRT bit
    FCTL3 = FWKEY | LOCK;                   // Set LOCK bit
}

