//******************************************************************************
//  MSP430F673x Demo - Flash In-System Programming, Long-Word Write at 0x1800
//
//  Description: This program first erases flash segment D, then it writes a
//  32-bit value to memory location 0x1800 using long-word write mode. Long-word
//  write provides faster write than byte/word mode. RESET the device to
//  re-execute code. This is implemented to prevent stressing of Flash
//  unintentionally. Run program until it reaches the breakpoint indicated
//  below, then use the debugger's memory browser to view segment D.
//  ACLK = REFO = 32kHz, MCLK = SMCLK = default DCO 1048576Hz
//  //* Set Breakpoint on NOP in the Mainloop to avoid Stressing Flash *//
//
//               MSP430F673x
//            -----------------
//        /|\|              XIN|-
//         | |                 |
//         --|RST          XOUT|-
//           |                 |
//
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
    unsigned long * Flash_ptrD;
    unsigned long value;

    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    Flash_ptrD = (unsigned long *) 0x1800;  // Initialize Flash pointer
    value = 0x12345678;                     // Initialize Value

    FCTL3 = FWKEY;                          // Clear Lock bit
    FCTL1 = FWKEY | ERASE;                  // Set Erase bit
    *Flash_ptrD = 0;                        // Dummy write to erase Flash seg
    FCTL1 = FWKEY | BLKWRT;                 // Enable long-word write

    *Flash_ptrD = value;                    // Write to Flash

    FCTL1 = FWKEY;                          // Clear WRT bit
    FCTL3 = FWKEY | LOCK;                   // Set LOCK bit

    while (1) ;                             // Loop forever, SET BREAKPOINT HERE
}

