//******************************************************************************
//    MSP430F673x Demo - MPY32, Saturation mode underflow test
//
//   Description: The example illustrates a special case showing underflow.
//   Underflow occurs when adding 2 negative numbers yields a positive result.
//   By having the saturation mode enabled, the result is rounded off to the
//   highest negative number (0x8000.0000 for 16 bit). Results with and without
//   saturation mode are shown in result variable and RESHI, RESLO registers
//   respectively.
//
//   ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//
//                MSP430F673x
//             -----------------
//         /|\|                 |
//          | |                 |
//          --|RST              |
//            |                 |
//            |                 |
//
//   M. Swanson
//   Texas Instruments Inc.
//   December 2011
//   Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

unsigned long result;

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    MPY32CTL0 = MPYSAT | MPYC;              // Saturation mode enable,
                                            // Carry bit set
    RES3 = 0;
    RES2 = 0;
    //------32-bit Result of a multiply operation (not shown) in RES0 and RES1------
    RES1 = 0x0000;                          // Pre-load first negative value
    RES0 = 0x8000;

    MACS = 0x8000;                          // Add to second negative value
    OP2 = 0x05;
    __no_operation();                       // Wait for result to become ready
    __no_operation();
    __no_operation();
    __no_operation();
    __no_operation();

    result = RESHI;                         // Load RESHI word result
    result = (result << 16) | RESLO;        // Shift RESHI left and concat with
                                            // RESLO word result

    MPY32CTL0 &= ~MPYSAT;                   // Clear saturation mode

    __bis_SR_register(LPM4_bits);           // LPM4
    __no_operation();                       // For debugger
}

