//******************************************************************************
//   MSP430F673x Demo - MPY32, 8x8 Signed Multiply
//
//   Description: Hardware multiplier is used to multiply two numbers.
//   The calculation is automatically initiated after the second operand is
//   loaded. Results are stored in RESLO, RESHI and SUMEXT = FFFF if result is
//   negative, SUMEXT = 0 otherwise. Result is also stored as Result variable.
//
//   ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//
//                MSP430F673x
//             -----------------
//         /|\|                 |
//          | |                 |
//          --|RST              |
//            |                 |
//            |                 |
//
//   M. Swanson
//   Texas Instruments Inc.
//   December 2011
//   Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

signed long result;                         // global variable for multiply
                                            // result

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    MPYS_B = 0x04;                          // Load first operand -signed mult
    OP2_B = 0x84;                           // Load second operand with byte
                                            // access to avoid need for sign ext

    result = RESHI;                         // Load RESHI word result
    result = (result << 16) | RESLO;        // Shift RESHI left and concat with
                                            // RESLO word result

    __bis_SR_register(LPM4_bits);           // Enter LPM4
    __no_operation();                       // For debugger
}

