//******************************************************************************
//   MSP430F673x Demo - MPY32, 8x8 Signed Multiply Accumulate
//
//   Description: Hardware multiplier is used to multiply two numbers.
//   The calculation is automatically initiated after the second operand is
//   loaded.  A second multiply accumulate operation is performed after that.
//   Results are stored in RESLO and RESHI. SUMEXT contains the extended sign of
//   result.
//
//   ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//
//                MSP430F673x
//             -----------------
//         /|\|                 |
//          | |                 |
//          --|RST              |
//            |                 |
//            |                 |
//
//   M. Swanson
//   Texas Instruments Inc.
//   December 2011
//   Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    MPY = 0x1234;                           // Load 1st operand - unsigned mult
    OP2 = 0x5678;                           // Load second operand

    MACS_B = 0x04;                          // Load first operand - signed MAC
    OP2_B = 0x84;                           // Load second operand with byte
                                            // access to avoid need for sign ext

    __bis_SR_register(LPM4_bits);           // Enter LPM4
    __no_operation();                       // For debugger
}

