//******************************************************************************
//  MSP430F673x Demo - Software Poll P1.4, Set P1.0 if P1.4 = 1
//
//  Description: Poll P1.4 in a loop, if high, P1.0 is set, if low, P1.0 reset.
//
//  ACLK = n/a, MCLK = SMCLK = default DCO
//
//               MSP430F673x
//            -----------------
//        /|\|              XIN|-
//         | |                 |
//         --|RST          XOUT|-
//     /|\   |                 |
//      --o--|P1.4         P1.0|-->LED
//     \|/
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    // Setup P1.0 output, P1.4 input
    P1DIR |= BIT0;                          // Set P1.0 to output direction
    P1OUT &= ~BIT0;                         // Clear P1.0

    while (1)                               // Test P1.4
    {
        if (P1IN & BIT4)
        {
            P1OUT |= BIT0;                  // if P1.4 set, set P1.0
        }
        else
        {
            P1OUT &= ~BIT0;                 // else reset P1.0
        }
    }
}

