//******************************************************************************
//  MSP430F673x Demo - Port Mapping, Port2; Single function to multiple pins;
//                     Single runtime configuration.
//
//  Description:  Port 2 is port mapped to output TimerA digital signals.
//  TACCR1-2 generate different PWM DutyCycles and have been output on multiple
//  Port2 pins.
//
//  ACLK = REFO~32kHz; MCLK = SMCLK = default DCO;
//
//               MSP430F673x
//            -----------------
//        /|\|                 |
//         | |                 |
//         --|RST              |
//           |    P2.0(TA0CCR1)|--> 25%
//           |    P2.1(TA0CCR1)|--> 25%
//           |    P2.2(TA0CCR2)|--> 50%
//           |    P2.3(TA0CCR2)|--> 50%
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

// Function definition
void Port_Mapping(void);

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    // Setup P2.x Port Mapping
    Port_Mapping();

    // Setup P2.x Pins
    P2DIR |= BIT0 | BIT1 | BIT2 | BIT3;     // P2.0 - P2.3 output
    P2SEL |= BIT0 | BIT1 | BIT2 | BIT3;     // P2.0 - P2.3 Port Map functions

    // Setup TA0
    TA0CCR0 = 128;                          // PWM Period/2
    TA0CCTL1 = OUTMOD_6;                    // CCR1 toggle/set
    TA0CCR1 = 96;                           // CCR1 PWM duty cycle
    TA0CCTL2 = OUTMOD_6;                    // CCR2 toggle/set
    TA0CCR2 = 64;                           // CCR2 PWM duty cycle
    TA0CTL = TASSEL_1 | MC_3;               // ACLK/2, up-down mode

    __bis_SR_register(LPM3_bits);           // Enter LPM3
    __no_operation();                       // For debugger
}

void Port_Mapping(void)
{
    __disable_interrupt();                  // Disable interrupts; Port Map cnfg
    PMAPKEYID = PMAPKEY;                    // Enable access Port Mapping regs

#ifdef PORT_MAP_RECFG
    PMAPCTL = PMAPRECFG;                    // Allow reconfig during runtime
#endif

    P2MAP0 = PM_TA0_1;                      // Enable TA0.0
    P2MAP1 = PM_TA0_1;                      // Enable TA0.0
    P2MAP2 = PM_TA0_2;                      // Enable TA0.1
    P2MAP3 = PM_TA0_2;                      // Enable TA0.1

    PMAPKEYID = 0;                          // Disable access Port Mapping regs
#ifdef PORT_MAP_EINT
    __enable_interrupt();                   // Re-enable all interrupts
#endif
}

