//*****************************************************************************
//  MSP430F673x Demo - SD24_B, Single Conversion on Single Channel Polling IFG
//
//  Description: This program uses the SD24_B module to perform a single
//  conversion on a single channel. The SD24_B interrupt flag for channel 2 is
//  polled to determine when a conversion has completed. Test by applying a
//  voltage to channel 2 (SD2P0, SD2N0) and setting a breakpoint at the line
//  indicated below. Run program until it reaches the breakpoint, then use the
//  debugger's watch window to view the conversion results. Results (upper 16
//  bits only) for channel 2 are stored in variable "results".
//  ACLK = n/a, MCLK = SMCLK = DCO =  ~ 1.1MHz
//  //* For minimum Vcc required for SD24_B module - see datasheet          *//
//  //* 100nF cap between Vref and AVss is recommended when using 1.5V REF  *//
//
//                MSP430F673x
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//    Vin+ -->|SD2P0            |
//    Vin- -->|SD2N0            |
//            |                 |
//            |            VREF |---+
//            |                 |   |
//            |                 |  -+- 100nF
//            |                 |  -+-
//            |                 |   |
//            |            AVss |---+
//            |                 |
//
//  M. Swanson
//  Texas Instruments, Inc
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//*****************************************************************************
#include <msp430.h>

/* Unsigned integer to store SD24_B conversion result */
unsigned int results;

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT

    SD24BCTL0 = SD24REFS | SD24SSEL_1;        // Select internal REF
                                              // Select SMCLK as SD24_B clock source

    SD24BCCTL2 |= SD24SNGL;                   // Single conversion

    __delay_cycles(0x3600);                   // Delay for 1.5V REF startup

    while (1)
    {
        SD24BCCTL2 |= SD24SC;                 // Set bit to start conversion
        while ((SD24BIFG & SD24IFG2) == 0) ;  // Poll interrupt flag for channel 2
        results = SD24BMEMH2;                 // Save CH2 results (clears IFG)
        __no_operation();                     // SET BREAKPOINT HERE
    }
}

