//*******************************************************************************
//  MSP430F673x Demo - Timer0_A0, PWM TA1.1-2, Up Mode, DCO SMCLK
//
//  Description: This program generates two PWM outputs on P1.1,P3.3 using
//  Timer0_A configured for up mode. The value in CCR0, 512-1, defines the PWM
//  period and the values in CCR1 and CCR2 the PWM duty cycles. Using ~1.045MHz
//  SMCLK as TACLK, the timer period is ~500us with a 75% duty cycle on P1.1
//  and 25% on P3.3.
//  ACLK = n/a, SMCLK = MCLK = TACLK = default DCO ~1.045MHz.
//
//              MSP430F673x
//            ---------------
//        /|\|               |
//         | |               |
//         --|RST            |
//           |               |
//           |     P1.1/TA0.1|--> CCR1 - 75% PWM
//           |     P3.3/TA0.2|--> CCR2 - 25% PWM
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>


int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    // Setup P1.1 TA0.1, P3.3 TA0.2
    P1DIR |= BIT1;                          // P1.1/TA0.1 output
    P1SEL |= BIT1;                          // Output TA1
    P3DIR |= BIT3;                          // P3.3/TA0.2 output
    P3SEL |= BIT3;                          // Output TA2

    // Setup TA0
    TA0CCR0 = 512 - 1;                      // PWM Period
    TA0CCTL1 = OUTMOD_7;                    // CCR1 reset/set
    TA0CCR1 = 384;                          // CCR1 PWM duty cycle
    TA0CCTL2 = OUTMOD_7;                    // CCR2 reset/set
    TA0CCR2 = 128;                          // CCR2 PWM duty cycle
    TA0CTL = TASSEL_2 | MC_1 | TACLR;       // SMCLK, up mode, clear TAR

    __bis_SR_register(LPM0_bits);           // Enter LPM0
    __no_operation();                       // For debugger
}

