//******************************************************************************
//  MSP430F673x Demo - Timer1_A1, Toggle P8.4/TA1.0, Up Mode, 32kHz ACLK
//
//  Description: Toggle P8.4 using hardware TA1.0 output. Timer1_A is configured
//  for up mode with CCR0 defining period, TA1.0 also output on P8.4. In this
//  example, CCR0 is loaded with 10-1 and TA1.0 will toggle P8.4 at TACLK/10.
//  Thus the output frequency on P8.4 will be the TACLK/20. No CPU or software
//  resources required. Normal operating mode is LPM3.
//  As coded with TACLK = ACLK, P8.4 output frequency = 32768/20 = 1.6384kHz.
//  ACLK = TACLK = 32kHz, MCLK = default DCO ~1.045MHz
//
//              MSP430F673x
//            ---------------
//        /|\|               |
//         | |               |
//         --|RST            |
//           |               |
//           |     P8.4/TA1.0|--> ACLK/20
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    // Setup P8.4 TA1.0
    P8DIR |= BIT4;                          // P8.4/TA1.0 output
    P8SEL |= BIT4;                          // Output TA0

    // Setup LFXT1
    UCSCTL6 &= ~(XT1OFF);                   // XT1 On
    UCSCTL6 |= XCAP_3;                      // Internal load cap
    // Loop until XT1 fault flag is cleared
    do
    {
        UCSCTL7 &= ~(XT2OFFG | XT1LFOFFG | DCOFFG);
        // Clear XT2,XT1,DCO fault flags
        SFRIFG1 &= ~OFIFG;                  // Clear fault flags
    } while (SFRIFG1 & OFIFG);              // Test oscillator fault flag

    // Setup TA1
    TA1CCTL0 = OUTMOD_4;                    // CCR0 toggle mode
    TA1CCR0 = 10 - 1;
    TA1CTL = TASSEL_1 | MC_1 | TACLR;       // ACLK, upmode, clear TAR

    __bis_SR_register(LPM3_bits);           // Enter LPM3
    __no_operation();                       // For debugger
}

