//******************************************************************************
//  MSP430F673x Demo - Timer1_A1, Toggle P8.4/TA1.0, Up/Down Mode, DCO SMCLK
//
//  Description: Toggle P8.4 using hardware TA1.0 output. Timer1_A is configured
//  for up/down mode with CCR0 defining period, TA1.0 also output on P8.4. In
//  this example, CCR0 is loaded with 250 and TA1.0 will toggle P8.4 at
//  TACLK/2*250. Thus the output frequency on P8.4 will be the TACLK/1000.
//  No CPU or software resources required.
//  As coded with TACLK = SMCLK, P8.4 output frequency is ~1.045M/1000.
//  SMCLK = MCLK = TACLK = default DCO ~1.045MHz
//
//              MSP430F673x
//            ---------------
//        /|\|               |
//         | |               |
//         --|RST            |
//           |               |
//           |     P8.4/TA1.0|--> SMCLK/1000
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    // Setup P8.4 TA1.0
    P8DIR |= BIT4;                          // P8.4/TA1.0 output
    P8SEL |= BIT4;                          // Output TA0

    // Setup TA1
    TA1CCTL0 = OUTMOD_4;                    // CCR0 toggle mode
    TA1CCR0 = 250;
    TA1CTL = TASSEL_2 | MC_3 | TACLR;       // SMCLK, up-downmode, clear TAR

    __bis_SR_register(LPM0_bits);           // Enter LPM0
    __no_operation();                       // For debugger
}

