//******************************************************************************
//  MSP430F673x Demo - Timer1_A1, PWM TA1.1, Up/Down Mode, DCO SMCLK
//
//  Description: This program generates a PWM output on P8.5 using
//  Timer1_A configured for up/down mode. The value in CCR0, 128, defines the
//  PWM period/2 and the value in CCR1 the PWM duty cycle. Using
//  ~1.045MHz SMCLK as TACLK, the timer period is ~233us with a 75% duty cycle
//  on P8.5.
//  SMCLK = MCLK = TACLK = default DCO ~1.045MHz.
//
//              MSP430F673x
//            ---------------
//        /|\|               |
//         | |               |
//         --|RST            |
//           |               |
//           |     P8.5/TA1.1|--> CCR1 - 75% PWM
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    // Setup P8.5 TA1.1
    P8DIR |= BIT5;                          // P8.5/TA1.1 output
    P8SEL |= BIT5;                          // Output TA1

    // Setup TA1
    TA1CCR0 = 128;                          // PWM Period/2
    TA1CCTL1 = OUTMOD_6;                    // CCR1 toggle/set
    TA1CCR1 = 32;                           // CCR1 PWM duty cycle
    TA1CTL = TASSEL_2 | MC_3 | TACLR;       // SMCLK, up-down mode, clear TAR

    __bis_SR_register(LPM0_bits);           // Enter LPM0
    __no_operation();                       // For debugger
}

