//*******************************************************************************
//  MSP430F673x Demo - Timer2_A2, PWM TA2.1, Up/Down Mode, DCO SMCLK
//
//  Description: This program generates a PWM output on P8.7 using
//  Timer2_A configured for up/down mode. The value in CCR0, 128, defines the
//  PWM period/2 and the values in CCR1 and CCR2 the PWM duty cycles. Using
//  ~1.045MHz SMCLK as TACLK, the timer period is ~233us with a 75% duty cycle
//  on P8.7.
//  SMCLK = MCLK = TACLK = default DCO ~1.045MHz.
//
//              MSP430F673x
//            ---------------
//        /|\|               |
//         | |               |
//         --|RST            |
//           |               |
//           |     P8.7/TA2.1|--> CCR1 - 75% PWM
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    // Setup P8.7 TA2.1
    P8DIR |= BIT7;                          // P8.7/TA2.1
    P8SEL |= BIT7;                          // Output TA1

    // Setup TA2
    TA2CCR0 = 128;                          // PWM Period/2
    TA2CCTL1 = OUTMOD_6;                    // CCR1 toggle/set
    TA2CCR1 = 32;                           // CCR1 PWM duty cycle
    TA2CTL = TASSEL_2 | MC_3 | TACLR;       // SMCLK, up-down mode, clear TAR

    __bis_SR_register(LPM0_bits);           // Enter LPM0
    __no_operation();                       // For debugger
}

