//******************************************************************************
//  MSP430F673x Demo - UCS, Software Toggle P1.0 at Default DCO
//
//  Description: Toggle P1.0 by xor'ing P1.0 inside of a software loop.
//  ACLK is brought out on pin P11.0, SMCLK is brought out on P11.2, and MCLK
//  is brought out on pin P11.1.
//  ACLK = REFO = 32.768kHz, MCLK = SMCLK = (Default DCO)/2 = (2MHz/2) = 1MHz
//
//                MSP430F673x
//             -----------------
//         /|\|                 |
//          | |             PJ.3|-->ACLK
//          --|RST          PJ.1|-->MCLK
//            |             PJ.0|-->SMCLK
//            |                 |
//            |             P1.0|-->LED
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT

    // Setup P1.0 output, J1.0 SMCLK, J1.1 MCLK, J1.3 ACLK
    P1DIR |= BIT0;                          // Set P1.0 to output direction
    P1OUT &= ~BIT0;                         // Clear P1.0
    PJDIR |= BIT0 | BIT1 | BIT3;            // ACLK, MCLK, SMCLK set out to pins
    PJSEL |= BIT0 | BIT1 | BIT3;            // PJ.0,1,3 for debugging purposes.

    while (1)
    {
        P1OUT ^= BIT0;                      // Toggle P1.0
        __delay_cycles(60000);              // Delay
    }
}

