//******************************************************************************
//  MSP430F673x Demo - UCS, VLO sources ACLK. Toggles P1.0
//
//  Description: This program demonstrates using VLO to source ACLK
//  ACLK = VLO = ~12kHz
//
//                MSP430F673x
//             -----------------
//         /|\|                 |
//          | |                 |
//          --|RST              |
//            |                 |
//            |             PJ.3|--> ACLK = ~10kHz
//            |                 |
//            |             P1.0|-->LED
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
    WDTCTL = WDT_ADLY_250;                  // WDT ~1000ms, ACLK, interval timer
    SFRIE1 |= WDTIE;                        // Enable WDT interrupt

    // Setup P1.0 output, J1.3 ACLK
    P1DIR |= BIT0;                          // Set P1.0 to output direction
    P1OUT &= ~BIT0;                         // Clear P1.0
    PJDIR |= BIT3;                          // ACLK set out to pin
    PJSEL |= BIT3;                          // PJ.3 for debugging purposes.

    // Setup UCS
    UCSCTL4 |= SELA_1;                      // VLO Clock Sources ACLK

    __bis_SR_register(LPM3_bits | GIE);     // Enter LPM3 w/ interrupts
    __no_operation();                       // For debugger
}

// Watchdog Timer interrupt service routine
#pragma vector = WDT_VECTOR
__interrupt void watchdog_timer(void)
{
    P1OUT ^= BIT0;                          // Toggle P1.0 using exclusive-OR
}

