//******************************************************************************
//  MSP430F673x Demo - Reset on Invalid Address fetch, Toggle P1.0
//
//  Description: This program demonstrates how a reset is executed if the CPU
//  tries to fetch instructions from within the module register memory address
//  range (0x0100 --0x0FEF) or from within unused address ranges. Toggle P1.0
//  by xor'ing P1.0 inside of a software loop that ends with TAR loaded with
//  3FFFh - op-code for "jmp $". This simulates a code error. The MSP430
//  will force a reset because it will not allow a fetch from within the address
//  range of the peripheral memory, as is seen by return to the main loop and
//  LED flash.
//  ACLK = n/a, MCLK = SMCLK = default DCO ~1.045MHz
//
//                MSP430F673x
//             -----------------
//         /|\|                 |
//          | |                 |
//          --|RST              |
//            |                 |
//            |             P1.0|-->LED
//
//  M. Swanson
//  Texas Instruments Inc.
//  December 2011
//  Built with CCS Version: 5.1.0 and IAR Embedded Workbench Version: 5.40.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
    WDTCTL = WDTPW | WDTHOLD;               // Stop WDT - SET BREAKPOINT HERE

    // Setup P1.0 output
    P1DIR |= BIT0;                          // Set P1.0 to output direction

    TA0R = 0x3FFF;                          // Valid opcode (for "jmp $")

    while (1)
    {
        P1OUT ^= BIT0;                      // Toggle P1.0 using exclusive-OR

        __delay_cycles(50000);              // Delay loop

        // C code to directly call an address location
        ((void (*)()) 0x350)();             // Invalid fetch ("call #0350h")

        /* 0x350 is address of TA0R register and is within the module register
         * memory address range (0x0100 --0x0FEF) */
    }
}

