//******************************************************************************
//   MSP430FR57xx Demo - Stay in active mode with MCLK = 8MHz
//
//   Description: Configure ACLK = VLO, MCLK = 8MHz. 
//   The ACTIVE_MODE_TEST function is intended to mimic a typical cache hit
//   ratio for a real world application. The code itself is a combination of
//   move, jump and math operations performed in an infinite loop.
//   The active power for a typical cache hit ratio using MCLK=8MHz is measured
//
//           MSP430FR57x
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |               |
//        |               |
//
//   Priya Thanigai
//   Texas Instruments Inc.
//   August 2010
//   Built with IAR Embedded Workbench Version: 5.10 & Code Composer Studio V4.0
//******************************************************************************

#include <msp430.h>
void ACTIVE_MODE_TEST(void);

int main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Stop WDT

  P1DIR = 0;
  P1OUT = 0;
  P1REN = 0xFF;

  P2DIR = 0;
  P2OUT = 0;
  P2REN = 0xFF;

  P3DIR = 0;
  P3OUT = 0;
  P3REN = 0xFF;

  P4DIR = 0;
  P4OUT = 0;
  P4REN = 0xFF;

  PJDIR = 0xFF;
  PJOUT = 0;

  CSCTL0_H = 0xA5;
  CSCTL1 |= DCOFSEL0 + DCOFSEL1;            // Set max. DCO setting
  CSCTL2 = SELA_0 + SELS_3 + SELM_3;        // ACLK = VLO
  CSCTL3 = DIVA_0 + DIVS_0 + DIVM_0;        // MCLK = SMCLK = DCO


  ACTIVE_MODE_TEST();                       // Endless loop

}

// This function executes the active mode power test.
void ACTIVE_MODE_TEST(void)
{
  __asm("IDD_AM_L:                                ");
  __asm("            MOV     #0x2000, R4          ");
  __asm("            MOV     #0x4, 0(R4)          ");
  __asm("            MOV     &0x2000, &0x2002     ");
  __asm("            ADD     @R4, 2(R4)           ");
  __asm("            SWPB    @R4+                 ");
  __asm("            MOV     @R4, R5              ");
  __asm("IDD_AM_L1:                               ");
  __asm("            XOR     @R4+, &0x2020        ");
  __asm("            DEC     R5                   ");
  __asm("            JNZ     IDD_AM_L1            ");
  __asm("            XOR.B   #0x01, &0x0202       ");
  __asm("            JMP     IDD_AM_L             ");
}
