//******************************************************************************
//   MSP430F59xx Demo - eUSCI_A0, SPI 3-Wire Slave Data Echo
//
//   Description: SPI slave talks to SPI master using 3-wire mode. Data received
//   from master is echoed back.
//   ACLK = 32.768kHz, MCLK = SMCLK = DCO ~ 1MHz
//   Note: Ensure slave is powered up before master to prevent delays due to
//   slave init.
//
//
//                   MSP430FR5969
//                 -----------------
//            /|\ |                 |
//             |  |                 |
//            -+->|                 |
//                |                 |
//                |             P2.0|-> Data Out (UCA0SOMI)
//                |                 |
//                |             P2.1|<- Data In (UCA0SIMO)
//                |                 |
//                |             P1.5|-> Serial Clock Out (UCA0CLK)
//
//
//   P. Thanigai
//   Texas Instruments Inc.
//   Feb 2012
//   Built with CCS V5.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW+WDTHOLD;                   // Stop watchdog timer

  // XT1 Setup
  PJSEL0 |= BIT4 + BIT5;

  CSCTL0_H = 0xA5;
  CSCTL1 = DCOFSEL_0;                      // Set DCO= 1MHz
  CSCTL1 &= ~DCORSEL;
  CSCTL2 = SELA__LFXTCLK + SELS__DCOCLK + SELM__DCOCLK;
  CSCTL3 = DIVA__1 + DIVS__1 + DIVM__1;     // set all dividers
  CSCTL4 |= LFXTDRIVE_0;
  CSCTL4 &= ~LFXTOFF;

  do
  {
    CSCTL5 &= ~LFXTOFFG;
                                            // Clear XT1 fault flag
    SFRIFG1 &= ~OFIFG;
  }while (SFRIFG1&OFIFG);                   // Test oscillator fault flag

  // Configure SPI pins
  P1SEL1 |= BIT5;
  P2SEL1 |= BIT0 + BIT1;


  UCA0CTLW0 |= UCSWRST;                     // **Put state machine in reset**
  UCA0CTLW0 |= UCSYNC+UCCKPL+UCMSB;         // 3-pin, 8-bit SPI slave
                                            // Clock polarity high, MSB
  UCA0CTLW0 |= UCSSEL_2;                    // ACLK
  UCA0BR0 = 0x02;                           // /2
  UCA0BR1 = 0;                              //
  UCA0MCTLW = 0;                            // No modulation
  UCA0CTLW0 &= ~UCSWRST;                    // **Initialize USCI state machine**
  UCA0IE |= UCRXIE;                         // Enable USCI_A0 RX interrupt

  __bis_SR_register(LPM0_bits + GIE);       // Enter LPM0, enable interrupts



}

#pragma vector=USCI_A0_VECTOR
__interrupt void USCI_A0_ISR(void)
{
  while (!(UCA0IFG&UCTXIFG));               // USCI_A0 TX buffer ready?
    UCA0TXBUF = UCA0RXBUF;                  // Echo received data
}
