//******************************************************************************
//   MSP430FR59xx Demo - Configure MCLK for 16MHz operation
//
//   Description: Configure SMCLK = MCLK = 16MHz
//   IMPORTANT NOTE: While the FR5739 is capable of operation w/ MCLK = 16MHz
//   the throughput of the device is dependent on accesses to FRAM.
//   The maximum speed for accessing FRAM is limited to 8MHz*.
//   Wait states are inserted automatically when the FRAM is accessed at
//   speeds higher than 8MHz to prevent timing violations.
//   Refer to the FRCTL chapter of the User's Guide.
//   * Refer device D/s for typical numbers
//
//           MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |               |
//        |          P3.4 |---> SMCLK = MCLK = 16MHz
//
//   T. Witt/ P. Thanigai
//   Texas Instruments Inc.
//   November 2011
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.1
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT

  CSCTL0_H = 0xA5;
  CSCTL1 = DCORSEL | DCOFSEL_4;             // Set max. DCO setting
  CSCTL2 = SELS__DCOCLK | SELM__DCOCLK;     // set SMCLK = MCLK = DCO
  CSCTL3 = DIVS__1 | DIVM__1;               // set all dividers
  CSCTL0_H = 0;

  P3OUT = 0;                                // output SMCLK
  P3DIR |= BIT4;
  P3SEL1 |= BIT4;

  while(1);

}
