//******************************************************************************
//   MSP430FR59xx Demo - ACLK = XT1 = 32768Hz, SMCLK= XT2 = 8MHz, MCLK = DCO
//
//   Description: Configure ACLK = LFXT, SMCLK = HFXT and MCLK = DCO
//   NOTE1: 32768Hz and 8MHz crystals required!
//
//           MSP430FR59x
//         ---------------
//     /|\|               |
//      | |               |-LFXIN
//      --|RST            |-LFXOUT
//        |               |
//        |               |-HFXIN
//        |               |-HFXOUT
//        |               |
//        |          P2.0 |--->ACLK = 32768 Hz
//        |          P3.4 |--->SMCLK = 8MHz
//
//   P. Thanigai
//   Texas Instruments Inc.
//   August 2012
//   Built with IAR Embedded Workbench V5.40 & Code Composer Studio V5.2
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;

  // XT1, XT2 Setup
  PJSEL0 |= BIT4 | BIT5 | BIT6 | BIT7;

  CSCTL0_H = 0xA5;
  CSCTL1 = DCOFSEL_6;                       // Set DCO= 8MHz
  CSCTL2 = SELA__LFXTCLK | SELS__HFXTCLK | SELM__DCOCLK;
  CSCTL3 = DIVA__1 | DIVS__1 | DIVM__1;     // set all dividers
  CSCTL4 |= LFXTDRIVE_3 | HFXTDRIVE_3;
  CSCTL4 &= ~(LFXTOFF | HFXTOFF);

  do
  {
    CSCTL5 &= ~(LFXTOFFG | HFXTOFFG);
                                            // Clear XT1 fault flag
    SFRIFG1 &= ~OFIFG;
  }while (SFRIFG1&OFIFG);                   // Test oscillator fault flag

 // Output ACLK, SMCLK
  P2DIR |= BIT0;
  P2SEL0 |= BIT0;
  P2SEL1 |= BIT0;

  P3DIR |= BIT4;
  P3SEL0 |= BIT4;
  P3SEL1 |= BIT4;


 while(1);

}



