//******************************************************************************
//   MSP430FR59xx Demo - Using LFXT in bypass mode, failsafe operation shown
//
//   Description: ACLK is sourced from LFXT configured in bypass mode.
//   An external 32768 Hz digital input  signal is required for this example.
//   When the signal is removed, ACLK defaults to LFMODOSC = 5MHz/128
//   The LED stays ON until fault condition remains.
//   Once the fault is fixed, LED goes OFF and ACLK is restored back to the
//   digital input.
//
//   IMPORTANT NOTE: The MSP-TS430RGZC Rev1.1 (FET Target board) has a wiring
//   defect.
//   When using this board the digital clock input needs to be given to the
//   LFXOUT (pin 46) instead of the LFXIN pin
//   For any other hardware that is correctly wired, the digital bypass input
//   is given to LFXTIN pin as expected.
//
//ACLK = 32kHz, MCLK = SMCLK = 1MHz
//
//           MSP430FR59x
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |          PJ.4 |<-- External 32768Hz required!
//        |          P2.0 |--->ACLK
//        |          P1.0 |--->LED
//
//   P. Thanigai
//   Texas Instruments Inc.
//   August 2012
//   Built with IAR Embedded Workbench V5.40 & Code Composer Studio V5.2
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;
  // LED setup
  P1OUT = 0;
  P1DIR |= BIT0;
  // Output ACLK
  P2SEL0 |= BIT0;
  P2SEL1 |= BIT0;
  P2DIR |= BIT0;
  // XT1 Setup
  PJSEL0 |= BIT4;
  PJSEL1 &= ~BIT4;

  CSCTL0_H = 0xA5;
  CSCTL1 = DCOFSEL_0;                       // Set DCO= 1MHz
  CSCTL2 = SELA__LFXTCLK + SELS__DCOCLK + SELM__DCOCLK;
  CSCTL3 = DIVA__1 + DIVS__1 + DIVM__1;     // set all dividers
  CSCTL4 |= LFXTBYPASS+HFXTOFF+LFXTOFF;

  do
  {
    CSCTL5 &= ~LFXTOFFG;                    // Clear XT1 fault flag
    SFRIFG1 &= ~OFIFG;
  }while (SFRIFG1&OFIFG);                   // Test oscillator fault flag

  // Now that osc is running enable fault interrupt
  SFRIE1 |= OFIE;

  __bis_SR_register(LPM0_bits);             // Wait in LPM0 for fault flag
  __no_operation();

}

#pragma vector=UNMI_VECTOR
__interrupt void UNMI_ISR(void)
{
    do
  {
    // set a breakpoint on the line below to observe XT1 operating from LFMODOSC
    // when the breakpoint is hit during a crystal fault
    CSCTL5 &= ~LFXTOFFG;                    // Clear XT1 fault flag
    SFRIFG1 &= ~OFIFG;
    P1OUT |= BIT0;
    __delay_cycles(25000);                  // time for flag to get set again
  }while (SFRIFG1&OFIFG);                   // Test oscillator fault flag

  P1OUT &= ~BIT0;


}
