//******************************************************************************
//  MSP430FR59x Demo - MPU Write protection violation - PUC
//
//  Description: The MPU segment boundaries are defined by:
//  Border 1 = 0x6000 [MPUSEGB1 = 0x0600]
//  Border 2 = 0x8000 [MPUSEGB2 = 0x0800]
//  Segment 1 = 0x4400 - 0x5FFF
//  Segment 2 = 0x6000 - 0x7FFF
//  Segment 3 = 0x8000 - 0x13FFF
//  Segment 2 is write protected. Any write to an address in the segment 2 range
//  causes a PUC. The LED toggles after reset once MPUSEG2IFG is set. A delay is included
//  so the debugger can gain access via JTAG.
//
//  ACLK = n/a, MCLK = default DCO = 1MHz
//
//
//           MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |           P1.0|-->LED
//
//   T. Witt/ P. Thanigai
//   Texas Instruments Inc.
//   February 2012
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.1
//******************************************************************************

#include <msp430.h>


unsigned int *ptr = 0;
unsigned int Data =0;

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT

  // Use this trap loop when connecting to the debugger
  // Tie P1.2 high
  // If P1.2 is floating code execution continues
  P1DIR &= ~BIT2;                           // P1.2 Input
  P1REN |= BIT2;
  if(P1IN & BIT2)
  {
	while(1);
  }


  P1DIR |= BIT0;                            // Configure P1.0 for LED

  while (MPUCTL1 & MPUSEG2IFG)                 // has reset occured due to Seg2
  {
    P1OUT ^= BIT0;                          // Toggle LED
    __delay_cycles(30000);                    // Delay to see toggle
  }
  // Configure MPU
  MPUCTL0 = MPUPW;                          // Write PWD to access MPU registers
  MPUSEGB1 = 0x0600;                        // B1 = 0x6000; B2 = 0x8000
  MPUSEGB2 = 0x0800;                        // Borders are assigned to segments
  MPUSAM &= ~MPUSEG2WE;                     // Segment 2 is protected from write
  MPUSAM |= MPUSEG2VS;                      // Violation select on write access

  MPUCTL0 = MPUPW + MPUENA ;                // Enable MPU protection

  Data = 0x88;

  // Cause an MPU violation by writing to segment 2
  ptr = (unsigned int  *)0x6002;
  *ptr = Data;

  while(1);                                 // Code never gets here

}
