//******************************************************************************
//  MSP430FR59xx Demo - WDT, Toggle P1.0, Interval Overflow ISR, DCO SMCLK
//
//  Description: Toggle P1.0 using software timed by the WDT ISR. Toggle rate
//  is approximately 30ms = {(1MHz) / 32768} based on DCO = 8MHz
//  clock source used in this example for the WDT.
//  ACLK = n/a, SMCLK = 1MHz
//
//                MSP430FR5969
//             -----------------
//         /|\|                 |
//          | |                 |
//          --|RST              |
//            |                 |
//            |             P1.0|-->LED
//
//   T. Witt/ P. Thanigai
//   Texas Instruments Inc.
//   November 2011
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.1
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTSSEL__SMCLK | WDTTMSEL | WDTCNTCL | WDTIS__32K;


  CSCTL0_H = 0xA5;
  CSCTL1 |= DCORSEL;
  CSCTL1 |= DCOFSEL_3;                      // Set DCO = 8MHz
  CSCTL2 = SELA__VLOCLK | SELS__DCOCLK | SELM__DCOCLK;// set ACLK = VLO MCLK = DCO
  CSCTL3 = DIVA__1 + DIVS__8 + DIVM__8;     // set all dividers
  CSCTL0_H = 0;

  SFRIE1 |= WDTIE;                          // Enable WDT interrupt
  P1DIR |= BIT0;                            // Set P1.0 to output direction

  __bis_SR_register(LPM0_bits + GIE);       // Enter LPM0, enable interrupts
  __no_operation();                         // For debugger
}

// Watchdog Timer interrupt service routine
#pragma vector=WDT_VECTOR
__interrupt void WDT_ISR(void)
{
  P1OUT ^= BIT0;                            // Toggle P1.0 (LED)
}
