//******************************************************************************
//   MSP430FR59xx Demo - Stay in active mode with MCLK = 8MHz
//
//   Description:
//   The ACTIVE_MODE_TEST function is intended to mimic a typical cache hit
//   ratio for a real world application. The code itself is a combination of
//   move, jump and math operations performed in an infinite loop.
//   The active power for a typical cache hit ratio using MCLK=8MHz is measured
//
//   ACLK = VLO, MCLK = SMCLK = 8MHz
//
//
//          MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |               |
//        |          P1.0 |---> Disconnect JP9 for power meas.
//
//   T. Witt/ P. Thanigai
//   August 2012
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.2
//******************************************************************************

#include <msp430.h>

void ACTIVE_MODE_TEST(void);

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT

  P1DIR = 0;
  P1OUT = 0;
  P1REN = 0xFF;

  P2DIR = 0;
  P2OUT = 0;
  P2REN = 0xFF;

  P3DIR = 0;
  P3OUT = 0;
  P3REN = 0xFF;

  P4DIR = 0;
  P4OUT = 0;
  P4REN = 0xFF;

  PJDIR = 0xFF;
  PJOUT = 0;

  CSCTL0_H = 0xA5;
  CSCTL1 = DCOFSEL_6;                       // Set DCO setting for 8MHz
  CSCTL1 &= ~DCORSEL;
  CSCTL2 = SELA__VLOCLK | SELS__DCOCLK | SELM__DCOCLK;
  CSCTL3 = DIVA__1 | DIVS__1 | DIVM__1;     // MCLK = SMCLK = DCO = 8MHz
  CSCTL0_H = 0;

  // Endless loop. Function never returns...
  ACTIVE_MODE_TEST();
}

// This function executes the active mode power test.
void ACTIVE_MODE_TEST(void)
{
  __asm("IDD_AM_L:                                ");
  __asm("            MOV     #0x2000, R4          ");
  __asm("            MOV     #0x4, 0(R4)          ");
  __asm("            MOV     &0x2000, &0x2002     ");
  __asm("            ADD     @R4, 2(R4)           ");
  __asm("            SWPB    @R4+                 ");
  __asm("            MOV     @R4, R5              ");
  __asm("IDD_AM_L1:                               ");
  __asm("            XOR     @R4+, &0x2020        ");
  __asm("            DEC     R5                   ");
  __asm("            JNZ     IDD_AM_L1            ");
  __asm("            XOR.B   #0x01, &0x0202       ");
  __asm("            JMP     IDD_AM_L             ");
}
