//******************************************************************************
// MSP430FR59xx Demo - COMPE output Toggle in LPM4; input channel CE1;
//                     Vcompare is compared against internal 2.0V reference
//
// Description: Use CompE and internal reference to determine if input'Vcompare'
// is high or low.  When Vcompare exceeds 2.0V CEOUT goes high and when Vcompare
// is less than 2.0V then CEOUT goes low.
//
// Connect P3.5/CEOUT to P1.0 externally to see the LED toggle accordingly.
//
//
//
//                MSP430FR5969
//             ------------------
//         /|\|                  |
//          | |                  |
//          --|RST       P1.1/CE1|<--Vcompare
//            |                  |
//            |        P3.5/CEOUT|----> 'high'(Vcompare>2.0V); 'low'(Vcompare<2.0V)
//            |                  |  |
//            |              P1.0|__| LED 'ON'(Vcompare>2.0V); 'OFF'(Vcompare<2.0V)
//            |                  |
//
//   Tyler Witt / Priya Thanigai
//   Texas Instruments Inc.
//   August 2012
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.2
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT
  P3DIR  |= BIT5;                           // P3.5 output direction
  P3SEL1 |= BIT5;                           // Select CEOUT function on P3.5/CEOUT

  // Setup ComparatorE
  CECTL0 |= CEIPEN | CEIPSEL_1;             // Enable V+, input channel CE1
  CECTL1 |= CEPWRMD_1;                      // normal power mode
  CECTL2 |= CERSEL;                         // VREF is applied to -terminal
  CECTL2 |= CERS_3 | CEREFL_2;              // R-ladder off; bandgap ref voltage (1.2V)
                                            // supplied ref amplifier to get Vcref=2.0V (CEREFL_2)
  CECTL3 |= BIT1;                           // Input Buffer Disable @P1.1/CE1
  CECTL1 |= CEON;                           // Turn On ComparatorE

  __delay_cycles(75);                       // delay for the reference to settle

  __bis_SR_register(LPM4_bits);             // Enter LPM4
  __no_operation();                         // For debug
}
