//******************************************************************************
// MSP430FR59xx Demo - COMPE Toggle from LPM4; CompE in ultra low power mode
// 		               Vcompare is compared against the Vcc*1/2
//
// Description: Use CompE and shared reference to determine if input 'Vcompare'
//    is high or low.  When Vcompare exceeds Vcc*1/2 CEOUT goes high and when
//    Vcompare is less than Vcc*1/2 then CEOUT goes low.
//    Connect P3.0/CEOUT to P1.0 externally to see the LED toggle accordingly.
//
//                MSP430FR5969
//             ------------------
//         /|\|                  |
//          | |                  |
//          --|RST       P1.1/CE1|<--Vcompare
//            |                  |
//            |        P3.5/CEOUT|----> 'high'(Vcompare>Vcc*1/2); 'low'(Vcompare<Vcc*1/2)
//            |                  |  |
//            |            P1.0  |__| LED 'ON'(Vcompare>Vcc*1/2); 'OFF'(Vcompare<Vcc*1/2)
//            |                  |
//
//   Tyler Witt/ Priya Thanigai
//   Texas Instruments Inc.
//   August 2012
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.2
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT
  P3DIR  |= BIT5;                           // P3.5CEOUT output direction
  P3SEL1 |= BIT5;                           // Select CEOUT function on P3.5/CEOUT

  // Setup ComparatorE
  CECTL0 |= CEIPEN | CEIPSEL_1;             // Enable V+, input channel CE01
  CECTL1 |= CEMRVS;                         // CMRVL selects the refV - VREF0
  CECTL1 |= CEPWRMD_2;                      // Ultra-Low Power mode
  CECTL2 |= CERSEL;                         // VREF is applied to -terminal
  CECTL2 |= CERS_1 | CEREF04;               // VCC applied to R-ladder; VREF0 is Vcc*1/2
  CECTL3 |= BIT1;                           // Input Buffer Disable @P1.1/CE1
  CECTL1 |= CEON;                           // Turn On ComparatorE

  __delay_cycles(75);                       // delay for the reference to settle

  __bis_SR_register(LPM0_bits);             // Enter LPM4
  __no_operation();                         // For debug
}
