//******************************************************************************
//  MSP430FR59x Demo - COMPE Hysteresis, COUT Toggle in LPM4; High speed mode
//
//  Description: Use CompE and shared reference to determine if input 'Vcompare'
//  is high or low.  Shared reference is configured to generate hysteresis.
//  When Vcompare exceeds Vcc*3/4 COUT goes high and when Vcompare is less
//  than Vcc*1/4 then COUT goes low.
//  Connect P3.5/COUT to P1.0 externally to see the LED toggle accordingly.
//
//                MSP430FR5969
//             ------------------
//         /|\|                  |
//          | |                  |
//          --|RST       P1.1/CE1|<--Vcompare
//            |                  |
//            |        P3.5/COUT |----> 'high'(Vcompare>Vcc*3/4); 'low'(Vcompare<Vcc*1/4)
//            |                  |  |
//            |            P1.0  |__| LED 'ON'(Vcompare>Vcc*3/4); 'OFF'(Vcompare<Vcc*1/4)
//            |                  |
//
//   Tyler Witt/ Priya Thanigai
//   Texas Instruments Inc.
//   August 2012
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.2
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT
  P3DIR  |= BIT5;                           // P3.0CEOUT output direction
  P3SEL1 |= BIT5;                           // Select CEOUT function on P3.0/CEOUT

  // Setup ComparatorE

  CECTL0 |= CEIPEN | CEIPSEL_1;             // Enable V+, input channel CE1
  CECTL1 |= CEPWRMD_0;                      // CEMRVS=0 => select VREF1 as ref when CEOUT
                                            // is high and VREF0 when CEOUT is low
                                            // High-Speed Power mode
  CECTL2 |= CERSEL;                         // VRef is applied to -terminal
  CECTL2 |= CERS_1 | CEREF13;               // VREF1 is Vcc*1/4
  CECTL2 |= CEREF04 | CEREF03;              // VREF0 is Vcc*3/4
  CECTL3 |= BIT1;                           // Input Buffer Disable @P1.1/CE1
  CECTL1 |= CEON;                           // Turn On ComparatorE

  __delay_cycles(75);                       // delay for the reference to settle

  __bis_SR_register(LPM0_bits);             // Go to LPM4
  __no_operation();                         // For debug
}
