//******************************************************************************
//  MSP430FR59xx Demo - USCI_A0 External Loopback test @ 115200 baud
//
//  Description: This demo connects TX to RX of the MSP430 UART
//  The example code shows proper initialization of registers
//  and interrupts to receive and transmit data. If data is incorrect P1.0 LED is
//  turned ON.
//  ACLK = n/a, MCLK = SMCLK = BRCLK = default DCO = 1MHz
//
//
//                MSP430FR5969
//
//             -----------------
//       RST -|     P2.0/UCA0TXD|----|
//            |                 |    |
//           -|                 |    |
//            |     P2.1/UCA0RXD|----|
//            |                 |
//
//   P. Thanigai
//   Texas Instruments Inc.
//   August 2012
//   Built with CCS V4 and IAR Embedded Workbench Version: 5.2
//******************************************************************************
#include <msp430.h>

unsigned char RXData = 0;
unsigned char TXData = 1;

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // stop watchdog

  // Configure UART pins
  P2SEL1 |= BIT0 + BIT1;
  P2SEL0 &= ~(BIT0 + BIT1);

  // Configure UART
  UCA0CTLW0 |= UCSWRST | UCSSEL__SMCLK;     // Put eUSCI in reset, select SMCLK
  UCA0BR0 = 8;                              // 1000000/115200 = 8.68
  UCA0MCTLW |= 0xD600;                      // 1000000/115200 - INT(1000000/115200)=0.68
                                            // UCBRSx value = 0xD6 (See UG)
  UCA0BR1 = 0;
  UCA0CTL1 &= ~UCSWRST;                     // release from reset
  UCA0IE |= UCRXIE;                         // enable RX interrupt

  while (1)
  {

    while(!(UCA0IFG & UCTXIFG));
    UCA0TXBUF = TXData;                     // Load data onto buffer

    __bis_SR_register(LPM0_bits+GIE);       // Enter LPM0
  }
}


#pragma vector=USCI_A0_VECTOR
__interrupt void USCI_A0_ISR(void)
{
  switch(__even_in_range(UCA0IV,USCI_UART_UCTXCPTIFG))
  {
    case USCI_NONE: break;
    case USCI_UART_UCRXIFG:
    	  UCA0IFG &=~ UCRXIFG;              // Clear interrupt
    	  RXData = UCA0RXBUF;               // Clear buffer
    	  if(RXData != TXData)              // Check value
    	  {
    	      P1DIR |= BIT0;                // If incorrect turn on P1.0
    	      P1OUT |= BIT0;
    		  while(1);                     //trap CPU
    	  }
    	  TXData++;                         // increment data byte
    	  __bic_SR_register_on_exit(CPUOFF);// Exit LPM0 on reti
      break;
    case USCI_UART_UCTXIFG: break;
    case USCI_UART_UCSTTIFG: break;
    case USCI_UART_UCTXCPTIFG: break;
  }
}
