//******************************************************************************
//  MSP430FR59xx Demo - eUSCI_A0 External Loopback test
//
//  Description: This demo connects TX to RX of the MSP430 UART
//  The example code shows proper initialization of registers
//  and interrupts to receive and transmit data. If data is incorrect P1.0 LED is
//  turned ON.
//  ACLK = 32768Hz, MCLK = SMCLK = BRCLK = default DCO = ~1MHz
//
//
//                MSP430FR5969
//
//             -----------------
//       RST -|     P2.0/UCA0TXD|----|
//            |                 |    |
//           -|                 |    |
//            |     P2.1/UCA0RXD|----|
//            |                 |
//
//   P. Thanigai
//   Texas Instruments Inc.
//   August 2012
//   Built with CCS V4 and IAR Embedded Workbench Version: 5.2
//******************************************************************************
#include <msp430.h>

unsigned int i;
unsigned char RXData = 0;
unsigned char TXData = 1;
unsigned char check = 0;
int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // stop watchdog

  // XT1 Setup
  PJSEL0 |= BIT4 + BIT5;

  CSCTL0_H = 0xA5;
  CSCTL1 = DCOFSEL_0;                       // Set DCO= 1MHz
  CSCTL1 &= ~DCORSEL;
  CSCTL2 = SELA__LFXTCLK + SELS__DCOCLK + SELM__DCOCLK;
  CSCTL3 = DIVA__1 + DIVS__1 + DIVM__1;     // set all dividers
  CSCTL4 |= LFXTDRIVE_0;
  CSCTL4 &= ~LFXTOFF;

  do
  {
    CSCTL5 &= ~LFXTOFFG;
                                            // Clear XT1 fault flag
    SFRIFG1 &= ~OFIFG;
  }while (SFRIFG1&OFIFG);                   // Test oscillator fault flag

  // Configure UART pins
  P2SEL1 |= BIT0 + BIT1;
  P2SEL0 &= ~(BIT0 + BIT1);
  // Configure UART 0
  UCA0CTL1 |= UCSWRST;
  UCA0CTL1 = UCSSEL_1;                      // Set ACLK = 32768 as UCBRCLK
  UCA0BR0 = 3;                              // 9600 baud
  UCA0MCTLW |= 0x5300;                      // 32768/9600 - INT(32768/9600)=0.41
                                            // UCBRSx value = 0x53 (See UG)
  UCA0BR1 = 0;
  UCA0CTL1 &= ~UCSWRST;                     // release from reset
  UCA0IE |= UCRXIE;                         // enable RX interrupt

  while (1)
  {
    //TXData = TXData+1;                    // Increment TX data
    while(!(UCA0IFG & UCTXIFG));
    UCA0TXBUF = TXData;                     // Load data onto buffer

    __bis_SR_register(LPM0_bits+GIE);       // Enter LPM0
  }
}



#pragma vector = USCI_A0_VECTOR             // eUSCI ISR
__interrupt void USCI_A0_ISR(void)
{
  UCA0IFG &=~ UCRXIFG;                      // Clear interrupt
  RXData = UCA0RXBUF;                       // Clear buffer
  if(RXData != TXData)                      // Check value
  {
      P1DIR |= BIT0;                        // If incorrect turn on P1.0
      P1OUT |= BIT0;
	  while(1);                             //trap CPU
  }
  TXData++;                                 // increment data byte
  __bic_SR_register_on_exit(CPUOFF);        // Exit LPM0 on reti

}
