//******************************************************************************
//   MSP430FR59xx Demo - Long word writes to FRAM
//
//   Description: Use long word write to write to 512 byte blocks of FRAM.
//   Toggle LED after every 100 writes.
//   NOTE: Running this example for extended periods will impact the FRAM
//   endurance.
//   ACLK = VLO, MCLK = SMCLK = default DCO
//
//           MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |               |
//        |          P1.0 |---> LED
//
//   Priya Thanigai
//   Texas Instruments Inc.
//   August 2012
//   Built with IAR Embedded Workbench V5.40 & Code Composer Studio V5.2
//******************************************************************************
#include "msp430.h"

void FRAMWrite(void);

unsigned char count = 0;
unsigned long *FRAM_write_ptr;
unsigned long data;

#define FRAM_TEST_START 0xD000


int main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Stop WDT

  // Turn on LED
  P1DIR |= BIT0;
  // Initialize dummy data
  data = 0x00010001;

  while(1)
  {
  data ++;
  FRAM_write_ptr = (unsigned long *)FRAM_TEST_START;
  FRAMWrite();                              // Endless loop
  count++;
  if (count > 100)
    {
      P1OUT ^= 0x01;                        // Toggle LED to show 512K bytes
      count = 0;                            // ..have been written
      data = 0x00010001;
    }

  }

}


void FRAMWrite (void)

{
 unsigned int i=0;

  for ( i= 0; i<128; i++)
  {
    *FRAM_write_ptr++ = data;
  }

}


