//******************************************************************************
//   MSP430FR59xx Demo - Enters LPM0 with ACLK = LFXT, MCLK = 1MHz
//
//   Description: Configure ACLK = LFXT and enters LPM0.
//
//   NOTE: On the FET board: MSP-TS430RGZ48C drives an LED that can show high power numbers
//   when turned ON. Measure current with LED jumper JP9 disconnected.
//   LED jumper disconnected.
//
//   ACLK = LFXT, MCLK = SMCLK = 1MHz
//
//          MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |               |
//        |          P1.0 |---> Disconnect JP9 for power meas.
//
//   T. Witt/ P. Thanigai
//   Texas Instruments Inc.
//   November 2011
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.1
//******************************************************************************
#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTTMSEL | WDTSSEL_1 | WDTIS_5; // ACLK, ~1s interrupts
  SFRIE1 |= WDTIE;                          // Enable WDT interrupt
  P1DIR = 0;
  P1OUT = 0;
  P1REN = 0xFF;

  P2DIR = 0;
  P2OUT = 0;
  P2REN = 0xFF;

  P3DIR = 0;
  P3OUT = 0;
  P3REN = 0xFF;

  P4DIR = 0;
  P4OUT = 0;
  P4REN = 0xFF;

  PJDIR = 0xFF;
  PJOUT = 0;

  // XT1 Setup
  PJSEL0 |= BIT4 + BIT5;

  CSCTL0_H = 0xA5;
  CSCTL1 = DCOFSEL_0;                      // Set DCO= 1MHz
  CSCTL1 &= ~DCORSEL;
  CSCTL2 = SELA__LFXTCLK + SELS__DCOCLK + SELM__DCOCLK;
  CSCTL3 = DIVA__1 + DIVS__1 + DIVM__1;     // set all dividers
  CSCTL4 |= LFXTDRIVE_0;
  CSCTL4 &= ~LFXTOFF;

  do
  {
    CSCTL5 &= ~LFXTOFFG;
                                            // Clear XT1 fault flag
    SFRIFG1 &= ~OFIFG;
  }while (SFRIFG1&OFIFG);                   // Test oscillator fault flag


  // Turn on LED
  P1DIR |= BIT0;
  __bis_SR_register(LPM0_bits+GIE);
  __no_operation();                         // For debugger
}


// Watchdog Timer interrupt service routine
#pragma vector=WDT_VECTOR
__interrupt void WDT_ISR(void)
{
  P1OUT ^= 0x01;                            // Toggle P1.0 (LED)
}
