//******************************************************************************
//   MSP430FR59xx Demo - Enters LPM3 with ACLK = VLO
//
//   Description: Configures WDT and ACLK to be sourced from VLO and enters LPM3.
//   Note: On the FET board P1.0 drives an LED that can show high power numbers
//   when turned ON. Measure current with LED jumper JP3 disconnected.
//   LED jumper disconnected.
//   ACLK = LFXT1 = 32kHz, MCLK = SMCLK = 4MHz
//
//          MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |               |
//        |          P1.0 |---> Disconnect JP9 for power meas.
//
//   T. Witt/ P. Thanigai
//   Texas Instruments Inc.
//   December 2011
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.1
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTTMSEL | WDTSSEL_2 | WDTIS_5; // VLOCLK, 1s interrupts
  SFRIE1 |= WDTIE;                          // Enable WDT interrupt

  P1DIR = 0;
  P1OUT = 0;
  P1REN = 0xFF;

  P2DIR = 0;
  P2OUT = 0;
  P2REN = 0xFF;

  P3DIR = 0;
  P3OUT = 0;
  P3REN = 0xFF;

  P4DIR = 0;
  P4OUT = 0;
  P4REN = 0xFF;

  PJDIR = 0;
  PJOUT = 0;
  PJREN = 0xFF;

  CSCTL0_H = 0xA5;
  CSCTL1 = DCOFSEL_0;                       // Set DCO setting
  CSCTL2 = SELM__DCOCLK + SELS__DCOCLK + SELA__VLOCLK;   
  CSCTL3 = DIVA__1 + DIVS__1 + DIVM__1;     // set all dividers

  CSCTL4 = LFXTOFF | HFXTOFF;
  CSCTL5 &= ~(LFXTOFFG | HFXTOFFG);

  // Turn on LED
  P1DIR |= BIT0;
  __bis_SR_register(LPM3_bits+GIE);
  __no_operation();                         // For debugger

}

// Watchdog Timer interrupt service routine
#pragma vector=WDT_VECTOR
__interrupt void WDT_ISR(void)
{
  P1OUT ^= BIT0;                            // Toggle P1.0 (LED)
}
