//******************************************************************************
//   MSP430FR59xx Demo - Enters LPM3 with ACLK = LFXT1
//
//   Description: Configure ACLK = LFXT1 and enters LPM3.
//   ACLK = LFXT1 = 32kHz, MCLK = SMCLK = 1MHz
//
//
//          MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |               |
//        |          P1.0 |---> Disconnect JP9 for power meas.
//
//   P. Thanigai
//   Texas Instruments Inc.
//   December 2011
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.1
//******************************************************************************

#include <msp430.h>


int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;


  P1DIR = 0;
  P1OUT = 0;
  P1REN = 0xFF;

  P2DIR = 0;
  P2OUT = 0;
  P2REN = 0xFF;

  P3DIR = 0;
  P3OUT = 0;
  P3REN = 0xFF;

  P4DIR = 0;
  P4OUT = 0;
  P4REN = 0xFF;

  PJDIR = 0xFF;
  PJOUT = 0;

  // XT1 Setup
  PJSEL0 |= BIT4 + BIT5;

  CSCTL0_H = 0xA5;
  CSCTL1 = DCOFSEL_0;                      // Set DCO= 1MHz
  CSCTL1 &= ~DCORSEL;
  CSCTL2 = SELA__LFXTCLK + SELS__DCOCLK + SELM__DCOCLK;
  CSCTL3 = DIVA__1 + DIVS__1 + DIVM__1;     // set all dividers
  CSCTL4 |= LFXTDRIVE_0;
  CSCTL4 &= ~LFXTOFF;

  do
  {
    CSCTL5 &= ~LFXTOFFG;
                                            // Clear XT1 fault flag
    SFRIFG1 &= ~OFIFG;
  }while (SFRIFG1&OFIFG);                   // Test oscillator fault flag

  __bis_SR_register(LPM3_bits);
}


