//*******************************************************************************
//  MSP430FR59x Demo - Timer0_A3, PWM TA0.1-2, Up Mode, DCO SMCLK
//
//  Description: This program generates two PWM outputs on P1.0,P1.1 using
//  Timer0_A configured for up mode. The value in CCR0, 1000-1, defines the PWM
//  period and the values in CCR1 and CCR2 the PWM duty cycles. Using ~1MHz
//  SMCLK as TACLK, the timer period is ~1ms with a 75% duty cycle on P1.0
//  and 25% on P1.1.
//  ACLK = n/a, SMCLK = MCLK = TACLK = 1MHz
//
//
//           MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |     P1.0/TA0.1|--> CCR1 - 75% PWM
//        |     P1.1/TA0.2|--> CCR2 - 25% PWM
//
//   T. Witt/ P. Thanigai
//   Texas Instruments Inc.
//   November 2011
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.1
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT
  CSCTL0_H = 0xA5;
  CSCTL1 |= DCOFSEL0 | DCOFSEL1;            // Set max. DCO setting = 8MHz
  CSCTL2 = SELA__VLOCLK + SELS__DCOCLK + SELM__DCOCLK;// set ACLK=VLO;SMCLK=DCO
  CSCTL3 = DIVA__8 | DIVS__8 + DIVM__8;     // set all dividers
  CSCTL0_H = 0;

  P1DIR |= BIT0 | BIT1;                     // P1.0 and P1.1 output
  P1SEL0 |= BIT0 | BIT1;                    // P1.0 and P1.1 options select
  TA0CCR0 = 1000-1;                         // PWM Period
  TA0CCTL1 = OUTMOD_7;                      // CCR1 reset/set
  TA0CCR1 = 750;                            // CCR1 PWM duty cycle
  TA0CCTL2 = OUTMOD_7;                      // CCR2 reset/set
  TA0CCR2 = 250;                            // CCR2 PWM duty cycle
  TA0CTL = TASSEL__SMCLK | MC__UP | TACLR;  // SMCLK, up mode, clear TAR

  __bis_SR_register(LPM0_bits);             // Enter LPM0
  __no_operation();                         // For debugger
}
