//******************************************************************************
//  MSP430FR59x Demo - TimerB, Toggle P1.0, CCR0 UP Mode ISR, DCO SMCLK
//
//  Description: Toggle P1.0 using software and TB_0 ISR. TimerB is
//  configured for UP mode, thus the timer overflows when TBR counts
//  to CCR0. In this example, CCR0 is loaded with 50000.
//  ACLK = n/a, MCLK = SMCLK = TACLK = default DCO = ~1MHz
//
//           MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |           P1.0|-->LED
//
//   T. Witt/ P. Thanigai
//   Texas Instruments Inc.
//   November 2011
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.1
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT

  P1DIR |= BIT0;
  P1OUT |= BIT0;

  TB0CCTL0 = CCIE;                          // TBCCR0 interrupt enabled
  TB0CCR0 = 50000;
  TB0CTL = TBSSEL__SMCLK + MC__UP;          // SMCLK, UP mode

  __bis_SR_register(LPM0_bits + GIE);       // Enter LPM0 w/ interrupt
}

// Timer B0 interrupt service routine
#pragma vector = TIMER0_B0_VECTOR
__interrupt void Timer_B (void)
{
  P1OUT ^= BIT0;
}
