//******************************************************************************
//  MSP430FR59x Demo - TimerB, Toggle P1.0, Overflow ISR, DCO SMCLK
//
//  Description: Toggle P1.0 using software and the TimerB overflow ISR.
//  In this example an ISR triggers when TB overflows. Inside the ISR P1.0
//  is toggled.Proper use of the TBIV interrupt
//  vector generator is demonstrated.
//
//  ACLK = n/a, MCLK = SMCLK = 1MHz
//
//
//           MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |           P1.0|-->LED
//
//   T. Witt/ P. Thanigai
//   Texas Instruments Inc.
//   November 2011
//   Built with IAR Embedded Workbench V5.30 & Code Composer Studio V5.1
//******************************************************************************

#include <msp430.h>

int main(void)
{
  WDTCTL = WDTPW | WDTHOLD;                 // Stop WDT

  CSCTL0_H = 0xA5;
  CSCTL1 |= DCOFSEL0 | DCOFSEL1;             // Set DCO setting
  CSCTL2 = SELA__VLOCLK + SELS__DCOCLK + SELM__DCOCLK;// set ACLK = VLO; MCLK = DCO
  CSCTL3 = DIVA__1 + DIVS__8 + DIVM__8;     // set all dividers
  CSCTL0_H = 0;
  P1DIR |= BIT0;
  P1OUT |= BIT0;

  TB0CTL = TBSSEL__SMCLK | MC__CONTINOUS | TBCLR | TBIE;
  	  	  	  	  	  	  	  	  	  	  	// SMCLK, contmode, clear TBR
                                            // enable interrupt

  __bis_SR_register(LPM0_bits + GIE);       // Enter LPM3, enable interrupts
  __no_operation();                         // For debugger
}

// TimerB Interrupt Vector (TBIV) handler
#pragma vector=TIMER0_B1_VECTOR
__interrupt void TIMER0_B1_ISR(void)
{
  switch(__even_in_range(TB0IV,14))
  {
    case  0: break;                          // No interrupt
    case  2: break;                          // CCR1 not used
    case  4: break;                          // CCR2 not used
    case  6: break;                          // reserved
    case  8: break;                          // reserved
    case 10: break;                          // reserved
    case 12: break;                          // reserved
    case 14: P1OUT ^= 0x01;                  // overflow
             break;
    default: break;
  }
}
