//******************************************************************************
// MSP430FR57xx Demo - COMPD Toggle from LPM4; input channel CD13;
// 		Vcompare is compared against the internal reference 2.0V
//
// Description: Use CompD (input channel CD13) and internal reference to
//	  determine if input'Vcompare'is high or low.  When Vcompare exceeds 2.0V
//    CDOUT goes high and when Vcompare is less than 2.0V then CDOUT goes low.
//    P3.5/CDOUT is connected internally to an LED; it will toggle accordingly.
//                                                   
//                 MSP430FR5739
//             ------------------                        
//         /|\|                  |                       
//          | |                  |                       
//          --|RST       P1.2/CD2|<--Vcompare
//            |                  |                                         
//            |        P3.5/CDOUT|----> 'high'(Vcompare>2.0V); 'low'(Vcompare<2.0V)
//            |                  |  |
//            |                  |  | LED 'ON'(Vcompare>2.0V); 'OFF'(Vcompare<2.0V)
//            |                  | 
//
//   Nick Angelou
//   Texas Instruments Inc.
//   February 2012
//   Built with IAR Embedded Workbench Version: 5.40 & Code Composer Studio V5.1
//******************************************************************************
#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/compd.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/frgpio.h"

void main(void)
{
	//Stop WDT
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

	//Set P3.5 as Ternary Module Function Output.
	/*
	* Base Address for Port 3
	* Select Port 3
	* Set Pin 5 to output Ternary Module Function, (CBOUT).
	*/
	FRGPIO_setAsPeripheralModuleFunctionOutputPin(__MSP430_BASEADDRESS_PORT3_R__,
		FRGPIO_PORT_P3,
		FRGPIO_PIN5,
		FRGPIO_TERNARY_MODULE_FUNCTION
	);

  //Initialize the Comparator D module
  /* Base Address of Comparator D,
   * Pin CD2 to Positive(+) Terminal,
   * Reference Voltage to Negative(-) Terminal,
   * Normal Power Mode,
   * Output Filter On with minimal delay,
   * Non-Inverted Output Polarity
   */
  COMPD_init(__MSP430_BASEADDRESS_COMPD__,
      COMPD_INPUT2,
      COMPD_VREF,
      COMPD_FILTEROUTPUT_OFF,
      COMPD_NORMALOUTPUTPOLARITY
      );

  //Set the reference voltage that is being supplied to the (-) terminal
  /* Base Address of Comparator D,
   * Reference Voltage of 2.0 V,
   * Lower Limit of 2.0*(32/32) = 2.0V,
   * Upper Limit of 2.0*(32/32) = 2.0V
   */
  COMPD_setReferenceVoltage(__MSP430_BASEADDRESS_COMPD__,
      COMPD_VREFBASE2_0V,
      32,
      32
      );

    //Disable Input Buffer on P1.2/CD2
	/* Base Address of Comparator D,
	 * Input Buffer port
	 * Selecting the CDx input pin to the comparator
	 * multiplexer with the CDx bits automatically
	 * disables output driver and input buffer for
	 * that pin, regardless of the state of the
	 * associated CDPD.x bit
	 */
	  COMPD_disableInputBuffer(__MSP430_BASEADDRESS_COMPD__,
	  	  COMPD_INPUT2);

  //Allow power to Comparator module
  COMPD_enable(__MSP430_BASEADDRESS_COMPD__);

  __delay_cycles(400);           // delay for the reference to settle
  
  __bis_SR_register(LPM4_bits);          // Enter LPM4
  __no_operation();                      // For debug 
}
