
#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/cs.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/frgpio.h"

//******************************************************************************
//!   MSP430FR57xx Demo - Configure MCLK for 24MHz operation
//!
//!   Description: Configure ACLK = SMCLK = MCLK = 24MHz
//!   IMPORTANT NOTE: While the FR5739 is capable of operation using a 24MHz
//!   MCLK; the throughput of the device is dependednt on accesses to FRAM.
//!   The maximum speed for accessing FRAM is limited to 8MHz*.
//!   Wait states are inserted automatically when the FRAM is accessed at
//!   speeds higher than 8MHz to prevent timing violations.
//!   Refer to the FRAM Clock System chapter of the User's Guide.
//!   * Refer device D/s for typical numbers
//!
//!           MSP430FR57x
//!         ---------------
//!     /|\|               |
//!      | |               |
//!      --|RST            |
//!        |               |
//!        |               |
//!        |          P2.0 |---> ACLK = MCLk = 24MHz
//!
//!   Texas Instruments Inc.
//!   February 2012
//!   Built with IAR Embedded Workbench Version: 5.40 & Code Composer Studio V5.1
//******************************************************************************

	unsigned long clockValue;
	
void main(void)
{

	
  //Stop WDT
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

  CS_setDCOFreq(__MSP430_BASEADDRESS_CS__,CS_DCORSEL_1,CS_DCOFSEL_3);

  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_ACLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_1);
  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_MCLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_1);


  //Set P2.0 as Output Low (for setup as ACLK).
  /*
   * Base Address for Port 2
   * Select Port 2
   * Set Pin 0 to output Low.
   */
  FRGPIO_setOutputLowOnPin(__MSP430_BASEADDRESS_PORT2_R__,
			FRGPIO_PORT_P2,
			FRGPIO_PIN0
	);

  //Set P2.0 as Ternary Module Function Output.
  /*
   * Base Address for Port 2
   * Select Port 2
   * Set Pin 0 to output Ternary Module Function, (ACLK).
   */
  FRGPIO_setAsPeripheralModuleFunctionOutputPin(__MSP430_BASEADDRESS_PORT2_R__,
			FRGPIO_PORT_P2,
			FRGPIO_PIN0,
			FRGPIO_TERNARY_MODULE_FUNCTION
	);
    clockValue = CS_getSMCLK(__MSP430_BASEADDRESS_CS__);
    clockValue = CS_getMCLK(__MSP430_BASEADDRESS_CS__);
    clockValue = CS_getACLK(__MSP430_BASEADDRESS_CS__);



  while(1);

}


