
#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/cs.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/frgpio.h"
#include "driverlib/5xx_6xx/sfr_sys.h"

//******************************************************************************
//!   MSP430FR57xx Demo - Output 32768Hz crystal on XT1 and observe failsafe
//!
//!   Description: Configure ACLK = XT1 in LF mode and enter LPM3.
//!   To observe failsafe behavior short the crystal briefly on the target board.
//!   This will cause an NMI to occur. P1.0 and P3.5 is toggled inside the NMI ISR.
//!   Once the fault flag is cleared XT1 operation continues from 32768Hz crystal
//!   Otherwise ACLK defaults to VLO (~8KHz).
//!   ACLK = LFXT1 = 32kHz, MCLK = SMCLK = 4MHz
//!
//!           MSP430FR57x
//!         ---------------
//!     /|\|               |
//!      | |               |
//!      --|RST            |
//!        |               |
//!        |          P2.0 |--->ACLK
//!        |          P1.0 |--->LED
//!        |          P3.5 |--->LED
//!
//!
//!   Texas Instruments Inc.
//!   February 2012
//!   Built with IAR Embedded Workbench Version: 5.40 & Code Composer Studio V5.1
//******************************************************************************

//*****************************************************************************
//
//Variable to store status of Oscillator fault flags and obtain clock frequency
//
//
//*****************************************************************************
unsigned int status;
unsigned long clockValue;

void main(void)
{
    //Stop WDT
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    // LED setup
    //Set P1.0 as an output pin.
    /*
     * Base Address for Port 1
     * Select Port 1
     * Set Pin 0 as output
     */
	FRGPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
			FRGPIO_PORT_P1,
			FRGPIO_PIN0
	);

	//Set P3.5 as Output Low.
	/*
	* Base Address for Port 3
	* Select Port 3
	* Set Pin 5 to output Low.
	*/
	FRGPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT3_R__,
		FRGPIO_PORT_P3,
		FRGPIO_PIN5
	);

	// XT1 Setup
	//Set PJ.4 and PJ.5 as Primary Module Function Input.
	/*
	* Base Address for Port J
	* Select Port J
	* Set Pin 4, 5 to input Primary Module Function, XT1.
	*/
	FRGPIO_setAsPeripheralModuleFunctionInputPin(__MSP430_BASEADDRESS_PORTJ_R__,
		FRGPIO_PORT_PJ,
		FRGPIO_PIN4 + FRGPIO_PIN5,
		FRGPIO_PRIMARY_MODULE_FUNCTION
	);

  //Set DCO Frequency
  CS_setDCOFreq(__MSP430_BASEADDRESS_CS__,CS_DCORSEL_0,CS_DCOFSEL_3);
  //Initialize ACLK=XT1 and no CLK DIVIDER set to 1
  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_ACLK,CS_XT1CLK_SELECT,CS_CLOCK_DIVIDER_1);
  //Initialize SMCLK=DCOCLK and no CLK DIVIDER set to 2
  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_SMCLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_2);
  //Initialize MCLK=DCOCLK and no CLK DIVIDER set to 2
  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_MCLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_2);
  //Set XT1 frequency
  CS_setExternalClockSource(__MSP430_BASEADDRESS_CS__,32768,0);
  //Start XT1 external crystal
  CS_XT1Start(__MSP430_BASEADDRESS_CS__,CS_XT1DRIVE_0);


  // Now that XT1OSC is running, enable fault interrupt
  SFR_enableInterrupt(__MSP430_BASEADDRESS_SFR__,SFR_OSCILLATOR_FAULT_INTERRUPT);

  //Set P2.0 as Output Low.
  /*
   * Base Address for Port 2
   * Select Port 2
   * Set Pin 0 to output Low.
   */
  FRGPIO_setOutputLowOnPin(__MSP430_BASEADDRESS_PORT2_R__,
			FRGPIO_PORT_P2,
			FRGPIO_PIN0
	);

  //Set P2.0 as Ternary Module Function Output.
  /*
   * Base Address for Port 2
   * Select Port 2
   * Set Pin 0 to output Ternary Module Function, ACLK.
   */
  FRGPIO_setAsPeripheralModuleFunctionOutputPin(__MSP430_BASEADDRESS_PORT2_R__,
			FRGPIO_PORT_P2,
			FRGPIO_PIN0,
			FRGPIO_TERNARY_MODULE_FUNCTION
	);


  CS_XT2Off(__MSP430_BASEADDRESS_CS__);
  
    clockValue = CS_getSMCLK(__MSP430_BASEADDRESS_CS__);
    clockValue = CS_getMCLK(__MSP430_BASEADDRESS_CS__);
    clockValue = CS_getACLK(__MSP430_BASEADDRESS_CS__);

  __bis_SR_register(LPM3_bits+GIE);

}

#pragma vector=UNMI_VECTOR
__interrupt void UNMI_ISR(void)
{
    do
  {
    // set a breakpoint on the line below to observe XT1 operating from VLO
    // when the breakpoint is hit during a crystal fault
	
	//Set P1.0 and P3.5 LED on
	/*
	* Base Address for Port 1
	* Select Port 1
	* Set Pin 0 to output high.
	*/
	FRGPIO_setOutputHighOnPin(__MSP430_BASEADDRESS_PORT1_R__,
		FRGPIO_PORT_P1,
		FRGPIO_PIN0
	);
	
	/*
	* Base Address for Port 3
	* Select Port 3
	* Set Pin 5 to output high.
	*/
	FRGPIO_setOutputHighOnPin(__MSP430_BASEADDRESS_PORT3_R__,
		FRGPIO_PORT_P3,
		FRGPIO_PIN5
		);

    status=CS_clearAllOscFlagsWithTimeout(__MSP430_BASEADDRESS_CS__,1000);

  } while (status);

    //Clear P1.0 LED off
	/*
	* Base Address for Port 1
	* Select Port 1
	* Set Pin 0 to output Low.
	*/
	FRGPIO_setOutputLowOnPin(__MSP430_BASEADDRESS_PORT1_R__,
		FRGPIO_PORT_P1,
		FRGPIO_PIN0
		);
		
    //Clear P3.5 LED off
	/*
	* Base Address for Port 3
	* Select Port 3
	* Set Pin 5 to output Low.
	*/
	FRGPIO_setOutputLowOnPin(__MSP430_BASEADDRESS_PORT3_R__,
		FRGPIO_PORT_P3,
		FRGPIO_PIN5
	);

}


