
//#include "inc/hw_memmap.h"
#include "msp430fr5969.h"
#include "driverlib/5xx_6xx/cs_a.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/frgpio.h"

//******************************************************************************
//   MSP430FR59xx Demo - Configure MCLK for 24MHz operation
//
//   Description: Configure SMCLK = MCLK = 24MHz
//   IMPORTANT NOTE: While the FRxxx is capable of operation w/ MCLK = 24MHz
//   the throughput of the device is dependent on accesses to FRAM.
//   The maximum speed for accessing FRAM is limited to 8MHz*.
//   Wait states are inserted automatically when the FRAM is accessed at
//   speeds higher than 8MHz to prevent timing violations.
//   Refer to the FRCTL chapter of the User's Guide.
//   * Refer device D/s for typical numbers
//
//           MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |               |
//        |          P3.4 |---> SMCLK = MCLK = 24MHz
//
//******************************************************************************

unsigned long clockValue;
	
void main(void)
{

	
  //Stop WDT
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);
  CSA_setDCOFreq(__MSP430_BASEADDRESS_CS_A__,CSA_DCORSEL_1,CSA_DCOFSEL_6);

  CSA_clockSignalInit(__MSP430_BASEADDRESS_CS_A__,CSA_SMCLK,CSA_DCOCLK_SELECT,CSA_CLOCK_DIVIDER_1);
  CSA_clockSignalInit(__MSP430_BASEADDRESS_CS_A__,CSA_MCLK,CSA_DCOCLK_SELECT,CSA_CLOCK_DIVIDER_1);


  //Set P2.0 as Output Low (for setup as ACLK).
  /*
   * Base Address for Port 2
   * Select Port 2
   * Set Pin 0 to output Low.
   */
  FRGPIO_setOutputLowOnPin(__MSP430_BASEADDRESS_PORT3_R__,
			FRGPIO_PORT_P3,
			FRGPIO_PIN4
	);

  //Set P2.0 as Ternary Module Function Output.
  /*
   * Base Address for Port 2
   * Select Port 2
   * Set Pin 0 to output Ternary Module Function, (ACLK).
   */
  FRGPIO_setAsPeripheralModuleFunctionOutputPin(__MSP430_BASEADDRESS_PORT3_R__,
			FRGPIO_PORT_P3,
			FRGPIO_PIN4,
			FRGPIO_TERNARY_MODULE_FUNCTION
	);

  while(1);

}


