#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/dac12.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"

//*******************************************************************************
//!
//! MSP430F6638 Example
//! DAC12 - 1.5V Output on DAC12_0
//!
//!  Using DAC12_0 and AVcc reference with a gain of 1, output 1.5V on DAC0.
//!  ACLK = n/a, MCLK = SMCLK = default DCO
//!
//!                MSP430F66x
//!            -----------------
//!        /|\|              XIN|-
//!         | |                 |
//!         --|RST          XOUT|-
//!           |                 |
//!           |        P7.6/DAC0|-> 1.5V
//!           |                 |
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - DAC12 peripheral
//! - GPIO Port peripheral
//! - DAC0
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - None.
//!
//******************************************************************************

void main (void)
{
    //Stop Watchdog Timer
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    /*
     * // Initialize DAC12_0,
     * // Choose P7.6 as output
     * // Use AVcc as Vref+
     * // Multiply Vout by 1
     * // Use medium settling speed/current
     * // Auto trigger as soon as data is set
     */
    DAC12_init(__MSP430_BASEADDRESS_DAC12_2__,
        DAC12_SUBMODULE_0,
        DAC12_OUTPUT_1,
        DAC12_VREF_AVCC,
        DAC12_VREFx1,
        DAC12_AMP_MEDIN_MEDOUT,
        DAC12_TRIGGER_ENCBYPASS);

    //Calibrate output buffer for DAC12_0
    DAC12_calibrateOutput(__MSP430_BASEADDRESS_DAC12_2__,
        DAC12_SUBMODULE_0);

    //Set 0x07FF (~1.5V) into data buffer for DAC12_0
    DAC12_setData(__MSP430_BASEADDRESS_DAC12_2__,
        DAC12_SUBMODULE_0,
        0x7FF);

    //Enter LPM4
    __bis_SR_register(LPM4_bits);
}

