#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/ei2c.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/cs.h"
#include "driverlib/5xx_6xx/frgpio.h"

//******************************************************************************
//  MSP430FR57xx Demo - USCI_B0 I2C Master TX bytes to Multiple Slaves
//
//  Description: This demo connects two MSP430's via the I2C bus. 
//  The master transmits to 4 different I2C slave addresses 0x0A,0x0B,0x0C&0x0D.
//  Each slave address has a specific related data in the array TXData[].
//  At the end of four I2C transactions the slave address rolls over and begins 
//  again at 0x0A.
//  ACLK = n/a, MCLK = SMCLK = BRCLK = default DCO = ~1.045MHz
//  Use with MSP430FR57xx_uscib0_i2c_MultiSlave.c
//
//                                /|\  /|\
//                MSP430FR5739    10k  10k     MSP430FR5739
//                   slave         |    |         master
//             -----------------   |    |   -----------------
//           -|XIN  P1.6/UCB0SDA|<-|----+->|P1.6/UCB0SDA  XIN|-
//            |                 |  |       |                 |
//           -|XOUT             |  |       |             XOUT|-
//            |     P1.7/UCB0SCL|<-+------>|P1.7/UCB0SCL     |
//            |                 |          |                 |
//
//******************************************************************************


unsigned char TXData[]= {0xA1,0xB1,0xC1,0xD1};// Pointer to TX data
unsigned char SlaveAddress[]= {0x0A,0x0B,0x0C,0x0D};                         
unsigned char TXByteCtr;
unsigned char SlaveFlag = 0;

void main(void)

{
	WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

	  // Configure MCLK=SMCLK=ACLK=DCOCLK for 1MHz operation
	  //Set DCO frequency to 8MHz
	  CS_setDCOFreq(__MSP430_BASEADDRESS_CS__,CS_DCORSEL_0,CS_DCOFSEL_3);
	  //Set ACLK = DCO with frequency divider of 8
	  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_ACLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_8);
	  //Set SMCLK = DCO with frequency divider of 8
	  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_SMCLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_8);
	  //Set MCLK = DCO with frequency divider of 8
	  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_MCLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_8);



    // Configure Pins for I2C
	//Set P1.6 and P1.7 as Secondary Module Function Input.
	/*
	* Base Address for Port 1
	* Select Port 1
	* Set Pin 6, 7 to input Secondary Module Function, (UCB0SIMO/UCB0SDA, UCB0SOMI/UCB0SCL).
	*/
	FRGPIO_setAsPeripheralModuleFunctionInputPin(__MSP430_BASEADDRESS_PORT1_R__,
		FRGPIO_PORT_P1,
		FRGPIO_PIN6 + FRGPIO_PIN7,
		FRGPIO_SECONDARY_MODULE_FUNCTION
	);

    eI2C_masterInit(__MSP430_BASEADDRESS_EUSCI_B0__,
                        eI2C_CLOCKSOURCE_SMCLK,
                        CS_getSMCLK(__MSP430_BASEADDRESS_CS__),
                        eI2C_SET_DATA_RATE_400KBPS,
                        0,
                        eI2C_NO_AUTO_STOP
                        );


    //Set Master in receive mode
    eI2C_setMode(__MSP430_BASEADDRESS_EUSCI_B0__,
    				eI2C_TRANSMIT_MODE
    				);
    //Enable I2C Module to start operations
    eI2C_enable(__MSP430_BASEADDRESS_EUSCI_B0__);

    //Enable master Receive interrupt
    eI2C_enableInterrupt(__MSP430_BASEADDRESS_EUSCI_B0__,
    				eI2C_TRANSMIT_INTERRUPT0 +
    				eI2C_NAK_INTERRUPT
    			  );

    SlaveFlag =0;
    while(1)
    {
     	//Specify slave address
    	eI2C_setSlaveAddress(__MSP430_BASEADDRESS_EUSCI_B0__,
    			SlaveAddress[SlaveFlag]
    				);


    	TXByteCtr = 1;                          // Load TX byte counter

    	while (eI2C_SENDING_STOP == eI2C_masterIsSTOPSent
    			(__MSP430_BASEADDRESS_EUSCI_B0__));


    	eI2C_masterSendStart(__MSP430_BASEADDRESS_EUSCI_B0__);

    	__bis_SR_register(CPUOFF + GIE);        // Enter LPM0 w/ interrupts
                                            // Remain in LPM0 until all data
                                            // is TX'd
    	// Change Slave address
    	SlaveFlag++;
    	if (SlaveFlag>3)                        // Roll over slave address
    	{
    		SlaveFlag =0;
    		__delay_cycles(1000);               // Delay between transmissions
    	}
   
    }
	
}

	
#pragma vector = USCI_B0_VECTOR 
__interrupt void USCIB0_ISR(void) 
{	
  switch(__even_in_range(UCB0IV,0x1E)) 
  {
        case 0x00: break;                   // Vector 0: No interrupts break;
        case 0x02: break;
        case 0x04:
          eI2C_masterSendStart(__MSP430_BASEADDRESS_EUSCI_B0__);
          break;                            // Vector 4: NACKIFG break;
        case 0x06: break;                   // Vector 6: STTIFG break;
        case 0x08: break;                   // Vector 8: STPIFG break;
        case 0x0a: break;                   // Vector 10: RXIFG3 break;
        case 0x0c: break;                   // Vector 14: TXIFG3 break;
        case 0x0e: break;                   // Vector 16: RXIFG2 break;
        case 0x10: break;                   // Vector 18: TXIFG2 break;
        case 0x12: break;                   // Vector 20: RXIFG1 break;
        case 0x14: break;                   // Vector 22: TXIFG1 break;
        case 0x16: break;                   // Vector 24: RXIFG0 break;  
        case 0x18: 
	  if (TXByteCtr)                    // Check TX byte counter
          {
		  	  eI2C_masterMultiByteSendNext(__MSP430_BASEADDRESS_EUSCI_B0__,
				  TXData[SlaveFlag]);
		  	  TXByteCtr--;                    // Decrement TX byte counter
          }
          else
          {
        	  eI2C_masterMultiByteSendStop(__MSP430_BASEADDRESS_EUSCI_B0__);
            __bic_SR_register_on_exit(CPUOFF);// Exit LPM0
          }
          break;                            // Vector 26: TXIFG0 break;
        default: break;
  }
}
	
