#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/ei2c.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/cs.h"
#include "driverlib/5xx_6xx/frgpio.h"

//******************************************************************************
//  MSP430FR57xx Demo - USCI_B0 I2C 4 Hardware I2C slaves
//
//  Description: This demo connects two MSP430's via the I2C bus. 
//  This code configures the MSP430 USCI to be addressed as 4 independent I2C
//  slaves. Each slave has its owm interrupt flag and data variable to store
//  incoming data. 
//  Use with MSP430FR57xx_uscib0_i2c_Master_MultiSlave.c
//  ACLK = n/a, MCLK = SMCLK = default DCO = ~1.045MHz
//
//                                /|\  /|\
//                MSP430FR5739    10k  10k     MSP430FR5739
//                   slave         |    |         master
//             -----------------   |    |   -----------------
//           -|XIN  P1.6/UCB0SDA|<-|----+->|P1.6/UCB0SDA  XIN|-
//            |                 |  |       |                 |
//           -|XOUT             |  |       |             XOUT|-
//            |     P1.7/UCB0SCL|<-+------>|P1.7/UCB0SCL     |
//            |                 |          |                 |
//            |                 |          |                 |
//
//******************************************************************************
unsigned char RXData0=0;  
unsigned char RXData1=0;
unsigned char RXData2=0;
unsigned char RXData3=0;

void main(void)

{
	
	WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    // Configure Pins for I2C
	//Set P1.6 and P1.7 as Secondary Module Function Input.
	/*
	* Base Address for Port 1
	* Select Port 1
	* Set Pin 6, 7 to input Secondary Module Function, (UCB0SIMO/UCB0SDA, UCB0SOMI/UCB0SCL).
	*/
	FRGPIO_setAsPeripheralModuleFunctionInputPin(__MSP430_BASEADDRESS_PORT1_R__,
		FRGPIO_PORT_P1,
		FRGPIO_PIN6 + FRGPIO_PIN7,
		FRGPIO_SECONDARY_MODULE_FUNCTION
	);
	
    // eUSCI configuration
    //SLAVE0 own address is 0x0A+ enable
    eI2C_slaveInit(__MSP430_BASEADDRESS_EUSCI_B0__,
    					0x0A,
                		eI2C_OWN_ADDRESS_OFFSET0,
                		eI2C_OWN_ADDRESS_ENABLE
                		);
    //SLAVE1 own address is 0x0B+ enable
    eI2C_slaveInit(__MSP430_BASEADDRESS_EUSCI_B0__,
        					0x0B,
                    		eI2C_OWN_ADDRESS_OFFSET1,
                    		eI2C_OWN_ADDRESS_ENABLE
                    		);
    //SLAVE2 own address is 0x0C+ enable
    eI2C_slaveInit(__MSP430_BASEADDRESS_EUSCI_B0__,
        					0x0C,
                    		eI2C_OWN_ADDRESS_OFFSET2,
                    		eI2C_OWN_ADDRESS_ENABLE
                    		);
    //SLAVE3 own address is 0x0D+ enable
    eI2C_slaveInit(__MSP430_BASEADDRESS_EUSCI_B0__,
        					0x0D,
                    		eI2C_OWN_ADDRESS_OFFSET3,
                    		eI2C_OWN_ADDRESS_ENABLE
                    		);

    eI2C_enable(__MSP430_BASEADDRESS_EUSCI_B0__);

    //receive interrupt enable
    eI2C_enableInterrupt(__MSP430_BASEADDRESS_EUSCI_B0__,
    				eI2C_RECEIVE_INTERRUPT0 +
    				eI2C_RECEIVE_INTERRUPT1 +
    				eI2C_RECEIVE_INTERRUPT2 +
    				eI2C_RECEIVE_INTERRUPT3
    				);


	
    __bis_SR_register(CPUOFF + GIE);        // Enter LPM0 w/ interrupts
    __no_operation();	 
}


#pragma vector = USCI_B0_VECTOR 
__interrupt void USCIB0_ISR(void)

{

   switch(__even_in_range(UCB0IV,0x1E))
    {
      case 0x00: break;                     // Vector 0: No interrupts break;
      case 0x02: break;                     // Vector 2: ALIFG break;
      case 0x04: break;                     // Vector 4: NACKIFG break;
      case 0x06: break;                     // Vector 6: STTIFG break;
      case 0x08: break;                     // Vector 8: STPIFG break;
      case 0x0a:                            // SLAVE3
        RXData3 = eI2C_slaveDataGet(__MSP430_BASEADDRESS_EUSCI_B0__);
        break;                              // Vector 10: RXIFG3 break;
      case 0x0c: break;                     // Vector 14: TXIFG3 break;
      case 0x0e:                            // SLAVE2
        RXData2 = eI2C_slaveDataGet(__MSP430_BASEADDRESS_EUSCI_B0__);
        break;                              // Vector 16: RXIFG2 break;
      case 0x10: break;                     // Vector 18: TXIFG2 break;
      case 0x12:                            // SLAVE1
        RXData1 = eI2C_slaveDataGet(__MSP430_BASEADDRESS_EUSCI_B0__);
        break;                              // Vector 20: RXIFG1 break;
      case 0x14: break;                     // Vector 22: TXIFG1 break;
      case 0x16:                            // SLAVE0
        RXData0 = eI2C_slaveDataGet(__MSP430_BASEADDRESS_EUSCI_B0__);
        // Get RX data
        break;                              // Vector 24: RXIFG0 break;
      case 0x18: break;                     // Vector 26: TXIFG0 break;
      case 0x1a: break;                     // Vector 28: BCNTIFG break;
      case 0x1c: break;                     // Vector 30: clock low timeout break;
      case 0x1e: break;                     // Vector 32: 9th bit break;
      default: break;	
    }
	
}	


