#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/ei2c.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/frgpio.h"
#include "driverlib/5xx_6xx/cs.h"

//******************************************************************************
//  MSP430FR57xx Demo - USCI_B0 I2C Slave RX single bytes from MSP430 Master
//
//  Description: This demo connects two MSP430's via the I2C bus. The master
//  transmits to the slave. This is the slave code. The interrupt driven
//  data receiption is demonstrated using the USCI_B0 RX interrupt.
//  ACLK = n/a, MCLK = SMCLK = default DCO = ~1.045MHz
//
//                                /|\  /|\
//                MSP430FR5739    10k  10k     MSP430FR5739
//                   slave         |    |         master
//             -----------------   |    |   -----------------
//           -|XIN  P1.6/UCB0SDA|<-|----+->|P1.6/UCB0SDA  XIN|-
//            |                 |  |       |                 |
//           -|XOUT             |  |       |             XOUT|-
//            |     P1.7/UCB0SCL|<-+------>|P1.7/UCB0SCL     |
//            |                 |          |                 |
//            |                 |          |                 |
//

//******************************************************************************
//*****************************************************************************
//
//Set the address for slave module. This is a 7-bit address sent in the
//following format:
//[A6:A5:A4:A3:A2:A1:A0:RS]
//
//A zero in the "RS" position of the first byte means that the master
//transmits (sends) data to the selected slave, and a one in this position
//means that the master receives data from the slave.
//
//*****************************************************************************
#define SLAVE_ADDRESS 0x48


unsigned char RXData;

void main(void)

{

    WDTCTL = WDTPW + WDTHOLD;


    // Configure Pins for I2C
	//Set P1.6 and P1.7 as Secondary Module Function Input.
	/*
	* Base Address for Port 1
	* Select Port 1
	* Set Pin 6, 7 to input Secondary Module Function, (UCB0SIMO/UCB0SDA, UCB0SOMI/UCB0SCL).
	*/
	FRGPIO_setAsPeripheralModuleFunctionInputPin(__MSP430_BASEADDRESS_PORT1_R__,
		FRGPIO_PORT_P1,
		FRGPIO_PIN6 + FRGPIO_PIN7,
		FRGPIO_SECONDARY_MODULE_FUNCTION
	);
	
    // eUSCI configuration
    eI2C_slaveInit(__MSP430_BASEADDRESS_EUSCI_B0__,
    				SLAVE_ADDRESS,
            		eI2C_OWN_ADDRESS_OFFSET0,
            		eI2C_OWN_ADDRESS_ENABLE
            		);

    //Set in receive mode
	eI2C_setMode(__MSP430_BASEADDRESS_EUSCI_B0__,
				eI2C_RECEIVE_MODE
						);

	eI2C_enable(__MSP430_BASEADDRESS_EUSCI_B0__);

	eI2C_enableInterrupt(__MSP430_BASEADDRESS_EUSCI_B0__,
				eI2C_RECEIVE_INTERRUPT0
				);

    __bis_SR_register(CPUOFF + GIE);        // Enter LPM0 w/ interrupts
    __no_operation();
}


//------------------------------------------------------------------------------
// The USCI_B0 data ISR RX vector is used to move received data from the I2C
// master to the MSP430 memory.
//------------------------------------------------------------------------------
//------------------------------------------------------------------------------
// The USCI_B0 state ISR TX vector is used to wake up the CPU from LPM0 in order
// to process the received data in the main program. LPM0 is only exit in case
// of a (re-)start or stop condition when actual data was received.
//------------------------------------------------------------------------------
#pragma vector = USCI_B0_VECTOR
__interrupt void USCIB0_ISR(void)

{

   switch(__even_in_range(UCB0IV,0x1E))
    {
      case 0x00: break;                     // Vector 0: No interrupts break;
      case 0x02: break;                     // Vector 2: ALIFG break;
      case 0x04: break;                     // Vector 4: NACKIFG break;
      case 0x06: break;                     // Vector 6: STTIFG break;
      case 0x08: break;                     // Vector 8: STPIFG break;
      case 0x0a: break;                     // Vector 10: RXIFG3 break;
      case 0x0c: break;                     // Vector 14: TXIFG3 break;
      case 0x0e: break;                     // Vector 16: RXIFG2 break;
      case 0x10: break;                     // Vector 18: TXIFG2 break;
      case 0x12: break;                     // Vector 20: RXIFG1 break;
      case 0x14: break;                     // Vector 22: TXIFG1 break;
      case 0x16:
      	  RXData = eI2C_slaveDataGet(__MSP430_BASEADDRESS_EUSCI_B0__);

        break;                              // Vector 24: RXIFG0 break;
      case 0x18: break;                     // Vector 26: TXIFG0 break;
      case 0x1a: break;                     // Vector 28: BCNTIFG break;
      case 0x1c: break;                     // Vector 30: clock low timeout break;
      case 0x1e: break;                     // Vector 32: 9th bit break;
      default: break;
    }

}
