//******************************************************************************
//!  MSP430F54xA Demo - Flash In-System Programming w/ Long-Word write at 0x1800
//!
//!  Description: This program first erases flash seg D, then it writes a 32-bit
//!  value to memory location 0x1800 using BLK write mode. BLK write
//!  provides faster write times than byte/word mode. LED toggles upon
//!  completion.
//!  ACLK = REFO = 32kHz, MCLK = SMCLK = default DCO 1048576Hz
//!
//!                MSP430F54xA
//!            -----------------
//!        /|\|                 |
//!         | |             P1.0|-LED
//!         --|RST              |
//!           |                 |
//!
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - Flash module
//! - GPIO Port peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - None.
//******************************************************************************

#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/flash.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"

//*****************************************************************************
//
//Calibration data to be written into flash
//
//*****************************************************************************
unsigned long calibration_data[] = {0x12345678};

//*****************************************************************************
//
//INFO address in flash to which data is written into
//
//*****************************************************************************
#define INFOD_START   (0x1800)


void main (void)
{
    unsigned short status;

    //Stop WDT
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    //Set P1.0 to output direction
    GPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
        GPIO_PORT_P1,
        GPIO_PIN0
        );

    //Erase INFOD
    do {
        Flash_segmentErase(__MSP430_BASEADDRESS_FLASH__,
            (unsigned char *)INFOD_START
            );
        status = Flash_eraseCheck(__MSP430_BASEADDRESS_FLASH__,
            (unsigned char *)INFOD_START,
            128
            );
    } while (status == STATUS_FAIL);

    //Flash write
    Flash_write32(__MSP430_BASEADDRESS_FLASH__,
        calibration_data,
        (unsigned long *)(INFOD_START),1);

    while (1)
    {
        //Toggle P1.0
        GPIO_toggleOutputOnPin(
            __MSP430_BASEADDRESS_PORT1_R__,
            GPIO_PORT_P1,
            GPIO_PIN0
            );

        //Delay
        __delay_cycles(1000000);
    }
}

