#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/fram.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/cs.h"
#include "driverlib/5xx_6xx/frgpio.h"
#include "driverlib/5xx_6xx/ref.h"

//******************************************************************************
//!   MSP430FR57xx Demo - Long word writes to FRAM
//!
//!   Description: Use long word write to write to 512 byte blocks of FRAM.
//!   Toggle LEDs after every 100 writes.
//!   NOTE: Running this example for extended periods will impact the FRAM
//!   endurance.
//!   ACLK = VLO, MCLK = SMCLK = 4MHz
//!
//!           MSP430FR573x
//!         ---------------
//!     /|\|               |
//!      | |               |
//!      --|RST            |
//!        |               |
//!        |               |
//!        |           P1.0|---> LED
//!		   |           P3.5|-->LED
//!
//!   Built with IAR Embedded Workbench Version: 5.40 & Code Composer Studio V5.1
//******************************************************************************

#define FRAM_TEST_START 0xCA00

void main(void)
{
  unsigned char count = 0;
  unsigned long data=0;
  
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);                 // Stop WDT


  // Configure MCLK for 4MHz operation
  //Set DCO frequency to 8MHz
  CS_setDCOFreq(__MSP430_BASEADDRESS_CS__,CS_DCORSEL_0,CS_DCOFSEL_3);
  //Set ACLK = VLO with frequency divider of 1
  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_ACLK,CS_VLOCLK_SELECT,CS_CLOCK_DIVIDER_1);
  //Set SMCLK = DCO with frequency divider of 2
  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_ACLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_2);
  //Set MCLK = DCO with frequency divider of 2
  CS_clockSignalInit(__MSP430_BASEADDRESS_CS__,CS_ACLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_2);

  // Turn off Temperature sensor and Reference Voltage.
  REF_disableTempSensor(__MSP430_BASEADDRESS_REF__);
  REF_disableReferenceVoltage(__MSP430_BASEADDRESS_REF__);

  //Set P1.0 as an output pin.
  /*
   * Base Address for Port 1
   * Select Port 1
   * Set Pin 0 as output
   */
	FRGPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
			FRGPIO_PORT_P1,
			FRGPIO_PIN0
	);
	//Set P3.5 as an output pin.
    /*
     * Base Address for Port 3
     * Select Port 3
     * Set Pin 5 as output
     */
	FRGPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT3_R__,
			FRGPIO_PORT_P3,
			FRGPIO_PIN5);

  // Initialize dummy data
  data = 0x11111111;

  while(1)
  {
          data += 0x00010001;

          FRAM_memoryFill32(__MSP430_BASEADDRESS_FRAM_FR5XX__,data,(unsigned long *)FRAM_TEST_START,128);
          count++;
          if (count > 100)
          {
			//Toggle P1.0 output pin.
			/*
			* Base Address for Port 1
			* Select Port 1
			* Set Pin 0 as output
			*/
			FRGPIO_toggleOutputOnPin(__MSP430_BASEADDRESS_PORT1_R__,
				FRGPIO_PORT_P1,
				FRGPIO_PIN0
				);
			//Toggle P3.5 output pin.
			/*
			* Base Address for Port 3
			* Select Port 3
			* Set Pin 5 as output
			*/
			FRGPIO_toggleOutputOnPin(__MSP430_BASEADDRESS_PORT3_R__,
				FRGPIO_PORT_P3,
				FRGPIO_PIN5
			);


            count = 0;                            //Reset counter
            data = 0x11111111;
          }
  }
}
