//******************************************************************************
//   Write a Word to Port A (Port1+Port2)
//
//   Writes a Word(FFFFh) to Port A and stays in LPM4
//   ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//
//                MSP430FR5969
//             -----------------
//         /|\|                 |
//          | |                 |
//          --|RST          PA.x|-->HI
//            |                 |
//            |                 |
//
//
//   This example uses the following peripherals and I/O signals.  You must
//   review these and change as needed for your own board:
//   - GPIO Port peripheral
//   
//   This example uses the following interrupt handlers.  To use this example
//   in your own application you must add these interrupt handlers to your
//   vector table.
//   - None.
//
//   Nick Angelou
//   Texas Instruments Inc.
//   February 2012
//   Built with IAR Embedded Workbench Version: 5.40 & Code Composer Studio V5.1
//******************************************************************************

#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/frgpio.h"
#include "driverlib/5xx_6xx/wdt.h"

void main (void)
{
    //Stop WDT
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    //PA.x output
    FRGPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
        FRGPIO_PORT_PA,
        FRGPIO_PIN0 + FRGPIO_PIN1 + FRGPIO_PIN2 + FRGPIO_PIN3 +
        FRGPIO_PIN4 + FRGPIO_PIN5 + FRGPIO_PIN6 + FRGPIO_PIN7 +
        FRGPIO_PIN8 + FRGPIO_PIN9 + FRGPIO_PIN10 + FRGPIO_PIN11 +
        FRGPIO_PIN12 + FRGPIO_PIN13 + FRGPIO_PIN14 + FRGPIO_PIN15
        );


    //Set all PA pins HI
    FRGPIO_setOutputHighOnPin(
        __MSP430_BASEADDRESS_PORT1_R__,
        FRGPIO_PORT_PA,
        FRGPIO_PIN0 + FRGPIO_PIN1 + FRGPIO_PIN2 + FRGPIO_PIN3 +
        FRGPIO_PIN4 + FRGPIO_PIN5 + FRGPIO_PIN6 + FRGPIO_PIN7 +
        FRGPIO_PIN8 + FRGPIO_PIN9 + FRGPIO_PIN10 + FRGPIO_PIN11 +
        FRGPIO_PIN12 + FRGPIO_PIN13 + FRGPIO_PIN14 + FRGPIO_PIN15
        );

    //Enter LPM4 w/interrupts enabled
    __bis_SR_register(LPM4_bits + GIE);

    //For debugger
    __no_operation();
}

