//******************************************************************************
//!  Software Poll P1.4, Set P1.0 if P1.4 = 1
//!
//!  Poll P1.4 in a loop, if hi P1.0 is set, if low, P1.0 reset.
//!  ACLK = n/a, MCLK = SMCLK = default DCO
//!
//!              MSP430F5438A
//!            -----------------
//!        /|\|              XIN|-
//!         | |                 |
//!         --|RST          XOUT|-
//!     /|\   |                 |
//!      --o--|P1.4         P1.0|-->LED
//!     \|/
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - GPIO Port peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - None
//!
//******************************************************************************
#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/gpio.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"

void main (void)
{
    //Stop watchdog timer
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    //Set P1.0 to output direction
    GPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
        GPIO_PORT_P1,
        GPIO_PIN0
        );

    //Set P1.4 to input direction
    GPIO_setAsInputPin(__MSP430_BASEADDRESS_PORT1_R__,
        GPIO_PORT_P1,
        GPIO_PIN4
        );

    while (1)
    {
        //Test P1.4
        if (GPIO_INPUT_PIN_HIGH == GPIO_getInputPinValue(
                __MSP430_BASEADDRESS_PORT1_R__,
                GPIO_PORT_P1,
                GPIO_PIN4
                )){
            //if P1.4 set, set P1.0
            GPIO_setOutputHighOnPin(
                __MSP430_BASEADDRESS_PORT1_R__,
                GPIO_PORT_P1,
                GPIO_PIN0
                );
        } else   {
            //else reset
            GPIO_setOutputLowOnPin(
                __MSP430_BASEADDRESS_PORT1_R__,
                GPIO_PORT_P1,
                GPIO_PIN0
                );
        }
    }
}

