#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/i2c.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"

//*****************************************************************************
//! This example shows how to configure the I2C module as a slave for
//! multi byte reception. The address of the slave module is set in this
//! example
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - I2C peripheral
//! - GPIO Port peripheral (for I2C pins)
//! - SCL2
//! - SDA
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - USCI_B0_VECTOR.
//!
//
//*****************************************************************************
//*****************************************************************************
//
//Set the address for slave module. This is a 7-bit address sent in the
//following format:
//[A6:A5:A4:A3:A2:A1:A0:RS]
//
//A zero in the "RS" position of the first byte means that the master
//transmits (sends) data to the selected slave, and a one in this position
//means that the master receives data from the slave.
//
//*****************************************************************************
#define SLAVE_ADDRESS 0x48


unsigned char store[40] = { 9, 10, 11, 12, 13, 14, 15, 16, 17, 18};
unsigned char * receivedDataPointer;

void main ()
{
    //Stop WDT
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    //Assign I2C pins to USCI_B0
    GPIO_setAsPeripheralModuleFunctionInputPin(__MSP430_BASEADDRESS_PORT3_R__,
        GPIO_PORT_P3,
        GPIO_PIN1 + GPIO_PIN2
        );

    //Initialize I2C as a slave device
    I2C_slaveInit(__MSP430_BASEADDRESS_USCI_B0__,
        SLAVE_ADDRESS
        );

    receivedDataPointer = store;

    //Specify transmit mode
    I2C_setMode(__MSP430_BASEADDRESS_USCI_B0__,
        I2C_RECEIVE_MODE
        );

    //Enable I2C Module to start operations
    I2C_enable(__MSP430_BASEADDRESS_USCI_B0__);

    //Enable interrupts
    I2C_enableInterrupt(__MSP430_BASEADDRESS_USCI_B0__,
        I2C_RECEIVE_INTERRUPT +
        I2C_STOP_INTERRUPT
        );

    while (1)
    {
        //Enter low power mode 0 with interrupts enabled.
        __bis_SR_register(LPM0_bits + GIE);
        __no_operation();
        receivedDataPointer = store;
    }
}

//******************************************************************************
//
//This is the USCI_B0 interrupt vector service routine.
//
//******************************************************************************
#pragma vector = USCI_B0_VECTOR
__interrupt void USCI_B0_ISR (void)
{
    switch (__even_in_range(UCB0IV,12)){
        case USCI_I2C_UCRXIFG:
            //receive data
            *receivedDataPointer++ = I2C_slaveDataGet(
            __MSP430_BASEADDRESS_USCI_B0__);
            break;

        case USCI_I2C_UCSTPIFG:
            __bic_SR_register_on_exit(LPM0_bits);
            break;
    }
}

