//******************************************************************************
//  MSP430FR59x Demo - MPU Write protection violation - Interrupt notification
//
//  Description: The MPU segment boundaries are defined by:
//  Border 1 = 0x6000 [MPUSEGB1 = 0x0600]
//  Border 2 = 0x8000 [MPUSEGB2 = 0x0800]
//  Segment 1 = 0x4400 - 0x5FFF
//  Segment 2 = 0x6000 - 0x7FFF
//  Segment 3 = 0x8000 - 0x13FFF
//  Segment 2 is write protected. Any write to an address in the segment 2 range
//  causes a PUC. The LED toggles after accessing SYS NMI ISR.
//
//  ACLK = n/a, MCLK = SMCLK = default DCO
//
//
//           MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |           P1.0|-->LED
//
//******************************************************************************

//#include "inc/hw_memmap.h"
#include "msp430fr5969.h"
#include "driverlib/5xx_6xx/mpu_a.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/frgpio.h"

unsigned char SYSNMIflag = 0;
unsigned int *ptr = 0;
unsigned int Data =0;

void main(void)
{
  // Stop WDT
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

  // Configure P1.0 for LED
 FRGPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
			FRGPIO_PORT_P1,
			FRGPIO_PIN0);

  // Configure MPU
  MPUA_createThreeSegments(__MSP430_BASEADDRESS_MPU_A__,0x0600,0x0800,
  		  	  	  	  	  MPUA_READ|MPUA_WRITE|MPUA_EXEC,
                            MPUA_READ,
                            MPUA_READ|MPUA_WRITE|MPUA_EXEC);
  MPUA_disablePUCOnViolation(__MSP430_BASEADDRESS_MPU_A__,MPUA_SECOND_SEG);

  MPUA_enableNMIevent(__MSP430_BASEADDRESS_MPU_A__);
  MPUA_start(__MSP430_BASEADDRESS_MPU_A__);

  Data = 0x88;

  // Cause an MPU violation by writing to segment 2+
  ptr = (unsigned int  *)0x6002;
  *ptr = Data;

  __delay_cycles(100);

  while(SYSNMIflag)
  {
	  FRGPIO_toggleOutputOnPin(__MSP430_BASEADDRESS_PORT1_R__,
	  		FRGPIO_PORT_P1,
	  		FRGPIO_PIN0
	  	);
      __delay_cycles(100000);
  }

  // No violation - trap here
  while(1);

}



// Sys NMI vector
#pragma vector = SYSNMI_VECTOR
__interrupt void SYSNMI_ISR(void)

{
    switch(__even_in_range(SYSSNIV,0x18))
    {
    case 0x00: break;
    case 0x02: break;
    case 0x04: break;
    case 0x06: break;
    case 0x08: break;
    case 0x0A: break;
    case 0x0C: break;                       //MPUSEG1IFG
    case 0x0E:
     // Clear violation interrupt flag
     MPUA_clearInterruptFlag(__MSP430_BASEADDRESS_MPU_A__,
    		 MPUA_SEG_2_ACCESS_VIOLATION
    		 );
     SYSNMIflag =1;                         // Set flag
    	break;
    case 0x10: break;                       // MPUSEG3IFG
    case 0x12: break;
    case 0x14: break;
    case 0x16: break;
    case 0x18: break;
    default: break;
    }
}

