#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/mpy32.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"

//******************************************************************************
//!
//! MPY - 8x8 Unsigned Multiply
//!
//!  Hardware multiplier is used to multiply two numbers. The calculation is
//!  automatically initiated after the second operand is loaded. Results are
//!  stored in RESLO and RESHI.
//!
//!  ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//!
//!               MSP430F5438A
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |                 |
//!            |                 |
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - MPY peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - NONE
//!
//******************************************************************************

void main (void)
{
    //Stop Watchdog Timer
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    //Set a 8-bit Operand into the specific Operand 1 register to specify
    //unsigned multiplication
    MPY32_setOperandOne8Bit(__MSP430_BASEADDRESS_MPY32__,
        MPY32_MULTIPLY_UNSIGNED,
        0x12);
    //Set 8- bit Operand 2 to begin the multiplication operation
    MPY32_setOperandTwo8Bit(__MSP430_BASEADDRESS_MPY32__,
        0x56);

    //Enter LPM4
    __bis_SR_register(LPM4_bits);
    //BREAKPOINT HERE to verify the correct Result in Registers,
    //RES0=0x060c RES1=0x0000
    __no_operation();
}

