#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/mpy32.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"

//******************************************************************************
//!
//! MPY - 8x8 Signed Multiply Accumulate
//!
//!  Hardware multiplier is used to multiply two numbers. The calculation is
//!  automatically initiated after the second operand is loaded.  A second
//!  multiply accumulate operation is performed after that. Results are stored
//!  in RESLO and RESHI.  SUMEXT contains the extended sign of result.
//!
//!  ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//!
//!               MSP430F5438A
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |                 |
//!            |                 |
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - MPY peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - NONE
//!
//******************************************************************************

void main (void)
{
    unsigned char value1,value2;

    //Stop WDT
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    //Set a 8-bit Operand into the specific Operand 1 register to specify
    //unsigned multiplication
    MPY32_setOperandOne16Bit(__MSP430_BASEADDRESS_MPY32__,
        MPY32_MULTIPLY_UNSIGNED,
        0x1234);
    //Set 8- bit Operand 2 to begin the multiplication operation
    MPY32_setOperandTwo16Bit(__MSP430_BASEADDRESS_MPY32__,
        0x5678);

    //Load Operand Values for Signed MAC
    value1 = 0x12;
    value2 = 0x16;

    //Set a 8-bit Operand into the specific Operand 1 register to specify
    //unsigned multiplication added to the current result
    MPY32_setOperandOne8Bit(__MSP430_BASEADDRESS_MPY32__,
        MPY32_MULTIPLYACCUMULATE_SIGNED,
        value1);

    //Set 8- bit Operand 2 to begin the multiplication operation
    MPY32_setOperandTwo8Bit(__MSP430_BASEADDRESS_MPY32__,
        value2);

    //Enter LPM4
    __bis_SR_register(LPM4_bits);

    //BREAKPOINT HERE to verify the correct Result in Registers
    __no_operation();
}

