//******************************************************************************
//!Toggle P2.1 using hardware TA1.0 output. Timer1_A is configured
//!for up/down mode with CCR0 defining period, TA1.0 also output on P1.1. In
//!this example, CCR0 is loaded with 250 and TA1.0 will toggle P1.1 at
//!TACLK/2*250. Thus the output frequency on P1.1 will be the TACLK/1000.
//!No CPU or software resources required.
//!As coded with TACLK = SMCLK, P2.1 output frequency is ~1.045M/1000.
//!SMCLK = MCLK = TACLK = default DCO ~1.045MHz
//!
//!		MSP430F5438A
//!		-------------------
//!		/|\|                   |
//!		 | |                   |
//!		 --|RST                |
//!		   |                   |
//!		   |       	 P2.1/TA1.0|--> SMCLK/1000
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - Timer peripheral
//! - GPIO Port peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - NONE
//!
//
//*****************************************************************************

#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/timera.h"
#include "driverlib/5xx_6xx/gpio.h"
#include "driverlib/5xx_6xx/wdt.h"

#define TIMERA_PERIOD 250
#define DUTY_CYCLE 250

void main (void)
{
    //Stop WDT
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    //P2.1 output
    //P2.1 option select
    GPIO_setAsPeripheralModuleFunctionOutputPin(__MSP430_BASEADDRESS_PORT2_R__,
        GPIO_PORT_P2,
        GPIO_PIN1
        );

    //Start timer in up down mode
    TimerA_configureUpDownMode(
        __MSP430_BASEADDRESS_T1A3__,
        TIMERA_CLOCKSOURCE_SMCLK,
        TIMERA_CLOCKSOURCE_DIVIDER_1,
        TIMERA_PERIOD,
        TIMERA_TAIE_INTERRUPT_DISABLE,
        TIMERA_CAPTURECOMPARE_INTERRUPT_DISABLE,
        TIMERA_DO_CLEAR
        );

    //Init compare mode
    TimerA_initCompare(__MSP430_BASEADDRESS_T1A3__,
        TIMERA_CAPTURECOMPARE_REGISTER_0,
        TIMERA_CAPTURECOMPARE_INTERRUPT_DISABLE,
        TIMERA_OUTPUTMODE_TOGGLE,
        DUTY_CYCLE
        );

    TimerA_startCounter(
            __MSP430_BASEADDRESS_T1A3__,
            TIMERA_UPDOWN_MODE
            );

    //Enter LPM0
    __bis_SR_register(LPM0_bits);

    //For debugger
    __no_operation();
}

