//******************************************************************************
//   MSP430TC0701 Demo - Timer_B, PWM TB1-6, Up Mode, DCO SMCLK
//
//   Description: This program generates six PWM outputs on P3/P5/P7 using
//   Timer_B configured for up mode. The value in CCR0, 512-1, defines the PWM
//   period and the values in CCR1-6 the PWM duty cycles. Using ~1048kHz SMCLK
//   as TBCLK, the timer period is ~488us.
//   ACLK = 32kHz, SMCLK = MCLK = TBCLK = default DCO ~1048kHz.
//
//                MSP430TC0701 
//             -----------------
//         /|\|              XIN|-
//          | |                 |  32kHz
//          --|RST          XOUT|-
//            |                 |
//            |         P5.7/TB1|--> CCR1 - 75% PWM
//            |         P7.4/TB2|--> CCR2 - 25% PWM
//            |        			|
//            |         		|
//            |      			|
//            |        			|
//
//******************************************************************************

#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/timerb.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"

void main(void)
{
	//Stop WDT
    WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

    GPIO_setAsPeripheralModuleFunctionOutputPin(__MSP430_BASEADDRESS_PORT5_R__,
	        GPIO_PORT_P5,
	        GPIO_PIN7
	        );

    GPIO_setAsPeripheralModuleFunctionOutputPin(__MSP430_BASEADDRESS_PORT7_R__,
	        GPIO_PORT_P7,
	        GPIO_PIN4
	        );

  
    //Start timer
	TimerB_configureUpMode(   __MSP430_BASEADDRESS_T0B7__,
	  TIMERB_CLOCKSOURCE_SMCLK,
	  TIMERB_CLOCKSOURCE_DIVIDER_1,
	  511,
	  TIMERB_TBIE_INTERRUPT_DISABLE,
	  TIMERB_CCIE_CCR0_INTERRUPT_DISABLE,
	  TIMERB_DO_CLEAR
	  );

	TimerB_startCounter(   __MSP430_BASEADDRESS_T0B7__,
		TIMERB_UP_MODE
		);



	//Initialize compare mode to generate PWM1
	TimerB_initCompare(__MSP430_BASEADDRESS_T0B7__,
	  TIMERB_CAPTURECOMPARE_REGISTER_1,
	  TIMERB_CAPTURECOMPARE_INTERRUPT_DISABLE,
	  TIMERB_OUTPUTMODE_RESET_SET,
	  383
	  );

	//Initialize compare mode to generate PWM2
	TimerB_initCompare(__MSP430_BASEADDRESS_T0B7__,
	  TIMERB_CAPTURECOMPARE_REGISTER_2,
	  TIMERB_CAPTURECOMPARE_INTERRUPT_ENABLE,
	  TIMERB_OUTPUTMODE_RESET_SET,
	  128
	  );


  _BIS_SR(LPM0_bits + GIE);                 // CPU off
}
