//******************************************************************************
//  MSP430F552x Demo - Timer_B, Toggle P1.0, CCR0 Cont. Mode ISR, DCO SMCLK
//
//  Description: Toggle P1.0 using software and TB_0 ISR. Toggles every
//  50000 SMCLK cycles. SMCLK provides clock source for TBCLK.
//  During the TB_0 ISR, P1.0 is toggled and 50000 clock cycles are added to
//  CCR0. TB_0 ISR is triggered every 50000 cycles. CPU is normally off and
//  used only during TB_ISR.
//  ACLK = n/a, MCLK = SMCLK = TBCLK = default DCO ~1.045MHz
//
//           MSP430F552x
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |           P1.0|-->LED
//
//******************************************************************************

#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/timerb.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"

#define COMPARE_VALUE 50000

void main(void)
{
	//Stop WDT
	WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

	//Set P1.0 to output direction
	GPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
	        GPIO_PORT_P1,
	        GPIO_PIN0
	        );

	//Start timer in continuous mode sourced by SMCLK
	TimerB_configureContinuousMode( __MSP430_BASEADDRESS_T0B7__,
	        TIMERB_CLOCKSOURCE_SMCLK,
	        TIMERB_CLOCKSOURCE_DIVIDER_1,
	        TIMERB_TBIE_INTERRUPT_DISABLE,
	        TIMERB_DO_CLEAR
	        );

	 //Initiaze compare mode
	    TimerB_initCompare(__MSP430_BASEADDRESS_T0B7__,
	        TIMERB_CAPTURECOMPARE_REGISTER_0,
	        TIMERB_CAPTURECOMPARE_INTERRUPT_ENABLE,
	        TIMERB_OUTPUTMODE_OUTBITVALUE,
	        COMPARE_VALUE
	        );

	TimerB_startCounter( __MSP430_BASEADDRESS_T0B7__,
	    		TIMERB_CONTINUOUS_MODE
	                );

  __bis_SR_register(LPM0_bits + GIE);       // Enter LPM0, enable interrupts
  __no_operation();                         // For debugger
}

// Timer B0 interrupt service routine
#pragma vector=TIMERB0_VECTOR
__interrupt void TIMERB0_ISR (void)
{
	GPIO_toggleOutputOnPin(
	        __MSP430_BASEADDRESS_PORT1_R__,
	        GPIO_PORT_P1,
	        GPIO_PIN0
	        );

	// Add Offset to CCR0 [Cont mode]
	TimerB_setCompareValue(__MSP430_BASEADDRESS_T0B7__,
	        TIMERB_CAPTURECOMPARE_REGISTER_0,
	        COMPARE_VALUE
	        );

}

