//******************************************************************************
//  MSP430F51x2 Demo - TimerD0, Toggle P1.0, Overflow ISR, DCO SMCLK
//
//  Description: Toggle P1.0 using software and TimerD0 overflow ISR.
//  In this example an ISR triggers when TD overflows. Inside the TD
//  overflow ISR P1.0 is toggled. Toggle rate is approximatlely 16Hz.
//  Proper use of the TDIV interrupt vector generator is demonstrated.
//  ACLK = n/a, MCLK = SMCLK = TDCLK = default DCO ~1.045MHz
//
//           MSP430F51x2
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |           P1.0|-->LED
//
//******************************************************************************
#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/timerd.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"

void main(void)
{
	//Stop WDT
	WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

	//Set P1.0 to output direction
	GPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
			GPIO_PORT_P1,
		    GPIO_PIN0
		    );

    TimerD_configureContinuousMode( __MSP430_BASEADDRESS_T0D3__,
  	  TIMERD_CLOCKSOURCE_SMCLK,
  	  TIMERD_CLOCKSOURCE_DIVIDER_1,
  	  TIMERD_CLOCKINGMODE_EXTERNAL_CLOCK,
  	  TIMERD_TDIE_INTERRUPT_ENABLE,
  	  TIMERD_DO_CLEAR
  	  );

    TimerD_startCounter( __MSP430_BASEADDRESS_T0D3__,
    		TIMERD_CONTINUOUS_MODE
    		);

  __bis_SR_register(LPM0_bits + GIE);       // Enter LPM0, enable interrupts
  __no_operation();                         // For debugger
}

// Timer0_D1 Interrupt Vector (TDIV) handler
#pragma vector=TIMER0_D1_VECTOR
__interrupt void TIMER0_D1_ISR(void)
{
  switch(__even_in_range(TD0IV,30))
  {
    case  0: break;                          // No interrupt
    case  2: break;                          // CCR1 not used
    case  4: break;                          // CCR2 not used
    case  6: break;                          // reserved
    case  8: break;                          // reserved
    case 10: break;                          // reserved
    case 12: break;                          // reserved
    case 14: break;
    case 16: // overflow
    		GPIO_toggleOutputOnPin(
    		  __MSP430_BASEADDRESS_PORT1_R__,
    		  GPIO_PORT_P1,
    		  GPIO_PIN0
    		  );
             break;
    case 18: break;                          // Clock fail low
    case 20: break;                          // Clock fail high
    case 22: break;                          // Hi-res freq locked
    case 24: break;                          // Hi-res freq unlocked
    case 26: break;                          // reserved
    case 28: break;                          // reserved
    case 30: break;                          // reserved       
    default: break; 
  }
}

