//******************************************************************************
//  MSP430F51x2 Demo - TimerD0, Toggle P2.3/TD0.0, Up/Down Mode, 32kHz ACLK
//
//  Description: Toggle P1.6 using hardware TD0.0 output. TimerD0 is configured
//  for up/down mode with CCR0 defining period, TD0.0 also output on P1.6. In
//  this example, CCR0 is loaded with 5 and TD0.0 will toggle P2.3 at TDCLK/2*5.
//  Thus the output frequency on P1.6 will be the TDCLK/20. No CPU or software
//  resources required. Normal operating mode is LPM3.
//  As coded with TDCLK = ACLK, P2.3 output frequency = 32768/20 = 1.6384kHz
//  ACLK = TDCLK = LFXT1 = 32kHz, MCLK = default DCO ~1.045MHz
//
//               MSP430F51x2
//            -------------------
//        /|\ |              XIN|-
//         |  |                 | 32kHz
//         ---|RST          XOUT|-
//           |                   |
//           |         P1.6/TD0.0|-->ACLK/20
//
//******************************************************************************
#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/timerd.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"
#include "driverlib/5xx_6xx/ucs.h"

void main(void)
{
  //Stop WDT
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

  // Configure ports
  GPIO_setAsPeripheralModuleFunctionOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
		  GPIO_PORT_P1,
		  GPIO_PIN6
		  );

  // XT1 configure
  GPIO_setAsPeripheralModuleFunctionInputPin(__MSP430_BASEADDRESS_PORTJ_R__,
		  GPIO_PORT_PJ,
		   GPIO_PIN4 + GPIO_PIN5
		  );

  UCS_clockSignalInit(__MSP430_BASEADDRESS_UCS__,
  		  UCS_FLLREF,
  		  UCS_XT1CLK_SELECT,
  		  UCS_CLOCK_DIVIDER_1
  		  );

  UCS_LFXT1Start ( __MSP430_BASEADDRESS_UCS__,
		  UCS_XT1_DRIVE3,
		  UCS_XCAP_3
      );

   UCS_clockSignalInit(__MSP430_BASEADDRESS_UCS__,
    		  UCS_ACLK,
    		  UCS_XT1CLK_SELECT,
    		  UCS_CLOCK_DIVIDER_1
    		  );

  TimerD_initCompare(__MSP430_BASEADDRESS_T0D3__,
            TIMERD_CAPTURECOMPARE_REGISTER_0,
            TIMERD_CAPTURECOMPARE_INTERRUPT_DISABLE,
            TIMERD_OUTPUTMODE_TOGGLE,
            5
            );


  TimerD_configureUpDownMode(
		  __MSP430_BASEADDRESS_T0D3__,
          TIMERD_CLOCKSOURCE_ACLK,
          TIMERD_CLOCKSOURCE_DIVIDER_1,
          TIMERD_CLOCKINGMODE_EXTERNAL_CLOCK,
          5,
          TIMERD_TDIE_INTERRUPT_DISABLE,
          TIMERD_CAPTURECOMPARE_INTERRUPT_DISABLE,
          TIMERD_DO_CLEAR
          );

  TimerD_startCounter(
  		  __MSP430_BASEADDRESS_T0D3__,
  		  TIMERD_UPDOWN_MODE
  		  );

  __bis_SR_register(LPM3_bits);             // Enter LPM3
  __no_operation();                         // For debugger
}
