//*******************************************************************************
//  MSP430F51x2 Demo - TimerD0, PWM TD0.1-2, Up/Down Mode, DCO SMCLK
//
//  Description: This program generates two PWM outputs on P1.7 and P2.0 using
//  TimerD0 configured for up/down mode. The value in CCR0, 128, defines the
//  PWM period/2 and the values in CCR1 and CCR2 the PWM duty cycles. Using
//  ~1.045MHz SMCLK as TDCLK, the timer period is ~233us with a 75% duty cycle
//  on P1.7 and 25% on P2.0. PWM freq = 4kHz. 
//  SMCLK = MCLK = TDCLK = default DCO ~1.045MHz.
//
//                MSP430F51x2
//            -------------------
//        /|\|                   |
//         | |                   |
//         --|RST                |
//           |                   |
//           |         P1.7/TD0.1|--> CCR1 - 75% PWM
//           |         P2.0/TD0.2|--> CCR2 - 25% PWM
//
//******************************************************************************
#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/timerd.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"
#include "driverlib/5xx_6xx/ucs.h"

void main(void)
{
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);
  // configure ports
  GPIO_setAsPeripheralModuleFunctionOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
  		  GPIO_PORT_P1,
  		  GPIO_PIN7
  		  );

  
  GPIO_setAsPeripheralModuleFunctionOutputPin(__MSP430_BASEADDRESS_PORT2_R__,
  		  GPIO_PORT_P2,
  		  GPIO_PIN0
  		  );


  TimerD_initCompare(__MSP430_BASEADDRESS_T0D3__,
              TIMERD_CAPTURECOMPARE_REGISTER_1,
              TIMERD_CAPTURECOMPARE_INTERRUPT_DISABLE,
              TIMERD_OUTPUTMODE_TOGGLE_SET,
              32
              );

  TimerD_initCompare(__MSP430_BASEADDRESS_T0D3__,
              TIMERD_CAPTURECOMPARE_REGISTER_2,
              TIMERD_CAPTURECOMPARE_INTERRUPT_DISABLE,
              TIMERD_OUTPUTMODE_TOGGLE_SET,
              96
              );

  TimerD_configureUpDownMode(
  		  __MSP430_BASEADDRESS_T0D3__,
            TIMERD_CLOCKSOURCE_SMCLK,
            TIMERD_CLOCKSOURCE_DIVIDER_1,
            TIMERD_CLOCKINGMODE_EXTERNAL_CLOCK,
            128,
            TIMERD_TDIE_INTERRUPT_DISABLE,
            TIMERD_CAPTURECOMPARE_INTERRUPT_DISABLE,
            TIMERD_DO_CLEAR
            );
  TimerD_startCounter(
    		  __MSP430_BASEADDRESS_T0D3__,
    		  TIMERD_UP_MODE
    		  );

  __bis_SR_register(LPM0_bits);             // Enter LPM0
  __no_operation();                         // For debugger
}

