#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/tlv.h"

//******************************************************************************
//!
//! ADC12 - Sample A10 Internal Temp Sensor as Input, AVcc Ref
//!  
//!  After initialization, the the calibration constants for the 
//!  unit are read in through the TLV. A single sample is made on A10 with 
//!  reference to internal 1.5V Vref. Software sets ADC12SC to start sample and 
//!  conversion - ADC12SC automatically cleared at EOC. ADC12 internal 
//!  oscillator times sample and conversion. In Mainloop MSP430 waits in LPM4 
//!  to save power until ADC10 conversion complete, ADC12_ISR will force exit 
//!  from any LPMx in Mainloop on reti.
//!
//!  ACLK = n/a, MCLK = SMCLK = default DCO ~ 1.045MHz, ADC12CLK = ADC12OSC
//!
//!  Uncalibrated temperature measured from device to device will vary do to
//!  slope and offset variance from device to device - please see datasheet.
//!
//!                MSP430F5438A
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |Temp Sensor-->A10|
//!            |                 |
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - WDT
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - NONE
//!
//******************************************************************************
void main()
{
  //Stop WDT
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);
  
  unsigned int status = TLV_getDeviceType();
  while (status != 0x8005);                  // trap

  // Check whether the device has a CPUXV2
  status = TLV_getPeripheral(TLV_PID_MSP430CPUXV2, 0);
  while (status != 0x2300);                 // trap
}
