#include "inc/hw_memmap.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "driverlib/5xx_6xx/gpio.h"

//******************************************************************************
//!
//! WDT - Failsafe Clock, 32kHz ACLK
//!
//!  Allow WDT+ in watchdog to timeout sourced by ACLK. LPM3 is entered, this
//!  example will demonstrate WDT+ feature by automatically re-enabling WDT+
//!  clock source as DCO if external XTAL fails. This can be seen as a continued,
//!  though faster as clocked by DCO, watchdog timeout which will toggle on P1.0
//!  in main function.
//!  ACLK = 32768, MCLK = SMCLK = default DCO ~1.045MHz
//!
//!                MSP430F552x
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |             P1.0|-->LED
//!            |                 |
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - WDT peripheral
//! - GPIO Port peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - None.
//!
//******************************************************************************

void main (void)
{
    //Watchdog mode -> reset after expired time; WDT is clocked by ACLK
    //Set Watchdog Timer timeout 1s - SET BREAKPOINT HERE
    WDT_watchdogTimerInit(__MSP430_BASEADDRESS_WDT_A__,
        WDT_CLOCKSOURCE_ACLK,
        WDT_CLOCKDIVIDER_32K);
    //Set P1.0 to output direction
    GPIO_setAsOutputPin(__MSP430_BASEADDRESS_PORT1_R__,
        GPIO_PORT_P1,
        GPIO_PIN0
        );

    //Toggle P1.0
    GPIO_toggleOutputOnPin(
        __MSP430_BASEADDRESS_PORT1_R__,
        GPIO_PORT_P1,
        GPIO_PIN0
        );

    //Enter LPM3
    __bis_SR_register(LPM3_bits + GIE);
    //For debugger
    __no_operation();
}

