//******************************************************************************
//!
//! MPY - Fractional mode, Q15 multiplication
//!
//!  The example illustrates multiplication of 2 Q15 numbers in fractional
//!  mode. The result is a Q15 (15 bit) number stored in the RES1 register.
//!  It can be viewed in the debugger window.
//!
//!   ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//!
//!  Tested On: MSP430F5438A,MSP430FR5739,MSP430FR5969
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |                 |
//!            |                 |
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - MPY peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - NONE
//!
//******************************************************************************
#include "inc/hw_memmap.h"
#include "mpy32.h"
#include "wdt_a.h"
#include "gpio.h"

unsigned long Result;
unsigned int Result_Q15;

void main (void)
{
    //Stop Watchdog Timer
    WDT_A_hold(WDT_A_BASE);

    //Enable Fraction Mode
    MPY32_setFractionMode(MPY32_BASE);

    //Set a 16-bit Operand into the specific Operand 1 register to specify
    //signed multiplication
    MPY32_setOperandOne16Bit(MPY32_BASE,
        MPY32_MULTIPLY_SIGNED,
        0x7D70);
    //Set 16-bit Operand 2 to begin the multiplication operation
    MPY32_setOperandTwo16Bit(MPY32_BASE,
        0x1000);

    //Read out Result
    Result = MPY32_getResult32Bit(MPY32_BASE);

    Result_Q15 = (Result >> 16);
    //Q15 result == 0x0FAE

    //Disable Fraction Mode
    MPY32_resetFractionMode(MPY32_BASE);

    //Enter LPM4
    __bis_SR_register(LPM4_bits);

    //BREAKPOINT HERE to verify the correct Result_Q15
    __no_operation();
}

