//******************************************************************************
//!
//! MPY - 16x16 Signed Multiply
//!
//!  Hardware multiplier is used to multiply two numbers. The calculation is
//!  automatically initiated after the second operand is loaded. Results are
//!  stored in RESLO, RESHI and SUMEXT = FFFF if result is negative, SUMEXT = 0
//!  otherwise. Result is also stored as Result variable.
//!
//!  ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//!
//!  Tested On: MSP430F5438A,MSP430FR5739,MSP430FR5969
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |                 |
//!            |                 |
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - MPY peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - NONE
//!
//******************************************************************************
#include "inc/hw_memmap.h"
#include "mpy32.h"
#include "wdt_a.h"
#include "gpio.h"

signed int multiplier = 0x1234;
signed int operand = -6578;
signed long Result;

void main (void)
{
    //Stop Watchdog Timer
    WDT_A_hold(WDT_A_BASE);

    //Set a 16-bit Operand into the specific Operand 1 register to specify
    //signed multiplication
    MPY32_setOperandOne16Bit(MPY32_BASE,
        MPY32_MULTIPLY_SIGNED,
        multiplier);
    //Set 16-bit Operand 2 to begin the multiplication operation
    MPY32_setOperandTwo16Bit(MPY32_BASE,
        operand);

    //Read out the result
    Result = MPY32_getResult32Bit(MPY32_BASE);

    //Enter LPM4
    __bis_SR_register(LPM4_bits);

    //BREAKPOINT HERE to verify the correct Result
    __no_operation();
}

