//******************************************************************************
//!
//! MPY - 8x8 Signed Multiply
//!
//!  Hardware multiplier is used to multiply two numbers. The calculation is
//!  automatically initiated after the second operand is loaded. Results are
//!  stored in RESLO, RESHI and SUMEXT = FFFF if result is negative, SUMEXT = 0
//!  otherwise.
//!
//!  ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//!
//!  Tested On: MSP430F5438A,MSP430FR5739,MSP430FR5969
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |                 |
//!            |                 |
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - MPY peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - NONE
//!
//******************************************************************************
#include "inc/hw_memmap.h"
#include "mpy32.h"
#include "wdt_a.h"
#include "gpio.h"

void main (void)
{
    unsigned char value1,value2;

    //Stop Watchdog Timer
    WDT_A_hold(WDT_A_BASE);

    //Assign operands for signed multiplication
    value1 = 0x04; //value1 == 4
    value2 = 0x84; //value2 == -124

    //Set a 8-bit Operand into the specific Operand 1 register to specify
    //signed multiplication
    MPY32_setOperandOne8Bit(MPY32_BASE,
        MPY32_MULTIPLY_SIGNED,
        value1);

    //Set 8- bit Operand 2 to begin the multiplication operation
    MPY32_setOperandTwo8Bit(MPY32_BASE,
        value2);

    //Enter LPM4
    __bis_SR_register(LPM4_bits);
    //BREAKPOINT HERE to verify the correct Result in Registers
    __no_operation();
}

