//****************************************************************************/
//! The device is set to core level 3. The PMM_setVcore function
//! also sets the SVS and SVM  (high & low side) modules as required for a
//! core setting of 3.
//!
//!
//!                MSP430F54xA
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |            Vcore|--> Monitor voltage on Vcore pin
//!            |             P1.0|-->LED
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - PMM peripheral
//! - GPIO Port peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - NONE.
//****************************************************************************/

#include "inc/hw_memmap.h"
#include "pmm.h"
#include "wdt_a.h"
#include "gpio.h"

unsigned int status = STATUS_SUCCESS ;

void main (void)
{
    //Stop WDT
    WDT_A_hold(WDT_A_BASE);
    status = PMM_setVCore(PMM_BASE,
        PMMCOREV_3
        );

    //Use the line below to bring the level back to 0
    status = PMM_setVCore(PMM_BASE,
        PMMCOREV_0
        );

    //Set P1.0 to output direction
    GPIO_setAsOutputPin(
        GPIO_PORT_P1,
        GPIO_PIN0
        );

    //continuous loop
    while (1)
    {
        //Toggle P1.0
        GPIO_toggleOutputOnPin(
            GPIO_PORT_P1,
            GPIO_PIN0
            );
        //Delay
        __delay_cycles(20000);
    }
}

