//******************************************************************************
//!  MSP430F5529 Demo - RAM controller turn off RAM sector
//!
//!  Description: Switch RAM sector off instead of retention state during low
//!  low power modes.
//!
//!  Tested On: MSP430F5529
//!         ---------------
//!        |               |
//!        |               |
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - TIMER_A peripheral
//! - GPIO peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - Timer A0
//!
//
//*****************************************************************************

#include "inc/hw_memmap.h"
#include "ram.h"
#include "wdt_a.h"
#include "gpio.h"
#include "timer_a.h"

unsigned char returnValue;

void main (void)
{
    //Stop WDT
    WDT_A_hold(WDT_A_BASE);

    //Set P1.0 to output direction
    GPIO_setAsOutputPin(
        GPIO_PORT_P1,
        GPIO_PIN0
        );

    //Start timer
    TIMER_A_startUpMode(TIMER_A0_BASE,
        TIMER_A_CLOCKSOURCE_ACLK,
        TIMER_A_CLOCKSOURCE_DIVIDER_1,
        25000,
        TIMER_A_TAIE_INTERRUPT_DISABLE,
        TIMER_A_CAPTURECOMPARE_INTERRUPT_ENABLE,
        TIMER_A_DO_CLEAR
        );

    //RAM controller sector off
    RAM_setSectorOff(RAM_BASE,
        RAM_SECTOR2
        ) ;

    //Enter LPM0, enable interrupts
    __bis_SR_register(LPM3_bits + GIE);

    //For debugger
    __no_operation();
}

//******************************************************************************
//
//This is the Timer A0 interrupt vector service routine.
//
//******************************************************************************
#pragma vector=TIMER0_A0_VECTOR
__interrupt void TIMER0_A0_ISR (void)
{
    returnValue = RAM_getSectorState(RAM_BASE,
        RAM_SECTOR0 +
        RAM_SECTOR1 +
        RAM_SECTOR2 +
        RAM_SECTOR3);

    //Toggle P1.0 using exclusive-OR
    GPIO_toggleOutputOnPin(
        GPIO_PORT_P1,
        GPIO_PIN0
        );
}

