//******************************************************************************
//  MSP430F51x2 Demo - TimerD0, Toggle P1.0, CCR0 Cont. Mode ISR, DCO SMCLK
//
//  Description: Toggle P1.0 using software and TD_0 ISR. Toggles every
//  50000 SMCLK cycles. SMCLK provides clock source for TDCLK.
//  During the TD_0 ISR, P1.0 is toggled and 50000 clock cycles are added to
//  CCR0. TD_0 ISR is triggered every 50000 cycles. CPU is normally off and
//  used only during TD_ISR. Toggle rate = 50000/1.045Mhz ~ 48ms. 
//  ACLK = n/a, MCLK = SMCLK = TDCLK = default DCO ~1.045MHz
//
//           MSP430F51x2
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |           P1.0|-->LED
//
//******************************************************************************

#include "inc/hw_memmap.h"
#include "timer_d.h"
#include "wdt_a.h"
#include "gpio.h"

void main(void)
{
   //Stop WDT
   WDT_A_hold(WDT_A_BASE);

   //Set P1.0 to output direction
   GPIO_setAsOutputPin(
	      GPIO_PORT_P1,
	      GPIO_PIN0
	      );

  //Start timer in continuous mode sourced by SMCLK
  TIMER_D_configureContinuousMode( TIMER_D0_BASE,
	  TIMER_D_CLOCKSOURCE_SMCLK,
	  TIMER_D_CLOCKSOURCE_DIVIDER_1,
	  TIMER_D_CLOCKINGMODE_EXTERNAL_CLOCK,
	  TIMER_D_TDIE_INTERRUPT_DISABLE,
	  TIMER_D_DO_CLEAR
	  );



  TIMER_D_startCounter( TIMER_D0_BASE,
		  TIMER_D_CONTINUOUS_MODE
		  );

  //Initiaze compare mode
  TIMER_D_initCompare(TIMER_D0_BASE,
          TIMER_D_CAPTURECOMPARE_REGISTER_0,
          TIMER_D_CAPTURECOMPARE_INTERRUPT_ENABLE,
          TIMER_D_OUTPUTMODE_OUTBITVALUE,
          50000
          );

  __bis_SR_register(LPM0_bits + GIE);       // Enter LPM0, enable interrupts
  __no_operation();                         // For debugger
}

// Timer0_D0 interrupt service routine
#pragma vector=TIMER0_D0_VECTOR
__interrupt void TIMER0_D0_ISR(void)
{
  //Toggle P1.0
  GPIO_toggleOutputOnPin(
	  
	  GPIO_PORT_P1,
	  GPIO_PIN0
	  );

  //Add Offset to CCR0
  TIMER_D_setCompareValue(TIMER_D0_BASE,
      TIMER_D_CAPTURECOMPARE_REGISTER_0,
      5000
      );
}

