//******************************************************************************
//  MSP430F51x2 Demo - TimerD0, Toggle P2.3/TD0.0, Up/Down Mode, 32kHz ACLK
//
//  Description: Toggle P1.6 using hardware TD0.0 output. TimerD0 is configured
//  for up/down mode with CCR0 defining period, TD0.0 also output on P1.6. In
//  this example, CCR0 is loaded with 5 and TD0.0 will toggle P2.3 at TDCLK/2*5.
//  Thus the output frequency on P1.6 will be the TDCLK/20. No CPU or software
//  resources required. Normal operating mode is LPM3.
//  As coded with TDCLK = ACLK, P2.3 output frequency = 32768/20 = 1.6384kHz
//  ACLK = TDCLK = LFXT1 = 32kHz, MCLK = default DCO ~1.045MHz
//
//               MSP430F51x2
//            -------------------
//        /|\ |              XIN|-
//         |  |                 | 32kHz
//         ---|RST          XOUT|-
//           |                   |
//           |         P1.6/TD0.0|-->ACLK/20
//
//******************************************************************************
#include "inc/hw_memmap.h"
#include "timer_d.h"
#include "wdt_a.h"
#include "gpio.h"
#include "ucs.h"

void main(void)
{
  //Stop WDT
  WDT_A_hold(WDT_A_BASE);

  // Configure ports
  GPIO_setAsPeripheralModuleFunctionOutputPin(
		  GPIO_PORT_P1,
		  GPIO_PIN6
		  );

  // XT1 configure
  GPIO_setAsPeripheralModuleFunctionInputPin(
		  GPIO_PORT_PJ,
		   GPIO_PIN4 + GPIO_PIN5
		  );

  UCS_clockSignalInit(UCS_BASE,
  		  UCS_FLLREF,
  		  UCS_XT1CLK_SELECT,
  		  UCS_CLOCK_DIVIDER_1
  		  );

  UCS_LFXT1Start ( UCS_BASE,
		  UCS_XT1_DRIVE3,
		  UCS_XCAP_3
      );

   UCS_clockSignalInit(UCS_BASE,
    		  UCS_ACLK,
    		  UCS_XT1CLK_SELECT,
    		  UCS_CLOCK_DIVIDER_1
    		  );

  TIMER_D_initCompare(TIMER_D0_BASE,
            TIMER_D_CAPTURECOMPARE_REGISTER_0,
            TIMER_D_CAPTURECOMPARE_INTERRUPT_DISABLE,
            TIMER_D_OUTPUTMODE_TOGGLE,
            5
            );


  TIMER_D_configureUpDownMode(
		  TIMER_D0_BASE,
          TIMER_D_CLOCKSOURCE_ACLK,
          TIMER_D_CLOCKSOURCE_DIVIDER_1,
          TIMER_D_CLOCKINGMODE_EXTERNAL_CLOCK,
          5,
          TIMER_D_TDIE_INTERRUPT_DISABLE,
          TIMER_D_CAPTURECOMPARE_INTERRUPT_DISABLE,
          TIMER_D_DO_CLEAR
          );

  TIMER_D_startCounter(
  		  TIMER_D0_BASE,
  		  TIMER_D_UPDOWN_MODE
  		  );

  __bis_SR_register(LPM3_bits);             // Enter LPM3
  __no_operation();                         // For debugger
}
