//*******************************************************************************
//  MSP430F51x2 Demo - TimerD0, PWM TD0.1-2, Up/Down Mode, DCO SMCLK
//
//  Description: This program generates two PWM outputs on P1.7 and P2.0 using
//  TimerD0 configured for up/down mode. The value in CCR0, 128, defines the
//  PWM period/2 and the values in CCR1 and CCR2 the PWM duty cycles. Using
//  ~1.045MHz SMCLK as TDCLK, the timer period is ~233us with a 75% duty cycle
//  on P1.7 and 25% on P2.0. PWM freq = 4kHz. 
//  SMCLK = MCLK = TDCLK = default DCO ~1.045MHz.
//
//                MSP430F51x2
//            -------------------
//        /|\|                   |
//         | |                   |
//         --|RST                |
//           |                   |
//           |         P1.7/TD0.1|--> CCR1 - 75% PWM
//           |         P2.0/TD0.2|--> CCR2 - 25% PWM
//
//******************************************************************************
#include "inc/hw_memmap.h"
#include "timer_d.h"
#include "wdt_a.h"
#include "gpio.h"
#include "ucs.h"

void main(void)
{
  WDT_A_hold(WDT_A_BASE);
  // configure ports
  GPIO_setAsPeripheralModuleFunctionOutputPin(
  		  GPIO_PORT_P1,
  		  GPIO_PIN7
  		  );

  
  GPIO_setAsPeripheralModuleFunctionOutputPin(
  		  GPIO_PORT_P2,
  		  GPIO_PIN0
  		  );


  TIMER_D_initCompare(TIMER_D0_BASE,
              TIMER_D_CAPTURECOMPARE_REGISTER_1,
              TIMER_D_CAPTURECOMPARE_INTERRUPT_DISABLE,
              TIMER_D_OUTPUTMODE_TOGGLE_SET,
              32
              );

  TIMER_D_initCompare(TIMER_D0_BASE,
              TIMER_D_CAPTURECOMPARE_REGISTER_2,
              TIMER_D_CAPTURECOMPARE_INTERRUPT_DISABLE,
              TIMER_D_OUTPUTMODE_TOGGLE_SET,
              96
              );

  TIMER_D_configureUpDownMode(
  		  TIMER_D0_BASE,
            TIMER_D_CLOCKSOURCE_SMCLK,
            TIMER_D_CLOCKSOURCE_DIVIDER_1,
            TIMER_D_CLOCKINGMODE_EXTERNAL_CLOCK,
            128,
            TIMER_D_TDIE_INTERRUPT_DISABLE,
            TIMER_D_CAPTURECOMPARE_INTERRUPT_DISABLE,
            TIMER_D_DO_CLEAR
            );
  TIMER_D_startCounter(
    		  TIMER_D0_BASE,
    		  TIMER_D_UP_MODE
    		  );

  __bis_SR_register(LPM0_bits);             // Enter LPM0
  __no_operation();                         // For debugger
}

