//******************************************************************************
//!  This program demonstrates using VLO to source ACLK
//!  ACLK = VLO = 9.4kHz (typical)
//!
//!                MSP430F5438A
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |                 |
//!            |            P11.0|-->ACLK
//!            |                 |
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - UCS module
//! - GPIO Port peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - None.
//*****************************************************************************

#include "inc/hw_memmap.h"
#include "ucs.h"
#include "wdt_a.h"
#include "gpio.h"
#include "sfr.h"

//*****************************************************************************
//
//Variable to store current clock values
//
//*****************************************************************************
unsigned long clockValue;

//*****************************************************************************
//
//Variable to store status of Oscillator fault flags
//
//*****************************************************************************
unsigned int status;

void main (void)
{
    //Stop watchdog timer
    WDT_A_hold(WDT_A_BASE);

    //VLO Clock Sources ACLK
    UCS_clockSignalInit(
        UCS_BASE,
        UCS_ACLK,
        UCS_VLOCLK_SELECT,
        UCS_CLOCK_DIVIDER_1
        );
    
    //VLO Clock Sources ACLK
    UCS_clockSignalInit(
        UCS_BASE,
        UCS_FLLREF,
        UCS_REFOCLK_SELECT,
        UCS_CLOCK_DIVIDER_1
        );

    //ACLK set out to pin
    GPIO_setAsPeripheralModuleFunctionOutputPin(
        GPIO_PORT_P11,
        GPIO_PIN0
        );

    // Enable global oscillator fault flag
    SFR_enableInterrupt(SFR_BASE,
                        SFR_OSCILLATOR_FAULT_INTERRUPT
                        );
    
    // Enable global interrupt
    __bis_SR_register(GIE);   
    
    clockValue = UCS_getACLK(UCS_BASE);

    //Enter LPM3
    __bis_SR_register(LPM3_bits);

    //For debugger
    __no_operation();
}

#pragma vector=UNMI_VECTOR
__interrupt void NMI_ISR(void)
{
  do {
    // If it still can't clear the oscillator fault flags after the timeout, 
    // trap and wait here.
    status = UCS_clearAllOscFlagsWithTimeout(UCS_BASE,
                                             1000
                                             );
  } while(status != 0);
}
