#include "inc/hw_memmap.h"
#include "usci_i2c.h"
#include "wdt_a.h"
#include "gpio.h"

//*****************************************************************************
//!
//! This example shows how to configure the I2C module as a slave for
//! single byte transmission in interrupt driven mode. The address of the slave
//! module is set in this example.
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - I2C peripheral
//! - GPIO Port peripheral (for I2C pins)
//! - SCL2
//! - SDA
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - USCI_B0_VECTOR.
//!
//*****************************************************************************
//*****************************************************************************
//
//Set the address for slave module. This is a 7-bit address sent in the
//following format:
//[A6:A5:A4:A3:A2:A1:A0:RS]
//
//A zero in the "RS" position of the first byte means that the master
//transmits (sends) data to the selected slave, and a one in this position
//means that the master receives data from the slave.
//
//*****************************************************************************
#define SLAVE_ADDRESS 0x48

unsigned char transmitData;

void main (void)
{
    //Stop WDT
    WDT_A_hold(WDT_A_BASE);

    //Assign I2C pins to USCI_B0
    GPIO_setAsPeripheralModuleFunctionInputPin(
        GPIO_PORT_P3,
        GPIO_PIN1 + GPIO_PIN2
        );

    //Initialize I2C as a slave device
    USCI_I2C_slaveInit(USCI_B0_BASE,
        SLAVE_ADDRESS
        );
    //Enable I2C Module to start operations
    USCI_I2C_enable(USCI_B0_BASE);

    //Set in transmit mode
    USCI_I2C_setMode(USCI_B0_BASE,
        USCI_I2C_TRANSMIT_MODE
        );
    //Initialize transmit data buffer
    transmitData = 0xAB;

    while(1)
    {

      // Poll for start
      while(0x00 == USCI_I2C_getInterruptStatus(USCI_B0_BASE, USCI_I2C_START_INTERRUPT));
  
      // Poll for transmit flag
      while(0x00 == USCI_I2C_getInterruptStatus(USCI_B0_BASE, USCI_I2C_TRANSMIT_INTERRUPT));
    
       //Transmit data
      USCI_I2C_slaveDataPut(USCI_B0_BASE,
      transmitData
      );
      // Increment TXData
      transmitData++;
      
      // Poll will STOP is received
       while(0x00 == USCI_I2C_getInterruptStatus(USCI_B0_BASE, USCI_I2C_STOP_INTERRUPT));
    }
}
