#include "inc/hw_memmap.h"
#include "cs.h"
#include "wdt_a.h"
#include "gpio.h"

//******************************************************************************
//!   MSP430FR57xx Demo - Configure MCLK for 8MHz operation
//!
//!   Description: Configure ACLK = SMCLK = MCLK = 8MHz
//!
//!           MSP430FR57x
//!         ---------------
//!     /|\|               |
//!      | |               |
//!      --|RST            |
//!        |               |
//!        |               |
//!        |          P2.0 |---> ACLK = MCLk = 8MHz
//!
//!
//******************************************************************************

void main(void)
{
  //Stop WDT
  WDT_A_hold(WDT_A_BASE);

  //Set DCO Frequency to 8MHz
  CS_setDCOFreq(CS_BASE,CS_DCORSEL_0,CS_DCOFSEL_3);

  //configure MCLK, SMCLK and ACLK to be source by DCOCLK
  CS_clockSignalInit(CS_BASE,CS_ACLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_1);
  CS_clockSignalInit(CS_BASE,CS_SMCLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_1);
  CS_clockSignalInit(CS_BASE,CS_MCLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_1);

  //Set P2.0 as Output Low (for setup as ACLK).
  /*
   
   * Select Port 2
   * Set Pin 0 to output Low.
   */
  GPIO_setOutputLowOnPin(
			GPIO_PORT_P2,
			GPIO_PIN0
	);

  //Set P2.0 as Ternary Module Function Output.
  /*
   
   * Select Port 2
   * Set Pin 0 to output Ternary Module Function, (ACLK).
   */
  GPIO_setAsPeripheralModuleFunctionOutputPin(
			GPIO_PORT_P2,
			GPIO_PIN0,
			GPIO_TERNARY_MODULE_FUNCTION
	);

  while(1);
}

