
#include "inc/hw_memmap.h"
#include "cs.h"
#include "wdt_a.h"
#include "gpio.h"

//******************************************************************************
//!   MSP430FR57xx Demo - Configure MCLK for 24MHz operation
//!
//!   Description: Configure ACLK = SMCLK = MCLK = 24MHz
//!   IMPORTANT NOTE: While the FR5739 is capable of operation using a 24MHz
//!   MCLK; the throughput of the device is dependednt on accesses to FRAM.
//!   The maximum speed for accessing FRAM is limited to 8MHz*.
//!   Wait states are inserted automatically when the FRAM is accessed at
//!   speeds higher than 8MHz to prevent timing violations.
//!   Refer to the FRAM Clock System chapter of the User's Guide.
//!   * Refer device D/s for typical numbers
//!
//!           MSP430FR57x
//!         ---------------
//!     /|\|               |
//!      | |               |
//!      --|RST            |
//!        |               |
//!        |               |
//!        |          P2.0 |---> ACLK = MCLk = 24MHz
//!
//!   Texas Instruments Inc.
//!   February 2012
//!   Built with IAR Embedded Workbench Version: 5.40 & Code Composer Studio V5.1
//******************************************************************************

	unsigned long clockValue;
	
void main(void)
{

	
  //Stop WDT
  WDT_A_hold(WDT_A_BASE);

  CS_setDCOFreq(CS_BASE,CS_DCORSEL_1,CS_DCOFSEL_3);

  CS_clockSignalInit(CS_BASE,CS_ACLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_1);
  CS_clockSignalInit(CS_BASE,CS_MCLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_1);


  //Set P2.0 as Output Low (for setup as ACLK).
  /*
   
   * Select Port 2
   * Set Pin 0 to output Low.
   */
  GPIO_setOutputLowOnPin(
			GPIO_PORT_P2,
			GPIO_PIN0
	);

  //Set P2.0 as Ternary Module Function Output.
  /*
   
   * Select Port 2
   * Set Pin 0 to output Ternary Module Function, (ACLK).
   */
  GPIO_setAsPeripheralModuleFunctionOutputPin(
			GPIO_PORT_P2,
			GPIO_PIN0,
			GPIO_TERNARY_MODULE_FUNCTION
	);
    clockValue = CS_getSMCLK(CS_BASE);
    clockValue = CS_getMCLK(CS_BASE);
    clockValue = CS_getACLK(CS_BASE);



  while(1);

}


