//******************************************************************************
//!  EUSCI_A0 External Loopback test
//!
//!  Description: This demo connects TX to RX of the MSP430 UART
//!  The example code shows proper initialization of registers
//!  and interrupts to receive and transmit data.
//!
//!  SMCLK = DCO/8 = ~1MHz
//!
//!
//!   		Tested on MSP430FR5739
//!             -----------------
//!       RST -|     P2.0/UCA0TXD|----|
//!            |                 |    |
//!            |                 |    |
//!            |     P2.1/UCA0RXD|----|
//!            |                 |
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - UART peripheral
//! - GPIO Port peripheral (for UART pins)
//! - UCA0TXD
//! - UCA0RXD
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - USCI_A0_VECTOR.
//******************************************************************************
#include "inc/hw_memmap.h"
#include "eusci_uart.h"
#include "wdt_a.h"
#include "cs.h"
#include "gpio.h"

unsigned int i;
unsigned char RXData = 0, TXData = 0;
unsigned char check = 0;

void main(void)
{
    // stop watchdog
	WDT_A_hold(WDT_A_BASE);





	//Set DCO frequency to 8 MHz
	CS_setDCOFreq(CS_BASE,CS_DCORSEL_0,CS_DCOFSEL_3);
		//Set SMCLK = DCO with frequency divider of 8
	CS_clockSignalInit(CS_BASE,CS_SMCLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_8);

    // Configure UART pins
	//Set P2.0 and P2.1 as Secondary Module Function Input.
	/*
	
	* Select Port 2
	* Set Pin 0, 1 to input Secondary Module Function, (UCA0TXD/UCA0SIMO, UCA0RXD/UCA0SOMI).
	*/
	GPIO_setAsPeripheralModuleFunctionInputPin(
		GPIO_PORT_P2,
		GPIO_PIN0 + GPIO_PIN1,
		GPIO_SECONDARY_MODULE_FUNCTION
	);

  // Configure UART
  if ( STATUS_FAIL == EUSCI_UART_init(EUSCI_A0_BASE,
              EUSCI_UART_CLOCKSOURCE_SMCLK,
              CS_getSMCLK(CS_BASE),
              115200,
              EUSCI_UART_NO_PARITY,
              EUSCI_UART_LSB_FIRST,
              EUSCI_UART_ONE_STOP_BIT,
              EUSCI_UART_MODE,
              EUSCI_UART_LOW_FREQUENCY_BAUDRATE_GENERATION )){
         return;
     }

  EUSCI_UART_enable(EUSCI_A0_BASE);

  // Enable USCI_A0 RX interrupt
  EUSCI_UART_enableInterrupt(EUSCI_A0_BASE,
		  EUSCI_UART_RECEIVE_INTERRUPT);                     // Enable interrupt

  __enable_interrupt();
  while (1)
  {
    TXData = TXData+1;                      // Increment TX data
    // Load data onto buffer
    EUSCI_UART_transmitData(EUSCI_A0_BASE,
    				   TXData);
    while(check != 1);
    check = 0;
  }
}
//******************************************************************************
//
//This is the USCI_A0 interrupt vector service routine.
//
//******************************************************************************
#pragma vector=USCI_A0_VECTOR
__interrupt void USCI_A0_ISR(void)
{
  switch(__even_in_range(UCA0IV,USCI_UART_UCTXCPTIFG))
  {
    case USCI_NONE: break;
    case USCI_UART_UCRXIFG:
       RXData = EUSCI_UART_receiveData(EUSCI_A0_BASE);
      if(!(RXData == TXData))                   // Check value
      {
        while(1);
      }
      check =1;
      break;
    case USCI_UART_UCTXIFG: break;
    case USCI_UART_UCSTTIFG: break;
    case USCI_UART_UCTXCPTIFG: break;
  }
}
