//******************************************************************************
//!  MSP430FR57x Demo - MPU Write protection violation - PUC
//!
//!  Description: The MPU segment boundaries are defined by:
//!  Border 1 = 0xCA00 [segment #: 4]
//!  Border 2 = 0xD000 [segment #: 8]
//!  Segment 1 = 0xC200 - 0xC9FF
//!  Segment 2 = 0xCA00 - 0xCFFF
//!  Segment 3 = 0xD000 - 0xFFFF
//!  Segment 2 is write protected. Any write to an address in the segment 2 range
//!  causes a PUC. The LEDs toggles due to repeated PUCs. A delay is included
//!  so the debugger can gain access via JTAG.
//!
//!  ACLK = n/a, MCLK = SMCLK = TACLK = default DCO = ~625 KHz
//!
//!           MSP430FR5739
//!         ---------------
//!     /|\|               |
//!      | |               |
//!      --|RST            |
//!        |               |
//!		   |           P1.0|-->LED
//!        |           P3.5|-->LED
//!
//******************************************************************************

#include "inc/hw_memmap.h"
#include "mpu.h"
#include "wdt_a.h"
#include "gpio.h"

unsigned int *ptr = 0;
unsigned int Data =0;

void main(void)
{
  WDT_A_hold(WDT_A_BASE);                 // Stop WDT

	//Set P1.0 as an output pin.
    /*
     
     * Select Port 1
     * Set Pin 0 as output
     */
	GPIO_setAsOutputPin(
			GPIO_PORT_P1,
			GPIO_PIN0);
		
  //Set P3.5 as an output pin.
  /*
   
   * Select Port 3
   * Set Pin 5 as output
   */

	GPIO_setAsOutputPin(
			GPIO_PORT_P3,
			GPIO_PIN5
	);

  if(MPU_getInterruptStatus(MPU_BASE,MPUSEG2IFG))
  {
	//Toggle P1.0 output pin.
   /*
	
	* Select Port 1
	* Set Pin 0 as output
	 */

	GPIO_toggleOutputOnPin(
		GPIO_PORT_P1,
		GPIO_PIN0
	);
	
	//Toggle P3.5 output pin.
   /*
	
	* Select Port 3
	* Set Pin 5 as output
	 */

	GPIO_toggleOutputOnPin(
		GPIO_PORT_P3,
		GPIO_PIN5
	);


  }

  __delay_cycles(30000);                    // Delay to see toggle

  MPU_enablePUCOnViolation(MPU_BASE,MPU_SECOND_SEG);
  MPU_createThreeSegments(MPU_BASE,0x06,0x08,
		  	  	  	  	  MPU_READ|MPU_WRITE|MPU_EXEC,
                          MPU_READ,
                          MPU_READ|MPU_WRITE|MPU_EXEC);
  MPU_start(MPU_BASE);

  Data = 0x88;
  
  // Cause an MPU violation by writing to segment 2
  ptr = (unsigned int  *)0xCC02;
  *ptr = Data;   
  
 
  while(1);                                 // Code never gets here

}


