//******************************************************************************
//!
//! MPY - Saturation Mpode Underflow Test
//!
//!  Description: The example illustrates a special case showing underflow.
//!  Underflow occurs when adding 2 negative numbers yields a positive result.
//!  By having the saturation mode enabled, the result if rounded off to the
//!  highest negative number (0x8000.0000 for 16 bit). Results can be viewed
//!  in the debugger window.
//!
//!  ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//!
//!  Tested On: MSP430F5438A,MSP430FR5739,MSP430FR5969
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |                 |
//!            |                 |
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - MPY peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - NONE
//!
//******************************************************************************
#include "inc/hw_memmap.h"
#include "mpy32.h"
#include "wdt_a.h"
#include "gpio.h"

unsigned long Result;
unsigned int Result_lower16;
unsigned int Result_upper16;

void main (void)
{
    //Stop Watchdog Timer
    WDT_A_hold(WDT_A_BASE);

//------Pre-Multiply to setup RES0 and RES1 ------------------------

    MPY32_setOperandOne16Bit(MPY32_BASE,
        MPY32_MULTIPLY_UNSIGNED,
        0x8000);
    MPY32_setOperandTwo8Bit(MPY32_BASE,
        0x1);

//------32-bit Result of a multiply operation in RES0 and RES1------
//RES1 == 0x0000
//RES0 == 0x8000

    MPY32CTL0 = MPYC; //Explicity Set MPY Carry Bit.
    //Enable Saturation Mode.
    MPY32_setSaturationMode(MPY32_BASE);

    //Set a 16-bit Operand into the specific Operand 1 register to specify
    //signed multiplication added to the current result
    MPY32_setOperandOne16Bit(MPY32_BASE,
        MPY32_MULTIPLYACCUMULATE_SIGNED,
        0x8000);
    //Set 16-bit Operand 2 to begin the multiplication operation
    MPY32_setOperandTwo16Bit(MPY32_BASE,
        0x0005);

    //Wait for the result to become ready
    __no_operation();
    __no_operation();
    __no_operation();
    __no_operation();
    __no_operation();

    //Read out Result
    Result = MPY32_getResult32Bit(MPY32_BASE);

    //Result_upper16 == 0x8000
    //Result_lower16 == 0x0000

    Result_upper16 = Result;
    Result_lower16 = (Result >> 16);

    //Disable Saturation Mode
    MPY32_resetSaturationMode(MPY32_BASE);

    //Enter LPM4
    __bis_SR_register(LPM4_bits);
    __no_operation();
}

