//******************************************************************************
//  Timer_B, Toggle P1.0, Overflow ISR, 32kHz ACLK
//
//  Description: Toggle P1.0 using software and the Timer_B overflow ISR.
//  In this example an ISR triggers when TB overflows. Inside the ISR P1.0
//  is toggled. Toggle rate is exactly 0.25Hz = [32kHz/FFFFh]/2. Proper use of the
//  TBIV interrupt vector generator is demonstrated.
//  ACLK = TBCLK = 32kHz, MCLK = SMCLK = default DCO ~ 1.045MHz
//
//  Tested On: MSP430FR5739
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |           P1.0|-->LED
//******************************************************************************

#include "inc/hw_memmap.h"
#include "timer_b.h"
#include "wdt_a.h"
#include "gpio.h"

void main(void)
{
	//Stop WDT
	WDT_A_hold(WDT_A_BASE);

	//Set P1.0 to output direction
	GPIO_setAsOutputPin(
	        GPIO_PORT_P1,
	        GPIO_PIN0
	        );

	TIMER_B_configureContinuousMode( TIMER_B0_BASE,
	        TIMER_B_CLOCKSOURCE_ACLK,
	        TIMER_B_CLOCKSOURCE_DIVIDER_1,
	        TIMER_B_TBIE_INTERRUPT_ENABLE,
	        TIMER_B_DO_CLEAR
	        );

  __bis_SR_register(LPM3_bits + GIE);       // Enter LPM3, enable interrupts
  __no_operation();                         // For debugger
}

// Timer_B7 Interrupt Vector (TBIV) handler
#pragma vector=TIMERB1_VECTOR
__interrupt void TIMERB1_ISR(void)
{
  /* Any access, read or write, of the TBIV register automatically resets the
  highest "pending" interrupt flag. */
  switch( __even_in_range(TBIV,14) )
  {
    case  0: break;                          // No interrupt
    case  2: break;                          // CCR1 not used
    case  4: break;                          // CCR2 not used
    case  6: break;                          // CCR3 not used
    case  8: break;                          // CCR4 not used
    case 10: break;                          // CCR5 not used
    case 12: break;                          // CCR6 not used
    case 14: 					             // overflow
    //Toggle P1.0
        GPIO_toggleOutputOnPin(
            GPIO_PORT_P1,
            GPIO_PIN0
            );

            break;
    default: break;
  }
}
