//******************************************************************************
//   Timer_B, PWM TB1-6, Up Mode, DCO SMCLK
//
//   Description: This program generates two PWM outputs on P1.4/P1.5 using
//   Timer_B configured for up mode. The value in CCR0, 512-1, defines the PWM
//   period and the values in CCR1-2 the PWM duty cycles. Using ~1048kHz SMCLK
//   as TBCLK, the timer period is ~488us.
//   ACLK = 32kHz, SMCLK = MCLK = TBCLK = default DCO ~1048kHz.
//
//   Tested On: MSP430FR5739
//             -----------------
//         /|\|              XIN|-
//          | |                 |  32kHz
//          --|RST          XOUT|-
//            |                 |
//            |       P1.4/TB0.1|--> CCR1 - 75% PWM
//            |       P1.5/TB0.2|--> CCR2 - 25% PWM
//            |        			|
//            |         		|
//            |      			|
//            |        			|
//
//******************************************************************************

#include "inc/hw_memmap.h"
#include "timer_b.h"
#include "wdt_a.h"
#include "gpio.h"

void main(void)
{
	//Stop WDT
    WDT_A_hold(WDT_A_BASE);

    GPIO_setAsPeripheralModuleFunctionOutputPin(
		GPIO_PORT_P1,
		GPIO_PIN4 | GPIO_PIN5,
		GPIO_PRIMARY_MODULE_FUNCTION
		);

    //Start timer
	TIMER_B_configureUpMode(TIMER_B0_BASE,
		TIMER_B_CLOCKSOURCE_SMCLK,
		TIMER_B_CLOCKSOURCE_DIVIDER_1,
		511,
		TIMER_B_TBIE_INTERRUPT_DISABLE,
		TIMER_B_CCIE_CCR0_INTERRUPT_DISABLE,
		TIMER_B_DO_CLEAR
		);

	TIMER_B_startCounter(TIMER_B0_BASE,
		TIMER_B_UP_MODE
		);

	//Initialize compare mode to generate PWM1
	TIMER_B_initCompare(TIMER_B0_BASE,
		TIMER_B_CAPTURECOMPARE_REGISTER_1,
		TIMER_B_CAPTURECOMPARE_INTERRUPT_DISABLE,
		TIMER_B_OUTPUTMODE_RESET_SET,
		383
		);

	//Initialize compare mode to generate PWM2
	TIMER_B_initCompare(TIMER_B0_BASE,
		TIMER_B_CAPTURECOMPARE_REGISTER_2,
		TIMER_B_CAPTURECOMPARE_INTERRUPT_ENABLE,
		TIMER_B_OUTPUTMODE_RESET_SET,
		128
		);

	_BIS_SR(LPM0_bits + GIE);                 // CPU off
}
