//******************************************************************************
//   MSP430FR59xx Demo - Configure MCLK for 24MHz operation
//
//   Description: Configure SMCLK = MCLK = 24MHz
//   IMPORTANT NOTE: While the FRxxx is capable of operation w/ MCLK = 24MHz
//   the throughput of the device is dependent on accesses to FRAM.
//   The maximum speed for accessing FRAM is limited to 8MHz*.
//   Wait states are inserted automatically when the FRAM is accessed at
//   speeds higher than 8MHz to prevent timing violations.
//   Refer to the FRCTL chapter of the User's Guide.
//   * Refer device D/s for typical numbers
//
//           MSP430FR5969
//         ---------------
//     /|\|               |
//      | |               |
//      --|RST            |
//        |               |
//        |               |
//        |          P3.4 |---> SMCLK = MCLK = 24MHz
//
//******************************************************************************

#include "inc/hw_memmap.h"
#include "cs.h"
#include "wdt_a.h"
#include "gpio.h"

unsigned long clockValue;
	
void main(void)
{

	
  //Stop WDT
  WDT_A_hold(WDT_A_BASE);
  CS_setDCOFreq(CS_BASE,CS_DCORSEL_1,CS_DCOFSEL_6);

  CS_clockSignalInit(CS_BASE,CS_SMCLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_1);
  CS_clockSignalInit(CS_BASE,CS_MCLK,CS_DCOCLK_SELECT,CS_CLOCK_DIVIDER_1);


  //Set P2.0 as Output Low (for setup as ACLK).
  /*
   
   * Select Port 2
   * Set Pin 0 to output Low.
   */
  GPIO_setOutputLowOnPin(
			GPIO_PORT_P3,
			GPIO_PIN4
	);

  //Set P2.0 as Ternary Module Function Output.
  /*
   
   * Select Port 2
   * Set Pin 0 to output Ternary Module Function, (ACLK).
   */
  GPIO_setAsPeripheralModuleFunctionOutputPin(
			GPIO_PORT_P3,
			GPIO_PIN4,
			GPIO_TERNARY_MODULE_FUNCTION
	);

  while(1);

}


