#include "inc/hw_memmap.h"
#include "eusci_i2c.h"
#include "wdt_a.h"
#include "gpio.h"

//******************************************************************************
//  MSP430FR57xx Demo - USCI_B0 I2C 4 Hardware I2C slaves
//
//  Description: This demo connects two MSP430's via the I2C bus. 
//  This code configures the MSP430 USCI to be addressed as 4 independent I2C
//  slaves. Each slave has its owm interrupt flag and data variable to store
//  incoming data. 
//
//	 Tested on MSP430FR5739, MSP430FR5969
//                                /|\  /|\
//                                10k  10k                 
//                   slave         |    |         master
//             -----------------   |    |   -----------------
//           -|XIN  P1.6/UCB0SDA|<-|----+->|P1.6/UCB0SDA  XIN|-
//            |                 |  |       |                 |
//           -|XOUT             |  |       |             XOUT|-
//            |     P1.7/UCB0SCL|<-+------>|P1.7/UCB0SCL     |
//            |                 |          |                 |
//            |                 |          |                 |
//
//******************************************************************************
unsigned char RXData0=0;  
unsigned char RXData1=0;
unsigned char RXData2=0;
unsigned char RXData3=0;

void main(void)

{
	
	WDT_A_hold(WDT_A_BASE);

    // Configure Pins for I2C
	//Set P1.6 and P1.7 as Secondary Module Function Input.
	/*
	
	* Select Port 1
	* Set Pin 6, 7 to input Secondary Module Function, (UCB0SIMO/UCB0SDA, UCB0SOMI/UCB0SCL).
	*/
	GPIO_setAsPeripheralModuleFunctionInputPin(
		GPIO_PORT_P1,
		GPIO_PIN6 + GPIO_PIN7,
		GPIO_SECONDARY_MODULE_FUNCTION
	);
	
    // eUSCI configuration
    //SLAVE0 own address is 0x0A+ enable
    EUSCI_I2C_slaveInit(EUSCI_B0_BASE,
    					0x0A,
                		EUSCI_I2C_OWN_ADDRESS_OFFSET0,
                		EUSCI_I2C_OWN_ADDRESS_ENABLE
                		);
    //SLAVE1 own address is 0x0B+ enable
    EUSCI_I2C_slaveInit(EUSCI_B0_BASE,
        					0x0B,
                    		EUSCI_I2C_OWN_ADDRESS_OFFSET1,
                    		EUSCI_I2C_OWN_ADDRESS_ENABLE
                    		);
    //SLAVE2 own address is 0x0C+ enable
    EUSCI_I2C_slaveInit(EUSCI_B0_BASE,
        					0x0C,
                    		EUSCI_I2C_OWN_ADDRESS_OFFSET2,
                    		EUSCI_I2C_OWN_ADDRESS_ENABLE
                    		);
    //SLAVE3 own address is 0x0D+ enable
    EUSCI_I2C_slaveInit(EUSCI_B0_BASE,
        					0x0D,
                    		EUSCI_I2C_OWN_ADDRESS_OFFSET3,
                    		EUSCI_I2C_OWN_ADDRESS_ENABLE
                    		);

    EUSCI_I2C_enable(EUSCI_B0_BASE);

    //receive interrupt enable
    EUSCI_I2C_enableInterrupt(EUSCI_B0_BASE,
    				EUSCI_I2C_RECEIVE_INTERRUPT0 +
    				EUSCI_I2C_RECEIVE_INTERRUPT1 +
    				EUSCI_I2C_RECEIVE_INTERRUPT2 +
    				EUSCI_I2C_RECEIVE_INTERRUPT3
    				);


	
    __bis_SR_register(CPUOFF + GIE);        // Enter LPM0 w/ interrupts
    __no_operation();	 
}


#pragma vector = USCI_B0_VECTOR 
__interrupt void USCIB0_ISR(void)

{

   switch(__even_in_range(UCB0IV,0x1E))
    {
      case 0x00: break;                     // Vector 0: No interrupts break;
      case 0x02: break;                     // Vector 2: ALIFG break;
      case 0x04: break;                     // Vector 4: NACKIFG break;
      case 0x06: break;                     // Vector 6: STTIFG break;
      case 0x08: break;                     // Vector 8: STPIFG break;
      case 0x0a:                            // SLAVE3
        RXData3 = EUSCI_I2C_slaveDataGet(EUSCI_B0_BASE);
        break;                              // Vector 10: RXIFG3 break;
      case 0x0c: break;                     // Vector 14: TXIFG3 break;
      case 0x0e:                            // SLAVE2
        RXData2 = EUSCI_I2C_slaveDataGet(EUSCI_B0_BASE);
        break;                              // Vector 16: RXIFG2 break;
      case 0x10: break;                     // Vector 18: TXIFG2 break;
      case 0x12:                            // SLAVE1
        RXData1 = EUSCI_I2C_slaveDataGet(EUSCI_B0_BASE);
        break;                              // Vector 20: RXIFG1 break;
      case 0x14: break;                     // Vector 22: TXIFG1 break;
      case 0x16:                            // SLAVE0
        RXData0 = EUSCI_I2C_slaveDataGet(EUSCI_B0_BASE);
        // Get RX data
        break;                              // Vector 24: RXIFG0 break;
      case 0x18: break;                     // Vector 26: TXIFG0 break;
      case 0x1a: break;                     // Vector 28: BCNTIFG break;
      case 0x1c: break;                     // Vector 30: clock low timeout break;
      case 0x1e: break;                     // Vector 32: 9th bit break;
      default: break;	
    }
	
}	


