//******************************************************************************
//!   Long word writes to FRAM
//!
//!   Description: Use long word write to write to 512 byte blocks of FRAM.
//!   Toggle LEDs after every 100 writes.
//!   NOTE: Running this example for extended periods will impact the FRAM
//!   endurance.
//!   ACLK = VLO, MCLK = SMCLK = 4MHz
//!
//!   Tested On: MSP430FR5739,MSP430FR5969
//!         ---------------
//!     /|\|               |
//!      | |               |
//!      --|RST            |
//!        |               |
//!        |               |
//!        |           P1.0|---> LED
//!		   |           P3.5|-->LED
//!
//******************************************************************************
#include "inc/hw_memmap.h"
#include "fram.h"
#include "wdt_a.h"
#include "gpio.h"

#define FRAM_TEST_START 0xCABA

void main(void) {
	unsigned char count = 0;
	unsigned long data = 0;

	WDT_A_hold(WDT_A_BASE);                 // Stop WDT

	//Set P1.0 as an output pin.
	/*
	 
	 * Select Port 1
	 * Set Pin 0 as output
	 */
	GPIO_setAsOutputPin(GPIO_PORT_P1, GPIO_PIN0);
	//Set P3.5 as an output pin.
	/*
	 
	 * Select Port 3
	 * Set Pin 5 as output
	 */
	GPIO_setAsOutputPin(GPIO_PORT_P3, GPIO_PIN5);

	// Initialize dummy data
	data = 0x11111111;

	while (1) {
		data += 0x00010001;

		FRAM_memoryFill32(FRAM_BASE, data, (unsigned long *) FRAM_TEST_START,
				128);
		count++;
		if (count > 100) {
			//Toggle P1.0 output pin.
			/*
			 
			 * Select Port 1
			 * Set Pin 0 as output
			 */
			GPIO_toggleOutputOnPin(GPIO_PORT_P1, GPIO_PIN0);
			//Toggle P3.5 output pin.
			/*
			 
			 * Select Port 3
			 * Set Pin 5 as output
			 */
			GPIO_toggleOutputOnPin(GPIO_PORT_P3, GPIO_PIN5);

			count = 0;                            //Reset counter
			data = 0x11111111;
		}
	}
}
