//******************************************************************************
//!
//! MPY - 32x32 Signed Multiply Accumalate
//!
//!  Hardware multiplier is used to multiply-accumalate a set of numbers. The
//!  first calculation is automatically initiated after the second operand is
//!  loaded. A second multiply-accumulate operation is performed next. Results
//!  are stored in RES0, RES1, RES2 and RES3.
//!  SUMEXT contains the extended sign of the result.
//!
//!   ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//!
//!  Tested On: MSP430F5438A,MSP430FR5739,MSP430FR5969
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |                 |
//!            |                 |
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - MPY peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - NONE
//!
//******************************************************************************

#include "inc/hw_memmap.h"
#include "mpy32.h"
#include "wdt_a.h"
#include "gpio.h"

void main (void)
{
    //Stop Watchdog Timer
    WDT_A_hold(WDT_A_BASE);

    //Set a 32-bit Operand into the specific Operand 1 register to specify
    //unsigned multiplication
    MPY32_setOperandOne32Bit(MPY32_BASE,
        MPY32_MULTIPLY_UNSIGNED,
        0x12341234);
    //Set 32-bit Operand 2 to begin the multiplication operation
    MPY32_setOperandTwo32Bit(MPY32_BASE,
        0x56785678);

    //Wait for the result to become ready
    __no_operation();
    __no_operation();
    __no_operation();
    __no_operation();
    __no_operation();

    //Set a 32-bit Operand into the specific Operand 1 register to specify
    //signed multiplication added to the current result
    MPY32_setOperandOne32Bit(MPY32_BASE,
        MPY32_MULTIPLYACCUMULATE_SIGNED,
        0x12341234);
    //Set 32-bit Operand 2 to begin the multiplication operation
    MPY32_setOperandTwo32Bit(MPY32_BASE,
        0x56785678);

    //Enter LPM4
    __bis_SR_register(LPM4_bits);

    //BREAKPOINT HERE to verify the correct Result in Registers.
    __no_operation();
}

