//******************************************************************************
//!
//! MPY - 16x16 Unsigned Multiply Accumulate
//!
//!  Hardware multiplier is used to multiply two numbers. The calculation is
//!  automatically initiated after the second operand is loaded. A second
//!  multiply accumulate operation is performed after that. Results are stored
//!  in RESLO and RESHI. SUMEXT contains the carry of the result.
//!
//!  ACLK = 32.768kHz, MCLK = SMCLK = default DCO
//!
//!  Tested On: MSP430F5438A,MSP430FR5739,MSP430FR5969
//!             -----------------
//!         /|\|                 |
//!          | |                 |
//!          --|RST              |
//!            |                 |
//!            |                 |
//!
//!
//! This example uses the following peripherals and I/O signals.  You must
//! review these and change as needed for your own board:
//! - MPY peripheral
//!
//! This example uses the following interrupt handlers.  To use this example
//! in your own application you must add these interrupt handlers to your
//! vector table.
//! - NONE
//!
//******************************************************************************

#include "inc/hw_memmap.h"
#include "mpy32.h"
#include "wdt_a.h"
#include "gpio.h"

void main (void)
{
    //Stop Watchdog Timer
    WDT_A_hold(WDT_A_BASE);

    //Set a 16-bit Operand into the specific Operand 1 register to specify
    //unsigned multiplication
    MPY32_setOperandOne16Bit(MPY32_BASE,
        MPY32_MULTIPLY_UNSIGNED,
        0x1234);
    //Set 16-bit Operand 2 to begin the multiplication operation
    MPY32_setOperandTwo16Bit(MPY32_BASE,
        0x5678);

    //Set a 16-bit Operand into the specific Operand 1 register to specify
    //unsigned multiplication added to the current result
    MPY32_setOperandOne16Bit(MPY32_BASE,
        MPY32_MULTIPLYACCUMULATE_UNSIGNED,
        0x1234);
    //Set 16-bit Operand 2 to begin the multiplication operation
    MPY32_setOperandTwo16Bit(MPY32_BASE,
        0x5678);

    //Enter LPM4
    __bis_SR_register(LPM4_bits);

    //BREAKPOINT HERE to verify the correct Result in Registers
    __no_operation();
}

