//******************************************************************************
//  MSP430F20x2/3 Demo - SPI full-Duplex 3-wire Slave
//
//  Description: SPI Master communicates full-duplex with SPI Slave using
//  3-wire mode. The level on P1.4 is TX'ed and RX'ed to P1.0.
//  Master will pulse slave reset for synch start.
//  ACLK = n/a, MCLK = SMCLK = Default DCO
//
//                Slave                      Master
//               MSP430F20x2/3              MSP430F20x2/3
//             -----------------          -----------------
//            |              XIN|-    /|\|              XIN|-
//            |                 |      | |                 |
//            |             XOUT|-     --|RST          XOUT|-
//            |                 | /|\    |                 |
//            |          RST/NMI|--+<----|P1.2             |
//      LED <-|P1.0             |        |             P1.4|<-
//          ->|P1.4             |        |             P1.0|-> LED
//            |         SDI/P1.7|<-------|P1.6/SDO         |
//            |         SDO/P1.6|------->|P1.7/SDI         |
//            |        SCLK/P1.5|<-------|P1.5/SCLK        |
//
/*
 * ======== Standard MSP430 includes ========
 */
#include <msp430.h>

/*
 * ======== Grace related declaration ========
 */
extern void CSL_init(void);


/*
 *  ======== main ========
 */
int main(void)
{
    CSL_init();
    USICTL0 &= ~USISWRST;                 // USI released for operation
    USISRL = P1IN;                        // init-load data
    USICNT = 8;                           // init-load counter

      __bis_SR_register(LPM0_bits + GIE);             // Enter LPM0 w/ interrupt

}
void universal_serial_interface(void)
{
	if (0x10 & USISRL)
	    P1OUT |= 0x01;
	else
	    P1OUT &= ~0x01;
	USISRL = P1IN;
	USICNT = 8;                           // re-load counter
}
