//******************************************************************************
//  MSP430G2xx3 Demo - P1 Interrupt from LPM4 with Internal Pull-up
//
//  Description: A hi/low transition on P1.3 will trigger P1_ISR which,
//  toggles P1.0. Normal mode is LPM4 ~ 0.1uA.
//  Internal pullup enabled on P1.3.
//  ACLK = n/a, MCLK = SMCLK = default DCO
//
//               MSP430G2xx3
//            -----------------
//        /|\|              XIN|-
//         | |                 |
//         --|RST          XOUT|-
//     /|\   |      R          |
//      --o--| P1.3-o      P1.0|-->LED
//     \|/
//******************************************************************************
/*
 * ======== Standard MSP430 includes ========
 */
#include <msp430.h>

/*
 * ======== Grace related declaration ========
 */
extern void CSL_init(void);

/*
 *  ======== main ========
 */
int main(void)
{
    CSL_init();

    __bis_SR_register(LPM4_bits + GIE);     // Enter LPM4 w/interrupt
}

void Port_1(void)
{
    P1OUT ^= 0x01;                          // P1.0 = toggle
    P1IFG &= ~0x08;                         // P1.3 IFG cleared
}
