//*****************************************************************************
//
// Hitachi138x110_HD66753.h - Prototypes for the Hitachi138x110 LCD
//                                     display driver with a HD66753
//                                     controller.
//
// Copyright (c) 2008-2011 Texas Instruments Incorporated.  All rights reserved.
// Software License Agreement
// 
// Texas Instruments (TI) is supplying this software for use solely and
// exclusively on TI's microcontroller products. The software is owned by
// TI and/or its suppliers, and is protected under applicable copyright
// laws. You may not combine this software with "viral" open-source
// software in order to form a larger program.
// 
// THIS SOFTWARE IS PROVIDED "AS IS" AND WITH ALL FAULTS.
// NO WARRANTIES, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT
// NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. TI SHALL NOT, UNDER ANY
// CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
// DAMAGES, FOR ANY REASON WHATSOEVER.
// 
//
//*****************************************************************************

#ifndef __Hitachi138x110_HD66753_H__
#define __Hitachi138x110_HD66753_H__

//*****************************************************************************
//
// Include Files
//
//*****************************************************************************


//*****************************************************************************
//
// User Configuration for the LCD Driver
//
//*****************************************************************************

// Define LCD Screen Orientation Here
#define LANDSCAPE
//#define LANDSCAPE_FLIP

//*****************************************************************************
//
// Defines for the pins that are used to communicate with the HD66753
//
//*****************************************************************************
#ifndef MIN
#    define MIN(n, m)   (((n) < (m)) ? (n) : (m))
#endif

#ifndef MAX
#    define MAX(n, m)   (((n) < (m)) ? (m) : (n))
#endif

#ifndef ABS
#    define ABS(n)     (((n) < 0) ? -(n) : (n))
#endif

// Pins from MSP430 connected to LCD
#define LCD_BACKLT_OUT      P8OUT
#define LCD_BACKLT_DIR      P8DIR
#define LCD_BACKLT_SEL      P8SEL
#define LCD_BACKLIGHT_PIN   BIT3
#define LCD_CS_RST_DIR      P9DIR
#define LCD_CS_RST_OUT      P9OUT
#define LCD_CS_PIN          BIT6
#define LCD_RESET_PIN       BIT7
#define LCD_SPI_SEL                     P9SEL
#define LCD_SPI_DIR                     P9DIR
#define LCD_MOSI_PIN            BIT1
#define LCD_MISO_PIN            BIT2
#define LCD_CLK_PIN             BIT3

/*
#define LCD_ROW                 110
#define LCD_COL                 138
#define LCD_Size                3505
#define LCD_MEM_Size            110 * 17
#define LCD_Max_Column_Offset   0x10

#define LCD_Last_Pixel          3505

#define LCD_MEM_Row             0x11
#define LCD_Row                 0x20
*/

// Grayscale level definitions
#define PIXEL_OFF               3
#define PIXEL_LIGHT             2
#define PIXEL_DARK              1
#define PIXEL_ON                0

#define INVERT_TEXT             BIT0
#define OVERWRITE_TEXT          BIT2
#define GRAYSCALE_TEXT          BIT1

//*****************************************************************************
//
// This driver operates in two different screen orientations.  They are:
//
// * Landscape - The screen is wider than it is tall, and there are more pins and the
//               white band on the top of the display. This is selected by defining
//               LANDSCAPE in the User Configuration section above.
//
// * Landscape flip - The screen is wider than it is tall, and there are more pins
//               and the white band on the bottom of the display. This is selected by
//               defining LANDSCAPE_FLIP in the User Configuration section above.
//
// These can also be imagined in terms of screen rotation; if landscape mode is 0 degrees
// of rotation, landscape flip is 180 degrees of rotation
//
// If no screen orientation is selected, "landscape" mode will be used.
//
//*****************************************************************************
#if ! defined(LANDSCAPE) && ! defined(LANDSCAPE_FLIP)
#define LANDSCAPE
#endif

//*****************************************************************************
//
// Various HD66753 command name labels and associated control bits
//
//*****************************************************************************


//*****************************************************************************
//
// Macros for the Display Driver
//
//*****************************************************************************

//
// Translates a 24-bit RGB color to a display driver-specific color.
//
// \param c is the 24-bit RGB color.  The least-significant byte is the blue
// channel, the next byte is the green channel, and the third byte is the red
// channel.
//
// This macro translates a 24-bit RGB color into a value that can be written
// into the display's frame buffer in order to reproduce that color, or the
// closest possible approximation of that color. This particular driver
// requires the 8-8-8 24 bit RGB color to convert into a 2BPP color.
// It works by adding together the MSB of the seperate red, green, and blue 
// components of the color. The max value corresponds to the red, green, and
// blue components each having a value 0x80 or greater. This would
// translate to a '1' for each MSB and give 1+1+1 = 3 (White Pixel).
// The minimum value is 0+0+0 = 0 (Black). Each gray value in between is
// possible with 2 = lighy gray and 1 = dark gray. 
//
// \return Returns the display-driver specific color

#define DPYCOLORTRANSLATE(c)   ((((c) & 0x00ff0000) >> 23) +              \
                                (((c) & 0x0000ff00) >> 15)  +             \
                                (((c) & 0x000000ff) >> 7))

//*****************************************************************************
//
// Prototypes for the globals exported by this driver.
//
//*****************************************************************************
extern void Hitachi138x110_HD66753Init(void);
extern void Hitachi138x110_setBacklight(unsigned char brightness);
extern void Hitachi138x110_setContrast(unsigned char newContrast);
extern void Hitachi138x110_backlightInit(void);
extern void Hitachi138x110_backlightOff(void);
extern void Hitachi138x110_disable(void);
extern void Hitachi138x110_InvertDisplay(void);

extern const tDisplay g_sHitachi138x110_HD66753;
extern unsigned int Hitachi138x110Memory[];
extern unsigned char ucBacklightLevel;
extern unsigned char ucContrast;


#endif // __Hitachi138x110_HD66753_H__
