#include <msp430fr5969.h>

#include "grlib.h"
#include "sharp96x96.h"
#include "images/images.h"
#include "driverlib/5xx_6xx/cs_a.h"
#include "driverlib/5xx_6xx/timera.h"
#include "driverlib/5xx_6xx/frgpio.h"
#include "driverlib/5xx_6xx/wdt.h"

void clockInit(void);
void boardInit();
void timerInit();

void main(void)
{
  volatile unsigned int i, j;
  tContext sContext;
  tRectangle myRectangle1 = { 5, 20, 25, 35};
  tRectangle myRectangle2 = { 30, 20, 50, 35};

  // Stop WDT
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);

  clockInit();
  timerInit();

  //
  // Initialize the display driver
  //
  Sharp96x96_LCDInit();
 
  //
  // Initialize the graphics context
  //
  GrContextInit(&sContext, &g_sharp96x96LCD);
  GrContextForegroundSet(&sContext, ClrBlack);
  GrContextBackgroundSet(&sContext, ClrWhite);

  GrClearDisplay(&sContext);

  GrContextFontSet(&sContext, &g_sFontFixed6x8);
  GrStringDraw(&sContext, "Welcome to ", -1, 0, 8, 0);

  GrContextFontSet(&sContext, &g_sFontCm12);
  GrStringDraw(&sContext, "Dallas TX", -1, 0, 70, 0);

  GrLineDrawH(&sContext, 0, 60, 85);

  GrPixelDraw(&sContext, 80, 30);
  GrPixelDraw(&sContext, 80, 34);
  GrPixelDraw(&sContext, 80, 38);
  GrPixelDraw(&sContext, 80, 42);
  GrPixelDraw(&sContext, 80, 46);
  GrPixelDraw(&sContext, 80, 50);

  GrRectFill(&sContext, &myRectangle1);
  GrRectDraw(&sContext, &myRectangle2);

  GrCircleFill(&sContext, 15, 55, 10);
  GrCircleDraw(&sContext, 45, 55, 10);

  GrFlush(&sContext);
  __no_operation();


  //Deleting some of the previously drawn operations
  GrContextForegroundSet(&sContext, ClrWhite);
  GrContextBackgroundSet(&sContext, ClrBlack);
  GrLineDrawH(&sContext, 0, 60, 85);

  GrContextFontSet(&sContext, &g_sFontCm12);
  GrStringDraw(&sContext, "Dallas", -1, 0, 70, 0);

  GrFlush(&sContext);
  __no_operation();

  GrClearDisplay(&sContext);
  GrImageDraw(&sContext, &Pig1BPP_COMP_RLE4, 0, 0);

  GrFlush(&sContext);
  __no_operation();
   while(1)
  {  
	   __bis_SR_register(LPM0_bits + GIE);     // LPM0 w/ interrupts
	   __no_operation();                       // For debugger
  } 

}

void clockInit(void)
{
    CSA_setDCOFreq(__MSP430_BASEADDRESS_CS_A__,CSA_DCORSEL_1,CSA_DCOFSEL_3);

    CSA_clockSignalInit(
    		__MSP430_BASEADDRESS_CS_A__,
                CSA_ACLK,
                CSA_VLOCLK_SELECT,
                CSA_CLOCK_DIVIDER_1
                );

    CSA_clockSignalInit(
    		__MSP430_BASEADDRESS_CS_A__,
                CSA_SMCLK,
                CSA_DCOCLK_SELECT,
                CSA_CLOCK_DIVIDER_1
                );

    CSA_clockSignalInit(
    		__MSP430_BASEADDRESS_CS_A__,
                CSA_MCLK,
                CSA_DCOCLK_SELECT,
                CSA_CLOCK_DIVIDER_1
                );

}

void boardInit()
{
    FRGPIO_setAsOutputPin(
            __MSP430_BASEADDRESS_PORTA_R__,
            FRGPIO_PORT_PA,
            FRGPIO_PIN0 + FRGPIO_PIN1 + FRGPIO_PIN2 + FRGPIO_PIN3 + FRGPIO_PIN4
                    + FRGPIO_PIN5 + FRGPIO_PIN6 + FRGPIO_PIN7 + FRGPIO_PIN8
                    + FRGPIO_PIN9 + FRGPIO_PIN10 + FRGPIO_PIN11 + FRGPIO_PIN12
                    + FRGPIO_PIN13 + FRGPIO_PIN14 + FRGPIO_PIN15);

    FRGPIO_setAsOutputPin(
            __MSP430_BASEADDRESS_PORTB_R__,
            FRGPIO_PORT_P2,
            FRGPIO_PIN0 + FRGPIO_PIN1 + FRGPIO_PIN2 + FRGPIO_PIN3 + FRGPIO_PIN4
                    + FRGPIO_PIN5 + FRGPIO_PIN6 + FRGPIO_PIN7 + FRGPIO_PIN8
                    + FRGPIO_PIN9 + FRGPIO_PIN10 + FRGPIO_PIN11 + FRGPIO_PIN12
                    + FRGPIO_PIN13 + FRGPIO_PIN14 + FRGPIO_PIN15);

    FRGPIO_setOutputLowOnPin(
            __MSP430_BASEADDRESS_PORTA_R__,
            FRGPIO_PORT_P9,
            FRGPIO_PIN0 + FRGPIO_PIN1 + FRGPIO_PIN2 + FRGPIO_PIN3 + FRGPIO_PIN4
                    + FRGPIO_PIN5 + FRGPIO_PIN6 + FRGPIO_PIN7 + FRGPIO_PIN8
                    + FRGPIO_PIN9 + FRGPIO_PIN10 + FRGPIO_PIN11 + FRGPIO_PIN12
                    + FRGPIO_PIN13 + FRGPIO_PIN14 + FRGPIO_PIN15);

    FRGPIO_setOutputLowOnPin(
            __MSP430_BASEADDRESS_PORTB_R__,
            FRGPIO_PORT_P9,
            FRGPIO_PIN0 + FRGPIO_PIN1 + FRGPIO_PIN2 + FRGPIO_PIN3 + FRGPIO_PIN4
                    + FRGPIO_PIN5 + FRGPIO_PIN6 + FRGPIO_PIN7 + FRGPIO_PIN8
                    + FRGPIO_PIN9 + FRGPIO_PIN10 + FRGPIO_PIN11 + FRGPIO_PIN12
                    + FRGPIO_PIN13 + FRGPIO_PIN14 + FRGPIO_PIN15);

    FRGPIO_setAsOutputPin(
            __MSP430_BASEADDRESS_PORTJ_R__,
            FRGPIO_PORT_P2,
            FRGPIO_PIN0 + FRGPIO_PIN1 + FRGPIO_PIN2 + FRGPIO_PIN3 + FRGPIO_PIN4
                    + FRGPIO_PIN5 + FRGPIO_PIN6 + FRGPIO_PIN7 + FRGPIO_PIN8
                    + FRGPIO_PIN9 + FRGPIO_PIN10 + FRGPIO_PIN11 + FRGPIO_PIN12
                    + FRGPIO_PIN13 + FRGPIO_PIN14 + FRGPIO_PIN15);

    FRGPIO_setOutputLowOnPin(
            __MSP430_BASEADDRESS_PORTJ_R__,
            FRGPIO_PORT_P9,
            FRGPIO_PIN0 + FRGPIO_PIN1 + FRGPIO_PIN2 + FRGPIO_PIN3 + FRGPIO_PIN4
                    + FRGPIO_PIN5 + FRGPIO_PIN6 + FRGPIO_PIN7 + FRGPIO_PIN8
                    + FRGPIO_PIN9 + FRGPIO_PIN10 + FRGPIO_PIN11 + FRGPIO_PIN12
                    + FRGPIO_PIN13 + FRGPIO_PIN14 + FRGPIO_PIN15);

}

void timerInit()
{
    TimerA_configureUpMode(__MSP430_BASEADDRESS_T1A3__,TIMERA_CLOCKSOURCE_SMCLK,
                        TIMERA_CLOCKSOURCE_DIVIDER_1,32000-1,
                        TIMERA_TAIE_INTERRUPT_DISABLE,
                        TIMERA_CCIE_CCR0_INTERRUPT_ENABLE, TIMERA_SKIP_CLEAR);
    TimerA_startCounter(__MSP430_BASEADDRESS_T1A3__,
    		TIMERA_UP_MODE
    					);
}

//------------------------------------------------------------------------------
// Timer A0 Interrupt Service Routine
//------------------------------------------------------------------------------
#pragma vector=TIMER1_A0_VECTOR
__interrupt void TIMER1_A0_ISR(void)
{
	Sharp96x96_SendToggleVCOMCommand();

	/* Add Offset to TACCR0 */
	TimerA_setCompareValue(__MSP430_BASEADDRESS_T1A3__,
	                      TIMERA_CAPTURECOMPARE_REGISTER_0,
	                      TimerA_getCaptureCompareCount(
	                              __MSP430_BASEADDRESS_T1A3__,
	                              TIMERA_CAPTURECOMPARE_REGISTER_0)+(32000-1));


}
