//*****************************************************************************
//
// sharp96x96.h
//
//
//*****************************************************************************

#ifndef __SHARPLCD_H__
#define __SHARPLCD_H__

//*****************************************************************************
//
// User Configuration for the LCD Driver
//
//*****************************************************************************
// LCD Screen Dimensions
#define LCD_VERTICAL_MAX    96
#define LCD_HORIZONTAL_MAX  96

// LCD Bus Width
#define LCD_BUS_WIDTH       16

// MCLK FREQUENCY (in MHz)
#define MCLK_FREQUENCY      25      

// Define LCD Screen Orientation Here
#define LANDSCAPE_FLIP

//Maximum Colors in an image color palette
#define MAX_PALETTE_COLORS  2

#define SHARP_SEND_TOGGLE_VCOM_COMMAND		0x01
#define SHARP_SKIP_TOGGLE_VCOM_COMMAND 		0x00

#define SHARP_LCD_TRAILER_BYTE				0x00

#define SHARP_VCOM_TOGGLE_BIT 		   		0x40

#define SHARP_LCD_CMD_CHANGE_VCOM			0x00
#define SHARP_LCD_CMD_CLEAR_SCREEN			0x20
#define SHARP_LCD_CMD_WRITE_LINE			0x80

//*****************************************************************************
//
// Macros for the Display Driver
//
//*****************************************************************************

//
// Translates a 24-bit RGB color to a display driver-specific color.
//
// \param c is the 24-bit RGB color.  The least-significant byte is the blue
// channel, the next byte is the green channel, and the third byte is the red
// channel.
//
// This macro translates a 24-bit RGB color into a value that can be written
// into the display's frame buffer in order to reproduce that color, or the
// closest possible approximation of that color. This particular driver
// requires the 8-8-8 24 bit RGB color to convert into 5-6-5 16 bit RGB Color
//
// \return Returns the display-driver specific color

#define DPYCOLORTRANSLATE(c)    (((c) & 0xff))
//
// Macro used to set the LCD data bus 
//
// \param uByte is the 8 or 16 bit (depending on parallel bus type)
// value to write to bus
//
// Define depending on the bus width, 8 or 16 pins, a char or an int
// is written to the Port Pin registers
//
// \return None

//
// Writes a command to the LCD Driver
//
// \param ucCommand is the 8 bit command to send to the LCD driver
// This particular LCD has only 8 bit commands
//
// \return None

#define WriteCommand(ucCommand)                                                  \
      while(UCA1STATW&UCBUSY);                                             \
      UCA1TXBUF = ucCommand


//
// Writes data to the LCD Driver
//
// \param uData is the 8 or 16 bit command to send to the LCD driver
// Uses the SET_LCD_DATA macro
//
// \return None

#define WriteData(uData)                                                  \
      while(UCA1STATW&UCBUSY);                                             \
      UCA1TXBUF = uData

//
// Sets the cursor to coordinates X, Y. Increment from Left to Right
//
// \param X and Y are the LCD pixel coordinates to place the cursor
//
// This macro sets the cursor location, and sets auto incrementing
// of the X value from left to right on the LCD screen. This is used
// when drawing rows of pixels in images or lines. Upon exiting this 
// macro, the LCD should be ready to accept a stream of data
//
// Note that left to right is relative to the screen orientation, but
// HORIZ_DIRECTION is defined depending on screen orientation to always
// be left to right. (See Coordinate Space and Mapping above)
//
// \return None

#define SetCursorLtoR(X, Y)                                                \
    __no_operation();

//
// Sets the cursor to coordinates X, Y. Increment from Top to Bottom
//
// \param X and Y are the LCD pixel coordinates to place the cursor
//
// This macro sets the cursor location, and sets auto incrementing
// of the Y value from top to bottom on the LCD screen. This is used
// when drawing rows of pixels in images or lines. Upon exiting this 
// macro, the LCD should be ready to accept a stream of data
//
// Note that top to bottom is relative to the screen orientation, but
// VERT_DIRECTION is defined depending on screen orientation to always
// be top to bottom. (See Coordinate Space and Mapping above)
//
// \return None

#define SetCursorTtoB(X, Y)                                                \
    __no_operation();

//*****************************************************************************
//
// Prototypes for the globals exported by this driver.
//
//*****************************************************************************
//extern void WriteDataGPIO(unsigned short usData);
extern void Sharp96x96_LCDInit(void);
extern const tDisplay g_sharp96x96LCD;
extern void Sharp96x96_SendToggleVCOMCommand();
#endif // __SHARPLCD_H__
