#include "inc/hw_memmap.h"
#include "grlib.h"
#include "driverlib/5xx_6xx/ucs.h"
#include "driverlib/5xx_6xx/pmm.h"
#include "driverlib/5xx_6xx/wdt.h"
#include "sharp400x240.h"
#include "images/images.h"


// EXTCOM Mode Select
#define EXTCOMIN_TOGGLE


void clockInit(void);

void main(void)
{
  volatile unsigned int i, j;
  long stringWidth = 0;

  tContext sContext;
  tRectangle myRectangle1 = { 100, 125, 120, 155};
  tRectangle myRectangle2 = { 45, 125, 75, 155};

  // Stop WDT
  WDT_hold(__MSP430_BASEADDRESS_WDT_A__);
  clockInit();

  //
  // Initialize the display driver
  //
  Sharp400x240_LCDInit();
 
  //
  // Initialize the graphics context
  //
  GrContextInit(&sContext, &g_sharp400x240LCD);


  GrContextForegroundSet(&sContext, ClrBlack);
  GrContextBackgroundSet(&sContext, ClrWhite);

  GrClearDisplay(&sContext);

  GrCircleDraw(&sContext, 120, 85, 25);
  GrCircleFill(&sContext, 60, 85, 25);

  GrRectDraw(&sContext, &myRectangle1 );
  GrRectFill(&sContext, &myRectangle2);

  GrLineDraw(&sContext, 20, 40,150, 40);


  GrContextFontSet(&sContext, &g_sFontCm26);

  GrStringDraw(&sContext, "Welcome to ", -1, 20, 8, 0);

  stringWidth = GrStringWidthGet(&sContext, "Welcome to", -1);
  GrContextFontSet(&sContext, &g_sFontCm30);
  GrContextForegroundSet(&sContext, ClrWhite );
  GrContextBackgroundSet(&sContext, ClrBlack);
  GrStringDraw(&sContext, "Dallas TX", -1, 20, 200, 1);

  GrFlush(&sContext);
  __no_operation();

  //Deleting some of the previously drawn operations
   GrContextForegroundSet(&sContext, ClrWhite);
   GrContextBackgroundSet(&sContext, ClrBlack);
   GrLineDraw(&sContext, 20, 40,150, 40);

   GrContextForegroundSet(&sContext, ClrWhite );
   GrContextBackgroundSet(&sContext, ClrBlack);
   GrContextFontSet(&sContext, &g_sFontCm26);
   GrStringDraw(&sContext, "Welcome to ", -1, 20, 8, 0);

   GrFlush(&sContext);
   __no_operation();


  GrClearDisplay(&sContext);
  GrImageDraw(&sContext, &Pig1BPP_COMP_RLE4, 0, 0);

  GrFlush(&sContext);
  __no_operation();

  Sharp400x240_LCDShutdown();

   while(1)
  {  
   __bis_SR_register(LPM0_bits + GIE);     // LPM0 w/ interrupts
   __no_operation();                       // For debugger
  } 

}

void clockInit(void)
{
	//Minimum CoreV
    PMM_setVCore(__MSP430_BASEADDRESS_PMM__,
	        PMM_CORE_LEVEL_0
	        );

    UCS_clockSignalInit(
    	        __MSP430_BASEADDRESS_UCS__,
    	        UCS_ACLK,
    	        UCS_REFOCLK_SELECT,
    	        UCS_CLOCK_DIVIDER_1
    	        );

    UCS_clockSignalInit(
   		        __MSP430_BASEADDRESS_UCS__,
   		        UCS_SMCLK,
   		        UCS_DCOCLK_SELECT,
   		        UCS_CLOCK_DIVIDER_1
   		        );

   	UCS_clockSignalInit(
   			        __MSP430_BASEADDRESS_UCS__,
   			        UCS_MCLK,
   			        UCS_DCOCLK_SELECT,
   			        UCS_CLOCK_DIVIDER_1
   			        );

   	UCS_clockSignalInit(
                    __MSP430_BASEADDRESS_UCS__,
                    UCS_FLLREF,
                    UCS_REFOCLK_SELECT,
                    UCS_CLOCK_DIVIDER_1
                    );

	//Set Ratio and Desired MCLK Frequency = 8MHz  and initialize DCO
	UCS_initFLLSettle(
			__MSP430_BASEADDRESS_UCS__,
	        8000,
	        250
	        );

}


