/*  
 * ======== main.c ========
 * Packet Protocol Demo:
 *
 * This USB demo example is to be used with a PC application (e.g. HyperTerminal)
 * to get the demo running, open hyper terminal and type any number 'x' between
 * 1-9, followed by 'x' number of charaters. Once all the 'x' characters are
 * received, the phrase " I received your packet with size of 'x' bytes" is sent
 * to the hyper terminal.
 *
 * If any character other than 1-9 is entered, then the following phrase is
 * returned: "Enter a valid number between 1 and 9"
 *
 * NOTE: In order to see the characters that you are typing in theHyper Terminal
 * window goto File -> Propoerties -> Settings -> ASCII Setup and check the
 * "Echo Typed Characters Locally"
 *
 * ----------------------------------------------------------------------------+
 * Please refer to the MSP430 USB API Stack Programmer's Guide,located
 * in the root directory of this installation for more details.
 * ---------------------------------------------------------------------------*/
#include <intrinsics.h>
#include <string.h>

#include "USB_config/descriptors.h"

#include "USB_API/USB_Common/device.h"
#include "USB_API/USB_Common/types.h"               //Basic Type declarations
#include "USB_API/USB_Common/usb.h"                 //USB-specific functions

#include "F5xx_F6xx_Core_Lib/HAL_UCS.h"
#include "F5xx_F6xx_Core_Lib/HAL_PMM.h"

#include "USB_API/USB_CDC_API/UsbCdc.h"
#include "usbConstructs.h"

VOID Init_Ports (VOID);
VOID Init_Clock (VOID);
volatile BYTE bDataReceiveCompleted_event = FALSE;
volatile BYTE bCommandBeingProcessed = FALSE;


WORD x,y;
BYTE size;
char c[2] = "";

#define bufferLen 11                    //The "size" byte can only be a single ASCII numerical digit, which means 1-9
BYTE buffer[bufferLen];
char outString[65];                     //Holds outgoing strings to be sent

/*  
 * ======== main ========
 */
VOID main (VOID)
{
    WDTCTL = WDTPW + WDTHOLD;                                   //Stop watchdog timer

    Init_Ports();                                               //Init ports (do first ports because clocks do change ports)
    SetVCore(3);
    Init_Clock();                                               //Init clocks
	
    USB_init();                 //Init USB

    USB_setEnabledEvents(
        kUSB_VbusOnEvent + kUSB_VbusOffEvent + kUSB_receiveCompletedEvent
        + kUSB_dataReceivedEvent + kUSB_UsbSuspendEvent + kUSB_UsbResumeEvent +
        kUSB_UsbResetEvent);

    //Check if we're already physically attached to USB, and if so, connect to it
    //This is the same function that gets called automatically when VBUS gets attached.
    if (USB_connectionInfo() & kUSB_vbusPresent){
        USB_handleVbusOnEvent();
    }

	__enable_interrupt();                           //Enable interrupts globally
    while (1)
    {
        switch (USB_connectionState())
        {
            case ST_USB_DISCONNECTED:
                __bis_SR_register(LPM3_bits + GIE);                                     //Enter LPM3 w/interrupt
                break;

            case ST_USB_CONNECTED_NO_ENUM:
                break;

            case ST_ENUM_ACTIVE:
                if (!bCommandBeingProcessed){                                           //If no command is being processed, then
                                                                                        //make sure there's a rcv operation
                                                                                        //open to receive the start of the "packet"
                    if (!(USBCDC_intfStatus(CDC0_INTFNUM,&x,
                              &y) & kUSBCDC_waitingForReceive)){                        //Only open it if we haven't already done so
                        if (USBCDC_receiveData(buffer,1,
                                CDC0_INTFNUM) == kUSBCDC_busNotAvailable){              //Start a receive operation for a single
                                                                                        //byte -- the "size" byte of
                                                                                        //the "packet"
                            USBCDC_abortReceive(&x,CDC0_INTFNUM);                       //Abort receive
                            break;                                                      //If bus is no longer available, escape out
                                                                                        //of the loop
                        }
                    }
                }

                __bis_SR_register(LPM0_bits + GIE);                                     //Wait in LPM0 until a receive operation has
                                                                                        //completed
                                                                                        //__bis_SR_register(LPM0_bits + GIE);
                if (bDataReceiveCompleted_event){
                    bDataReceiveCompleted_event = FALSE;
                    if (!bCommandBeingProcessed){                                       //This means that the incoming byte is the
                                                                                        //start of the "packet" -- the "size" byte
                        if ((buffer[0] >= 0x31) &&  (buffer[0] <= 0x39)){
                            size = buffer[0] - 0x30;                                    //It's in ASCII, so convert it to a number

                            if (USBCDC_receiveData(buffer,size,
                                    CDC0_INTFNUM) == kUSBCDC_busNotAvailable){          //And then open a rcv operation for that
                                                                                        //size
                                USBCDC_abortReceive(&x,CDC0_INTFNUM);                   //Abort receive
                                break;                                                  //If bus is no longer available, escape out
                                                                                        //of the loop
                            }
                            bCommandBeingProcessed = TRUE;                              //Now we're waiting for the "data" part of
                                                                                        //the "packet"
                        } else {
                            strcpy(
                                outString,
                                "\r\nEnter a valid number between 1 and 9\r\n\r\n");    //Prepare the outgoing string
                            if (cdcSendDataInBackground((BYTE*)outString,
                                    strlen(outString),CDC0_INTFNUM,0)){                 //Send the response over USB
                                USBCDC_abortSend(&x,CDC0_INTFNUM);                      //Operation may still be open; cancel it
                                break;                                                  //If the send fails, escape the main loop
                            }
                            bCommandBeingProcessed = FALSE;                             //Now we're back to waiting for the "size"
                                                                                        //byte
                        }
                    } else {                                                            //This means that the incoming data is the
                                                                                        //"data" part of the "packet"
                        strcpy(outString,
                            "\r\nI received your packet with size of ");                //Prepare the outgoing string
                        buffer[bufferLen - 1] = 0;
                        c[0] = (char)(size + '0');
                        c[1] = 0;
                        outString[64] = 0;                                              //Convert the size back to ASCII
                        strcat(outString,c);
                        strcat(outString," bytes.\r\n\r\n");
                        if (cdcSendDataInBackground((BYTE*)outString,
                                strlen(outString),CDC0_INTFNUM,0)){                     //Send the response over USB
                            USBCDC_abortSend(&x,CDC0_INTFNUM);                          //Operation may still be open; cancel it
                            break;                                                      //If the send fails, escape the main loop
                        }
                        bCommandBeingProcessed = FALSE;                                 //Now we're back to waiting for the "size"
                                                                                        //byte
                    }
                }
                break;

            case ST_ENUM_SUSPENDED:
                __bis_SR_register(LPM3_bits + GIE);             //Enter LPM3 until a resume or VBUS-off event
                break;

            case ST_ENUM_IN_PROGRESS:
                break;

            case ST_NOENUM_SUSPENDED:
                __bis_SR_register(LPM3_bits + GIE);
                break;

            case ST_ERROR:
                _NOP();
                break;

            default:;
        }
    }  //while(1)
} //main()

/*  
 * ======== Init_Clock ========
 */
VOID Init_Clock (VOID)
{
    //Initialization of clock module
    if (USB_PLL_XT == 2){
		#if defined (__MSP430F552x) || defined (__MSP430F550x)
			P5SEL |= 0x0C;                                      //enable XT2 pins for F5529
		#elif defined (__MSP430F563x_F663x)
			P7SEL |= 0x0C;
		#endif

        //use REFO for FLL and ACLK
        UCSCTL3 = (UCSCTL3 & ~(SELREF_7)) | (SELREF__REFOCLK);
        UCSCTL4 = (UCSCTL4 & ~(SELA_7)) | (SELA__REFOCLK);

        //MCLK will be driven by the FLL (not by XT2), referenced to the REFO
        Init_FLL_Settle(USB_MCLK_FREQ / 1000, USB_MCLK_FREQ / 32768);   //Start the FLL, at the freq indicated by the config
                                                                        //constant USB_MCLK_FREQ
        XT2_Start(XT2DRIVE_0);                                          //Start the "USB crystal"
    } 
	else {
		#if defined (__MSP430F552x) || defined (__MSP430F550x)
			P5SEL |= 0x10;                                      //enable XT1 pins
		#endif
        //Use the REFO oscillator to source the FLL and ACLK
        UCSCTL3 = SELREF__REFOCLK;
        UCSCTL4 = (UCSCTL4 & ~(SELA_7)) | (SELA__REFOCLK);

        //MCLK will be driven by the FLL (not by XT2), referenced to the REFO
        Init_FLL_Settle(USB_MCLK_FREQ / 1000, USB_MCLK_FREQ / 32768);   //set FLL (DCOCLK)

        XT1_Start(XT1DRIVE_0);                                          //Start the "USB crystal"
    }
}

/*  
 * ======== Init_Ports ========
 */
VOID Init_Ports (VOID)
{
    //Initialization of ports (all unused pins as outputs with low-level
    P1OUT = 0x00;
    P1DIR = 0xFF;
	P2OUT = 0x00;
    P2DIR = 0xFF;
    P3OUT = 0x00;
    P3DIR = 0xFF;
    P4OUT = 0x00;
    P4DIR = 0xFF;
    P5OUT = 0x00;
    P5DIR = 0xFF;
    P6OUT = 0x00;
    P6DIR = 0xFF;
	P7OUT = 0x00;
    P7DIR = 0xFF;
    P8OUT = 0x00;
    P8DIR = 0xFF;
    #if defined (__MSP430F563x_F663x)
		P9OUT = 0x00;
		P9DIR = 0xFF;
    #endif
}

/*  
 * ======== UNMI_ISR ========
 */
#pragma vector = UNMI_VECTOR
__interrupt VOID UNMI_ISR (VOID)
{
    switch (__even_in_range(SYSUNIV, SYSUNIV_BUSIFG ))
    {
        case SYSUNIV_NONE:
            __no_operation();
            break;
        case SYSUNIV_NMIIFG:
            __no_operation();
            break;
        case SYSUNIV_OFIFG:
            UCSCTL7 &= ~(DCOFFG + XT1LFOFFG + XT2OFFG); //Clear OSC flaut Flags fault flags
            SFRIFG1 &= ~OFIFG;                  //Clear OFIFG fault flag
            break;
        case SYSUNIV_ACCVIFG:
            __no_operation();
            break;
        case SYSUNIV_BUSIFG:
            SYSBERRIV = 0;                                      //clear bus error flag
            USB_disable();                                      //Disable
    }
}

